within ;
package ThermoelectricGenerator_V5_7
  model TEG_Module "TEG Module with ceramic packaging"

    //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

    //"Thermoelectric device (TEG or Peltier cooler) - 1D transient model: N couples, thermally in parallel, electrically in series"

    parameter Modelica.SIunits.Temperature T_0=295.15
      "Initial homogeneous temperature of element";

    parameter Modelica.SIunits.Thickness L=0.01 "Thickness of thermoelement";
    parameter Integer N=1 "Number of thermoelectric couples";
    parameter Modelica.SIunits.Area A=0.01^2
      "Cross section area of each single leg";

    parameter Modelica.SIunits.Length Length "Length of TEG";
    parameter Modelica.SIunits.Breadth Breadth "Breadth of TEG";
    parameter Modelica.SIunits.Thickness T_CP1 "Thickness 'left' ceramic plate";
    parameter Modelica.SIunits.Thickness T_CP2
      "Thickness 'right' ceramic plate";

    replaceable
      ThermoelectricGenerator_V5_7.Inner_TEG.CTEL_1D_dyn_seq_intalpha_contact_res
      inner_TEG constrainedby ThermoelectricGenerator_V5_7.Inner_TEG.CTEL_base(
      A=A,
      L=L,
      N_TE=N,
      T_0=T_0) "Model for TEG calculation" annotation (
      Placement(transformation(extent={{-82,-76},{70,70}})),
      Dialog(group=
            "Choose models for simulation (Further parameters can be edited in chosen model)"),

      choicesAllMatching=true);

    replaceable ThermoelectricGenerator_V5_7.Packaging.seq_1D_with_storing packaging_left
      constrainedby Packaging.base_class(
      T_0=T_0,
      Thickness=T_CP1,
      Breadth=Breadth,
      Length=Length) "Model for left ceramic packaging" annotation (
      Placement(transformation(extent={{-134,-78},{-112,78}})),
      choicesAllMatching=true,
      Dialog(group=
            "Choose models for simulation (Further parameters can be edited in chosen model)"));

    replaceable ThermoelectricGenerator_V5_7.Packaging.seq_1D_with_storing packaging_right
      constrainedby Packaging.base_class(
      T_0=T_0,
      Thickness=T_CP2,
      Breadth=Breadth,
      Length=Length) "Model for right ceramic packaging" annotation (
      Placement(transformation(extent={{96,-80},{116,80}})),
      choicesAllMatching=true,
      Placement(transformation(extent={{-302,82},{-280,242}})),
      Dialog(group=
            "Choose models for simulation (Further parameters can be edited in chosen model)"));

    Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a
      annotation (Placement(transformation(extent={{-170,-10},{-150,10}}),
          iconTransformation(extent={{-170,-10},{-150,10}})));
    Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b
      annotation (Placement(transformation(extent={{132,-10},{152,10}}),
          iconTransformation(extent={{132,-10},{152,10}})));
    Modelica.Electrical.Analog.Interfaces.PositivePin pin_p
      annotation (Placement(transformation(extent={{-170,-110},{-150,-90}}),
          iconTransformation(extent={{-170,-110},{-150,-90}})));
    Modelica.Electrical.Analog.Interfaces.NegativePin pin_n
      annotation (Placement(transformation(extent={{-170,92},{-150,112}}),
          iconTransformation(extent={{-170,92},{-150,112}})));

  equation
  // annotation (__Dymola_Images(Parameters(group="Sketch",
  // source="Images/TEG.png")));
    connect(pin_p, inner_TEG.p) annotation (Line(
        points={{-160,-100},{-96,-100},{-96,-44.8957},{-64.2667,-44.8957}},
        color={0,0,255},
        smooth=Smooth.None));
    connect(inner_TEG.port_a, packaging_left.port_b) annotation (Line(
        points={{-64.5833,0.491304},{-87.8333,0.491304},{-87.8333,0},{-112,0}},
        color={191,0,0},
        smooth=Smooth.None));
    connect(packaging_left.port_a, port_a) annotation (Line(
        points={{-134,0},{-160,0}},
        color={191,0,0},
        smooth=Smooth.None));
    connect(inner_TEG.n, pin_n) annotation (Line(
        points={{-64.2667,44.6087},{-98,44.6087},{-98,102},{-160,102}},
        color={0,0,255},
        smooth=Smooth.None));
    connect(inner_TEG.port_b, packaging_right.port_a) annotation (Line(
        points={{52.5833,0.491304},{80.8333,0.491304},{80.8333,0},{96,0}},
        color={191,0,0},
        smooth=Smooth.None));
    connect(packaging_right.port_b, port_b) annotation (Line(
        points={{116,0},{142,0}},
        color={191,0,0},
        smooth=Smooth.None));
  annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),           __Dymola_Images(Parameters(
  source="Images/TEG.png")),
      Icon(coordinateSystem(extent={{-180,-180},{180,160}},
            preserveAspectRatio=true), graphics={
          Text(
            extent={{-177,86},{-177,62}},
            lineColor={0,0,255},
            lineThickness=0.5,
            fillPattern=FillPattern.VerticalCylinder,
            fillColor={0,0,255},
            textString="n"),
          Text(
            extent={{-174,-118},{-174,-142}},
            lineColor={0,0,255},
            lineThickness=0.5,
            fillPattern=FillPattern.VerticalCylinder,
            fillColor={0,0,255},
            textString="p"),
          Rectangle(
            extent={{-146,126},{140,-140}},
            lineColor={184,0,0},
            lineThickness=0.5,
            fillColor={245,245,245},
            fillPattern=FillPattern.Solid),
          Text(
            extent={{-185,-15},{-185,-31}},
            lineColor={184,0,0},
            lineThickness=0.5,
            textString="port_a"),
          Text(
            extent={{167,-18},{167,-34}},
            lineColor={184,0,0},
            lineThickness=0.5,
            textString="port_b"),
          Rectangle(
            extent={{-126,84},{-114,-80}},
            lineColor={135,135,135},
            fillColor={175,175,175},
            fillPattern=FillPattern.Solid),
          Rectangle(extent={{-77,-59},{65,-79}}, lineColor={0,127,0}),
          Text(
            extent={{-6,-60},{-6,-78}},
            lineColor={0,127,0},
            fillColor={255,128,0},
            fillPattern=FillPattern.Solid,
            textString="Material_B"),
          Rectangle(
            extent={{75,-27},{79,-79}},
            lineColor={135,135,135},
            fillColor={0,0,255},
            fillPattern=FillPattern.Solid),
          Rectangle(
            extent={{-95,83},{-92,56}},
            lineColor={135,135,135},
            fillColor={0,0,255},
            fillPattern=FillPattern.Solid),
          Rectangle(extent={{-77,-27},{65,-47}}, lineColor={255,200,2}),
          Text(
            extent={{-6,-28},{-6,-46}},
            lineColor={255,200,2},
            fillColor={255,128,0},
            fillPattern=FillPattern.Solid,
            textString="Material_A"),
          Text(
            extent={{-6,50},{-6,32}},
            lineColor={0,127,0},
            fillColor={255,128,0},
            fillPattern=FillPattern.Solid,
            textString="Material_B"),
          Rectangle(extent={{-77,51},{65,31}}, lineColor={0,127,0}),
          Rectangle(extent={{-77,83},{66,63}}, lineColor={255,200,2}),
          Text(
            extent={{-6,82},{-6,64}},
            lineColor={255,200,2},
            fillColor={255,128,0},
            fillPattern=FillPattern.Solid,
            textString="Material_A"),
          Rectangle(
            extent={{75,83},{79,31}},
            lineColor={135,135,135},
            fillColor={0,0,255},
            fillPattern=FillPattern.Solid),
          Text(
            extent={{-6,47},{-6,3}},
            lineColor={0,0,0},
            lineThickness=0.5,
            fillPattern=FillPattern.Solid,
            textString="."),
          Text(
            extent={{-6,18},{-6,-26}},
            lineColor={0,0,0},
            lineThickness=0.5,
            fillPattern=FillPattern.Solid,
            textString="."),
          Text(
            extent={{-6,30},{-6,-14}},
            lineColor={0,0,0},
            lineThickness=0.5,
            fillPattern=FillPattern.Solid,
            textString="."),
          Text(
            extent={{-102,-109},{98,-135}},
            lineColor={184,0,0},
            fillColor={0,166,0},
            fillPattern=FillPattern.Solid,
            textString="%name",
            lineThickness=0.5),
          Rectangle(
            extent={{100,83},{111,-80}},
            lineColor={135,135,135},
            fillColor={175,175,175},
            fillPattern=FillPattern.Solid),
          Rectangle(
            extent={{-130,4},{-126,0}},
            lineColor={255,85,85},
            fillColor={255,85,85},
            fillPattern=FillPattern.Solid),
          Rectangle(
            extent={{-114,60},{-110,56}},
            lineColor={255,85,85},
            fillColor={255,85,85},
            fillPattern=FillPattern.Solid),
          Rectangle(
            extent={{-99,60},{-95,56}},
            lineColor={255,85,85},
            fillColor={255,85,85},
            fillPattern=FillPattern.Solid),
          Rectangle(
            extent={{-114,-46},{-110,-50}},
            lineColor={255,85,85},
            fillColor={255,85,85},
            fillPattern=FillPattern.Solid),
          Rectangle(
            extent={{-99,-46},{-95,-50}},
            lineColor={255,85,85},
            fillColor={255,85,85},
            fillPattern=FillPattern.Solid),
          Rectangle(
            extent={{79,62},{83,58}},
            lineColor={255,85,85},
            fillColor={255,85,85},
            fillPattern=FillPattern.Solid),
          Rectangle(
            extent={{96,62},{100,58}},
            lineColor={255,85,85},
            fillColor={255,85,85},
            fillPattern=FillPattern.Solid),
          Rectangle(
            extent={{79,-52},{83,-56}},
            lineColor={255,85,85},
            fillColor={255,85,85},
            fillPattern=FillPattern.Solid),
          Rectangle(
            extent={{96,-52},{100,-56}},
            lineColor={255,85,85},
            fillColor={255,85,85},
            fillPattern=FillPattern.Solid),
          Rectangle(
            extent={{111,2},{115,-2}},
            lineColor={255,85,85},
            fillColor={255,85,85},
            fillPattern=FillPattern.Solid),
          Line(
            points={{-128,2},{-158,2}},
            color={255,85,85},
            smooth=Smooth.None),
          Line(
            points={{-98,58},{-112,58}},
            color={255,85,85},
            smooth=Smooth.None),
          Line(
            points={{-98,-48},{-112,-48}},
            color={255,85,85},
            smooth=Smooth.None),
          Line(
            points={{96,60},{82,60}},
            color={255,85,85},
            smooth=Smooth.None),
          Line(
            points={{96,-54},{82,-54}},
            color={255,85,85},
            smooth=Smooth.None),
          Line(
            points={{140,0},{114,0}},
            color={255,85,85},
            smooth=Smooth.None),
          Rectangle(
            extent={{-95,-47},{-92,-80}},
            lineColor={135,135,135},
            fillColor={0,0,255},
            fillPattern=FillPattern.Solid)}),
      Diagram(coordinateSystem(extent={{-180,-180},{180,160}},
            preserveAspectRatio=false), graphics={Rectangle(
            extent={{-160,116},{140,-120}},
            lineColor={0,0,0},
            fillColor={215,215,215},
            fillPattern=FillPattern.Solid)}));
  end TEG_Module;
extends Modelica.Icons.Package;

  //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

  package Examples

    //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

  extends Modelica.Icons.ExamplesPackage;

    package IEEE_Examples "Examples from paper: F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of
  Thermoelectric Devices for Energy System Design'', IEEE Transaction on Industrial Electronics, Vol.: 61, No.: 3, March 2014, pp. 1301-1310"

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

    extends Modelica.Icons.ExamplesPackage;

      model TEG_TrDP_compared_with_TEG_StAP
        "'TrDP Model' compared with 'StAP Model' (cf. Fig. 5, 6 of paper referenced in 'Documentation' of this model)"

        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends Modelica.Icons.Example;

        Real Power=voltageSensor.v*currentSensor.i
          "Electric power in 'Load_resisitor'";

        Real Power_STATIC=voltageSensor1.v*currentSensor1.i
          "Electric power in 'Load_resisitor1' (STATIC MODEL)";

        Real PowerError(unit="%") = if abs(Power) > 0 then 100*(Power_STATIC -
          Power)/Power else 0;

        Modelica.Thermal.HeatTransfer.Sources.FixedTemperature T_h(T(displayUnit=
                "K") = 500)
          annotation (Placement(transformation(extent={{-76,22},{-56,2}})));
        Modelica.Thermal.HeatTransfer.Sources.FixedTemperature T_l(T(displayUnit=
                "K") = 300) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=180,
              origin={73,12})));
        Modelica.Electrical.Analog.Basic.Ground ground
          annotation (Placement(transformation(extent={{28,-26},{52,-2}})));
        Modelica.Electrical.Analog.Basic.Resistor Load_resistor(R=R)
          annotation (Placement(transformation(extent={{-36,44},{-8,72}})));
        Modelica.Electrical.Analog.Sensors.VoltageSensor voltageSensor
          annotation (Placement(transformation(extent={{-34,72},{-10,96}})));
        Modelica.Electrical.Analog.Sensors.CurrentSensor currentSensor
          annotation (Placement(transformation(extent={{6,46},{30,70}})));
        Inner_TEG.CTEL_1D_dyn_seq
                               TEG(
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_p_Thermonamic
            Material_A,
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_n_Thermonamic
            Material_B,
          T_0(displayUnit="K") = 300,
          S=10,
          A=0.0014*0.0014,
          L=0.0008,
          N_TE=199)
          annotation (Placement(transformation(extent={{-28,-18},{26,36}})));
        parameter Modelica.SIunits.Resistance R=2.502 "Load resistance";
        Modelica.Electrical.Analog.Basic.Resistor Load_resistor1(R=R)
          annotation (Placement(transformation(extent={{-27,-87},{1,-59}})));
        Modelica.Electrical.Analog.Sensors.VoltageSensor voltageSensor1
          annotation (Placement(transformation(extent={{-32,-59},{-8,-35}})));
        Modelica.Electrical.Analog.Sensors.CurrentSensor currentSensor1
          annotation (Placement(transformation(extent={{8,-85},{32,-61}})));
        Inner_TEG.Components_for_TEL.ThermoelectricElement_STATIC
                                               TE_STATIC_A(
          Type="p-type",
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_p_Thermonamic
            Material,
          A=TEG.A,
          L=TEG.L,
          T_0=TEG.T_0,
          ThomsonEffect=true,
          N_TE=TEG.N_TE)
          annotation (Placement(transformation(extent={{-20,-108},{-4,-92}})));
        Inner_TEG.Components_for_TEL.ThermoelectricElement_STATIC
                                               TE_STATIC_B(
          Type="n-type",
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_n_Thermonamic
            Material,
          A=TEG.A,
          L=TEG.L,
          T_0=TEG.T_0,
          ThomsonEffect=true,
          N_TE=TEG.N_TE)
          annotation (Placement(transformation(extent={{-20,-123},{-4,-107}})));
        Modelica.Electrical.Analog.Basic.Ground ground1
          annotation (Placement(transformation(extent={{28,-119},{52,-95}})));
      equation
        connect(voltageSensor.p, Load_resistor.p) annotation (Line(
            points={{-34,84},{-42,84},{-42,58},{-36,58}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(voltageSensor.n, Load_resistor.n) annotation (Line(
            points={{-10,84},{-2,84},{-2,58},{-8,58}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(currentSensor.p, Load_resistor.n) annotation (Line(
            points={{6,58},{-8,58}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(currentSensor.n, ground.p) annotation (Line(
            points={{30,58},{40,58},{40,-2}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TEG.p, Load_resistor.p) annotation (Line(
            points={{-21.7,-5.97273},{-42,-5.97273},{-42,58},{-36,58}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TEG.n, ground.p) annotation (Line(
            points={{-21.7,28.6364},{-34,28.6364},{-34,41},{40,41},{40,-2}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(voltageSensor1.p, Load_resistor1.p) annotation (Line(
            points={{-32,-47},{-40,-47},{-40,-73},{-27,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(voltageSensor1.n, Load_resistor1.n) annotation (Line(
            points={{-8,-47},{0,-47},{0,-73},{1,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(currentSensor1.p, Load_resistor1.n) annotation (Line(
            points={{8,-73},{1,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_A.n, TE_STATIC_B.n) annotation (Line(
            points={{-5.6,-96},{1,-96},{1,-111},{-5.6,-111}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_B.p, Load_resistor1.p) annotation (Line(
            points={{-18.32,-111.16},{-40,-111.16},{-40,-73},{-27,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_A.p, currentSensor1.n) annotation (Line(
            points={{-18.32,-96.16},{-29,-96.16},{-29,-88},{40,-88},{40,-73},{32,
                -73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));

        connect(ground1.p, currentSensor1.n) annotation (Line(
            points={{40,-95},{40,-73},{32,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_B.port_a, TE_STATIC_A.port_a) annotation (Line(
            points={{-18.32,-119},{-23,-119},{-23,-104},{-18.32,-104}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_A.port_b, TE_STATIC_B.port_b) annotation (Line(
            points={{-5.6,-104},{0,-104},{0,-119},{-5.6,-119}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TEG.port_b, T_l.port) annotation (Line(
            points={{19.8125,11.5773},{50.4841,11.5773},{50.4841,12},{63,12}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TEG.port_a, T_h.port) annotation (Line(
            points={{-21.8125,11.5773},{-39.4841,11.5773},{-39.4841,12},{-56,12}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));

        connect(T_h.port, TE_STATIC_B.port_a) annotation (Line(
            points={{-56,12},{-51,12},{-51,-119},{-18.32,-119}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_B.port_b, T_l.port) annotation (Line(
            points={{-5.6,-119},{51,-119},{51,12},{63,12}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));

        annotation (
          Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),       Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-110,-150},{90,100}},
              grid={1,1}), graphics),
          experiment(StopTime=0.4),
          experimentSetupOutput,
          Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-110,-150},{90,100}},
              grid={1,1})));
      end TEG_TrDP_compared_with_TEG_StAP;

      model TEG_TrDP_alpha_Int_compared_with_TEG_StAP
        "'TrDP_alpha_Int Model' compared with 'StAP Model' (cf. Fig. 5, 6 of paper referenced in 'Documentation' of this model)"

        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends Modelica.Icons.Example;

        Real Power=voltageSensor.v*currentSensor.i
          "Electric power in 'Load_resisitor'";

        Real Power_STATIC=voltageSensor1.v*currentSensor1.i
          "Electric power in 'Load_resisitor1' (STATIC MODEL)";

        Real PowerError(unit="%") = if abs(Power) > 0 then 100*(Power_STATIC -
          Power)/Power else 0;

        Modelica.Thermal.HeatTransfer.Sources.FixedTemperature T_h(T(displayUnit=
                "K") = 500)
          annotation (Placement(transformation(extent={{-82,22},{-62,2}})));
        Modelica.Thermal.HeatTransfer.Sources.FixedTemperature T_l(T(displayUnit=
                "K") = 300) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=180,
              origin={77,12})));
        Modelica.Electrical.Analog.Basic.Ground ground
          annotation (Placement(transformation(extent={{28,-26},{52,-2}})));
        Modelica.Electrical.Analog.Basic.Resistor Load_resistor(R=R)
          annotation (Placement(transformation(extent={{-36,44},{-8,72}})));
        Modelica.Electrical.Analog.Sensors.VoltageSensor voltageSensor
          annotation (Placement(transformation(extent={{-34,72},{-10,96}})));
        Modelica.Electrical.Analog.Sensors.CurrentSensor currentSensor
          annotation (Placement(transformation(extent={{6,46},{30,70}})));
        Inner_TEG.CTEL_1D_dyn_seq_intalpha
                                         TEG(
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_p_Thermonamic
            Material_A,
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_n_Thermonamic
            Material_B,
          T_0(displayUnit="K") = 300,
          S=10,
          A=0.0014*0.0014,
          L=0.0008,
          N_TE=199)
          annotation (Placement(transformation(extent={{-28,-18},{26,36}})));
        parameter Modelica.SIunits.Resistance R=2.502 "Load resistance";
        Modelica.Electrical.Analog.Basic.Resistor Load_resistor1(R=R)
          annotation (Placement(transformation(extent={{-27,-87},{1,-59}})));
        Modelica.Electrical.Analog.Sensors.VoltageSensor voltageSensor1
          annotation (Placement(transformation(extent={{-32,-59},{-8,-35}})));
        Modelica.Electrical.Analog.Sensors.CurrentSensor currentSensor1
          annotation (Placement(transformation(extent={{8,-85},{32,-61}})));
        Inner_TEG.Components_for_TEL.ThermoelectricElement_STATIC
                                               TE_STATIC_A(
          Type="p-type",
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_p_Thermonamic
            Material,
          A=TEG.A,
          L=TEG.L,
          T_0=TEG.T_0,
          ThomsonEffect=true,
          N_TE=TEG.N_TE)
          annotation (Placement(transformation(extent={{-20,-108},{-4,-92}})));
        Inner_TEG.Components_for_TEL.ThermoelectricElement_STATIC
                                               TE_STATIC_B(
          Type="n-type",
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_n_Thermonamic
            Material,
          A=TEG.A,
          L=TEG.L,
          T_0=TEG.T_0,
          ThomsonEffect=true,
          N_TE=TEG.N_TE)
          annotation (Placement(transformation(extent={{-20,-123},{-4,-107}})));
        Modelica.Electrical.Analog.Basic.Ground ground1
          annotation (Placement(transformation(extent={{28,-119},{52,-95}})));
      equation
        connect(voltageSensor.p, Load_resistor.p) annotation (Line(
            points={{-34,84},{-42,84},{-42,58},{-36,58}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(voltageSensor.n, Load_resistor.n) annotation (Line(
            points={{-10,84},{-2,84},{-2,58},{-8,58}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(currentSensor.p, Load_resistor.n) annotation (Line(
            points={{6,58},{-8,58}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TEG.p, Load_resistor.p) annotation (Line(
            points={{-21.7,-5.97273},{-42,-5.97273},{-42,58},{-36,58}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(voltageSensor1.p, Load_resistor1.p) annotation (Line(
            points={{-32,-47},{-40,-47},{-40,-73},{-27,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(voltageSensor1.n, Load_resistor1.n) annotation (Line(
            points={{-8,-47},{0,-47},{0,-73},{1,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(currentSensor1.p, Load_resistor1.n) annotation (Line(
            points={{8,-73},{1,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_A.n, TE_STATIC_B.n) annotation (Line(
            points={{-5.6,-96},{1,-96},{1,-111},{-5.6,-111}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_B.p, Load_resistor1.p) annotation (Line(
            points={{-18.32,-111.16},{-40,-111.16},{-40,-73},{-27,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_A.p, currentSensor1.n) annotation (Line(
            points={{-18.32,-96.16},{-29,-96.16},{-29,-88},{40,-88},{40,-73},{32,
                -73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));

        connect(ground1.p, currentSensor1.n) annotation (Line(
            points={{40,-95},{40,-73},{32,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_B.port_a, TE_STATIC_A.port_a) annotation (Line(
            points={{-18.32,-119},{-23,-119},{-23,-104},{-18.32,-104}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_A.port_b, TE_STATIC_B.port_b) annotation (Line(
            points={{-5.6,-104},{0,-104},{0,-119},{-5.6,-119}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TEG.port_b, T_l.port) annotation (Line(
            points={{19.8125,11.5773},{56.4841,11.5773},{56.4841,12},{67,12}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TEG.port_a, T_h.port) annotation (Line(
            points={{-21.8125,11.5773},{-39.4841,11.5773},{-39.4841,12},{-62,12}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));

        connect(T_h.port, TE_STATIC_B.port_a) annotation (Line(
            points={{-62,12},{-51,12},{-51,-119},{-18.32,-119}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_B.port_b, T_l.port) annotation (Line(
            points={{-5.6,-119},{57,-119},{57,12},{67,12}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(currentSensor.n, ground.p) annotation (Line(
            points={{30,58},{45,58},{45,-2},{40,-2}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(currentSensor.n, TEG.n) annotation (Line(
            points={{30,58},{45,58},{45,38},{-21.7,38},{-21.7,28.6364}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));

        annotation (
          Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),       Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-150},{100,100}},
              grid={1,1}), graphics),
          experiment(StopTime=0.4, Algorithm="Dassl"),
          experimentSetupOutput,
          Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-150},{100,100}},
              grid={1,1})));
      end TEG_TrDP_alpha_Int_compared_with_TEG_StAP;

      model TEG_TrDP_alpha_Int_compared_with_TEG_StAP_otherTempRange
        "'TrDP_alpha_Int Model' compared with 'StAP Model' in another temp. range (cf. Fig. 7 of paper referenced in 'Documentation' of this model)"

        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends Modelica.Icons.Example;

        Real Power=voltageSensor.v*currentSensor.i
          "Electric power in 'Load_resisitor'";

        Real Power_STATIC=voltageSensor1.v*currentSensor1.i
          "Electric power in 'Load_resisitor1' (STATIC MODEL)";

        Real PowerError(unit="%") = if abs(Power) > 0 then 100*(Power_STATIC -
          Power)/Power else 0;

        Modelica.Thermal.HeatTransfer.Sources.FixedTemperature T_h(T(displayUnit=
                "K") = 400)
          annotation (Placement(transformation(extent={{-82,22},{-62,2}})));
        Modelica.Thermal.HeatTransfer.Sources.FixedTemperature T_l(T(displayUnit=
                "K") = 300) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=180,
              origin={77,12})));
        Modelica.Electrical.Analog.Basic.Ground ground
          annotation (Placement(transformation(extent={{28,-26},{52,-2}})));
        Modelica.Electrical.Analog.Basic.Resistor Load_resistor(R=R)
          annotation (Placement(transformation(extent={{-36,44},{-8,72}})));
        Modelica.Electrical.Analog.Sensors.VoltageSensor voltageSensor
          annotation (Placement(transformation(extent={{-34,72},{-10,96}})));
        Modelica.Electrical.Analog.Sensors.CurrentSensor currentSensor
          annotation (Placement(transformation(extent={{6,46},{30,70}})));
        Inner_TEG.CTEL_1D_dyn_seq_intalpha
                                         TEG(
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_p_Thermonamic
            Material_A,
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_n_Thermonamic
            Material_B,
          T_0(displayUnit="K") = 300,
          S=10,
          A=0.0014*0.0014,
          L=0.0008,
          N_TE=199)
          annotation (Placement(transformation(extent={{-28,-18},{26,36}})));
        parameter Modelica.SIunits.Resistance R=2.502 "Load resistance";
        Modelica.Electrical.Analog.Basic.Resistor Load_resistor1(R=R)
          annotation (Placement(transformation(extent={{-27,-87},{1,-59}})));
        Modelica.Electrical.Analog.Sensors.VoltageSensor voltageSensor1
          annotation (Placement(transformation(extent={{-32,-59},{-8,-35}})));
        Modelica.Electrical.Analog.Sensors.CurrentSensor currentSensor1
          annotation (Placement(transformation(extent={{8,-85},{32,-61}})));
        Inner_TEG.Components_for_TEL.ThermoelectricElement_STATIC
                                               TE_STATIC_A(
          Type="p-type",
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_p_Thermonamic
            Material,
          A=TEG.A,
          L=TEG.L,
          T_0=TEG.T_0,
          ThomsonEffect=true,
          N_TE=TEG.N_TE)
          annotation (Placement(transformation(extent={{-20,-108},{-4,-92}})));
        Inner_TEG.Components_for_TEL.ThermoelectricElement_STATIC
                                               TE_STATIC_B(
          Type="n-type",
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_n_Thermonamic
            Material,
          A=TEG.A,
          L=TEG.L,
          T_0=TEG.T_0,
          ThomsonEffect=true,
          N_TE=TEG.N_TE)
          annotation (Placement(transformation(extent={{-20,-123},{-4,-107}})));
        Modelica.Electrical.Analog.Basic.Ground ground1
          annotation (Placement(transformation(extent={{28,-119},{52,-95}})));
      equation
        connect(voltageSensor.p, Load_resistor.p) annotation (Line(
            points={{-34,84},{-42,84},{-42,58},{-36,58}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(voltageSensor.n, Load_resistor.n) annotation (Line(
            points={{-10,84},{-2,84},{-2,58},{-8,58}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(currentSensor.p, Load_resistor.n) annotation (Line(
            points={{6,58},{-8,58}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TEG.p, Load_resistor.p) annotation (Line(
            points={{-21.7,-5.97273},{-42,-5.97273},{-42,58},{-36,58}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(voltageSensor1.p, Load_resistor1.p) annotation (Line(
            points={{-32,-47},{-40,-47},{-40,-73},{-27,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(voltageSensor1.n, Load_resistor1.n) annotation (Line(
            points={{-8,-47},{0,-47},{0,-73},{1,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(currentSensor1.p, Load_resistor1.n) annotation (Line(
            points={{8,-73},{1,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_A.n, TE_STATIC_B.n) annotation (Line(
            points={{-5.6,-96},{1,-96},{1,-111},{-5.6,-111}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_B.p, Load_resistor1.p) annotation (Line(
            points={{-18.32,-111.16},{-40,-111.16},{-40,-73},{-27,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_A.p, currentSensor1.n) annotation (Line(
            points={{-18.32,-96.16},{-29,-96.16},{-29,-88},{40,-88},{40,-73},{32,
                -73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));

        connect(ground1.p, currentSensor1.n) annotation (Line(
            points={{40,-95},{40,-73},{32,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_B.port_a, TE_STATIC_A.port_a) annotation (Line(
            points={{-18.32,-119},{-23,-119},{-23,-104},{-18.32,-104}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_A.port_b, TE_STATIC_B.port_b) annotation (Line(
            points={{-5.6,-104},{0,-104},{0,-119},{-5.6,-119}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TEG.port_b, T_l.port) annotation (Line(
            points={{19.8125,11.5773},{56.4841,11.5773},{56.4841,12},{67,12}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TEG.port_a, T_h.port) annotation (Line(
            points={{-21.8125,11.5773},{-39.4841,11.5773},{-39.4841,12},{-62,12}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));

        connect(T_h.port, TE_STATIC_B.port_a) annotation (Line(
            points={{-62,12},{-51,12},{-51,-119},{-18.32,-119}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_B.port_b, T_l.port) annotation (Line(
            points={{-5.6,-119},{57,-119},{57,12},{67,12}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(currentSensor.n, ground.p) annotation (Line(
            points={{30,58},{45,58},{45,-2},{40,-2}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(currentSensor.n, TEG.n) annotation (Line(
            points={{30,58},{45,58},{45,38},{-21.7,38},{-21.7,28.6364}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));

        annotation (
          Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),       Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-150},{100,100}},
              grid={1,1}), graphics),
          experiment(Algorithm="Dassl"),
          experimentSetupOutput,
          Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-150},{100,100}},
              grid={1,1})));
      end TEG_TrDP_alpha_Int_compared_with_TEG_StAP_otherTempRange;

      model TEG_TrDP_alpha_Int_compared_with_TEG_StAP_ShortCircuit
        "'TrDP_alpha_Int Model' compared with 'StAP Model' in el. short circuit (cf. Fig. 8 of paper referenced in 'Documentation' of this model)"

        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends Modelica.Icons.Example;

        Modelica.Thermal.HeatTransfer.Sources.FixedTemperature T_h(T(displayUnit=
                "K") = 500)
          annotation (Placement(transformation(extent={{-84,22},{-64,2}})));
        Modelica.Thermal.HeatTransfer.Sources.FixedTemperature T_l(T(displayUnit=
                "K") = 300) annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=180,
              origin={84,12})));
        Modelica.Electrical.Analog.Basic.Ground ground
          annotation (Placement(transformation(extent={{28,-26},{52,-2}})));
        Modelica.Electrical.Analog.Sensors.CurrentSensor currentSensor
          annotation (Placement(transformation(extent={{9,46},{33,70}})));
        Inner_TEG.CTEL_1D_dyn_seq_intalpha
                                         TEG(
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_p_Thermonamic
            Material_A,
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_n_Thermonamic
            Material_B,
          T_0(displayUnit="K") = 300,
          S=10,
          A=0.0014*0.0014,
          L=0.0008,
          N_TE=199)
          annotation (Placement(transformation(extent={{-28,-18},{26,36}})));

        Modelica.Electrical.Analog.Sensors.CurrentSensor currentSensor1
          annotation (Placement(transformation(extent={{8,-85},{32,-61}})));
        Inner_TEG.Components_for_TEL.ThermoelectricElement_STATIC
                                               TE_STATIC_A(
          Type="p-type",
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_p_Thermonamic
            Material,
          A=TEG.A,
          L=TEG.L,
          T_0=TEG.T_0,
          ThomsonEffect=true,
          N_TE=TEG.N_TE)
          annotation (Placement(transformation(extent={{-20,-108},{-4,-92}})));
        Inner_TEG.Components_for_TEL.ThermoelectricElement_STATIC
                                               TE_STATIC_B(
          Type="n-type",
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_n_Thermonamic
            Material,
          A=TEG.A,
          L=TEG.L,
          T_0=TEG.T_0,
          ThomsonEffect=true,
          N_TE=TEG.N_TE)
          annotation (Placement(transformation(extent={{-20,-123},{-4,-107}})));
        Modelica.Electrical.Analog.Basic.Ground ground1
          annotation (Placement(transformation(extent={{28,-119},{52,-95}})));
      equation
        connect(TE_STATIC_A.n, TE_STATIC_B.n) annotation (Line(
            points={{-5.6,-96},{1,-96},{1,-111},{-5.6,-111}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_A.p, currentSensor1.n) annotation (Line(
            points={{-18.32,-96.16},{-29,-96.16},{-29,-88},{40,-88},{40,-73},{32,
                -73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));

        connect(ground1.p, currentSensor1.n) annotation (Line(
            points={{40,-95},{40,-73},{32,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_B.port_a, TE_STATIC_A.port_a) annotation (Line(
            points={{-18.32,-119},{-23,-119},{-23,-104},{-18.32,-104}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_A.port_b, TE_STATIC_B.port_b) annotation (Line(
            points={{-5.6,-104},{0,-104},{0,-119},{-5.6,-119}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TEG.port_b, T_l.port) annotation (Line(
            points={{19.8125,11.5773},{54.4841,11.5773},{54.4841,12},{74,12}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TEG.port_a, T_h.port) annotation (Line(
            points={{-21.8125,11.5773},{-39.4841,11.5773},{-39.4841,12},{-64,12}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));

        connect(T_h.port, TE_STATIC_B.port_a) annotation (Line(
            points={{-64,12},{-55,12},{-55,-119},{-18.32,-119}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_B.port_b, T_l.port) annotation (Line(
            points={{-5.6,-119},{55,-119},{55,12},{74,12}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));

        connect(ground.p, TEG.n) annotation (Line(
            points={{40,-2},{40,39},{-29,39},{-29,28.6364},{-21.7,28.6364}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(currentSensor.n, ground.p) annotation (Line(
            points={{33,58},{40,58},{40,-2}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(currentSensor.p, TEG.p) annotation (Line(
            points={{9,58},{-43,58},{-43,-5.97273},{-21.7,-5.97273}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_B.p, currentSensor1.p) annotation (Line(
            points={{-18.32,-111.16},{-42,-111.16},{-42,-73},{8,-73}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        annotation (
          Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),       Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-150},{100,100}},
              grid={1,1}), graphics),
          experiment(Algorithm="Dassl"),
          experimentSetupOutput,
          Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-150},{100,100}},
              grid={1,1})));
      end TEG_TrDP_alpha_Int_compared_with_TEG_StAP_ShortCircuit;

      model TEG_TrDP_alpha_Int_TEG_StAP_compared_with_measurement
        "Adapted 'TrDP_alpha_Int Model' compared with adapted 'StAP Model' for real measurements [see Examples.IEEE_Examples.Components.measurement_table] (cf. Fig. 11 of paper referenced in 'Documentation' of this model)"

        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends Modelica.Icons.Example;

        Real Power=voltageSensor_TrDP_Int.v*currentSensor.i
          "Electric power in 'Load_resisitor'";

        Real Power_STATIC=voltageSensor_StAP.v*currentSensor1.i
          "Electric power in 'Load_resisitor1' (STATIC MODEL)";

        Real PowerError(unit="%") = if abs(Power) > 0 then 100*(Power_STATIC -
          Power)/Power else 0;

        // PARAMETERS
        parameter Modelica.SIunits.Resistance R=2.502 + 0.198
          "Load resistance (internal plus output resistance soldered between the contacts)";
        parameter Real lambda_Cer=15 "heat conductance ceramic";
        parameter Real lambda_WLP=10 "heat conductance heat transfer paste";
        parameter Real d_Cer=0.0008 "thickness ceramic";
        parameter Real d_WLP=0.0001 "thickness heat transfer paste";
        parameter Real c_Cer=850 "capacity ceramic";
        parameter Real rho_Cer=3800 "density ceramic";
        parameter Real lambda_air=0.0261 "heat conductance air gap";
        parameter Real d_air=0.00002 "thickness air gap";
        parameter Real d_Cu=0.000475 "thickness copper plate";
        parameter Real lambda_Cu=400 "heat conductance copper plate";
        parameter Real c_Cu=385 "capacity copper plate";
        parameter Real rho_Cu=8920 "density copper plate";

        Modelica.Electrical.Analog.Basic.Ground ground
          annotation (Placement(transformation(extent={{35,-30},{59,-6}})));
        Modelica.Electrical.Analog.Basic.Resistor Load_resistor(R=R)
          annotation (Placement(transformation(extent={{-24,41},{4,69}})));
        Modelica.Electrical.Analog.Sensors.VoltageSensor voltageSensor_TrDP_Int
          annotation (Placement(transformation(extent={{-22,69},{2,93}})));
        Modelica.Electrical.Analog.Sensors.CurrentSensor currentSensor
          annotation (Placement(transformation(extent={{18,43},{42,67}})));
        Inner_TEG.CTEL_1D_dyn_seq_intalpha
                                         TEG(
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_p_Thermonamic
            Material_A,
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_n_Thermonamic
            Material_B,
          L=0.0008,
          T_0(displayUnit="K") = 299.15,
          Mode="TEG",
          S=10,
          A=0.0014*0.0014,
          N_TE=199)
          annotation (Placement(transformation(extent={{-17,-19},{37,35}})));

        Modelica.Electrical.Analog.Basic.Resistor Load_resistor1(R=R)
          annotation (Placement(transformation(extent={{-15,-91},{13,-63}})));
        Modelica.Electrical.Analog.Sensors.VoltageSensor voltageSensor_StAP
          annotation (Placement(transformation(extent={{-20,-63},{4,-39}})));
        Modelica.Electrical.Analog.Sensors.CurrentSensor currentSensor1
          annotation (Placement(transformation(extent={{20,-89},{44,-65}})));
        Inner_TEG.Components_for_TEL.ThermoelectricElement_STATIC
                                               TE_STATIC_A(
          Type="p-type",
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_p_Thermonamic
            Material,
          A=TEG.A,
          L=TEG.L,
          T_0=TEG.T_0,
          ThomsonEffect=true,
          N_TE=TEG.N_TE)
          annotation (Placement(transformation(extent={{-8,-109},{8,-93}})));
        Inner_TEG.Components_for_TEL.ThermoelectricElement_STATIC
                                               TE_STATIC_B(
          Type="n-type",
          redeclare
            ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_n_Thermonamic
            Material,
          A=TEG.A,
          L=TEG.L,
          T_0=TEG.T_0,
          ThomsonEffect=true,
          N_TE=TEG.N_TE)
          annotation (Placement(transformation(extent={{-8,-124},{8,-108}})));
        Modelica.Electrical.Analog.Basic.Ground ground1
          annotation (Placement(transformation(extent={{40,-118},{64,-94}})));
        Modelica.Thermal.HeatTransfer.Sources.FixedTemperature T_h1(T(displayUnit=
               "K") = 473.15)
          annotation (Placement(transformation(extent={{-135,20},{-115,0}})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Air_Gap(G=2*TEG.N_TE
              *TEG.A*lambda_air/d_air)
          annotation (Placement(transformation(extent={{-109,5},{-99,15}})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor HTP(G=2*TEG.N_TE
              *TEG.A*lambda_WLP/d_WLP)
          annotation (Placement(transformation(extent={{-95,5},{-85,15}})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Ceramic_1_1(G=2*TEG.N_TE
              *TEG.A*lambda_Cer/(d_Cer/2))       annotation (Placement(
              transformation(
              extent={{-5,-5},{5,5}},
              rotation=90,
              origin={-70,-5})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Ceramic_1_2(G=2*TEG.N_TE
              *TEG.A*lambda_Cer/(d_Cer/2))       annotation (Placement(
              transformation(
              extent={{-5,-5},{5,5}},
              rotation=90,
              origin={-70,25})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Copper_1_1(G=2*TEG.N_TE
              *TEG.A*lambda_Cu/(d_Cu/2))      annotation (Placement(
              transformation(
              extent={{-5,-5},{5,5}},
              rotation=90,
              origin={-44,-5})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Copper_1_2(G=2*TEG.N_TE
              *TEG.A*lambda_Cu/(d_Cu/2))      annotation (Placement(
              transformation(
              extent={{-5,-5},{5,5}},
              rotation=90,
              origin={-44,25})));
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor
          heatCapacitor_Ceramic_1(T(start=TEG.T_0), C=3*d_Cer*TEG.N_TE*TEG.A*
              rho_Cer*c_Cer)
                      annotation (Placement(transformation(
              extent={{-5,-5},{5,5}},
              rotation=270,
              origin={-62,10})));
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor
          heatCapacitor_Copper_1(T(start=TEG.T_0), C=3*d_Cu*TEG.N_TE*TEG.A*
              rho_Cu*c_Cu)
                    annotation (Placement(transformation(
              extent={{-5,-5},{5,5}},
              rotation=270,
              origin={-36,10})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Air_Gap1(G=2*TEG.N_TE
              *TEG.A*lambda_air/d_air)      annotation (Placement(transformation(
                extent={{-120,-125},{-110,-115}})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor HTP1(G=2*TEG.N_TE
              *TEG.A*lambda_WLP/d_WLP)
          annotation (Placement(transformation(extent={{-105,-125},{-95,-115}})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Ceramic_1_3(G=2*TEG.N_TE
              *TEG.A*lambda_Cer/(d_Cer/2))       annotation (Placement(
              transformation(
              extent={{-5,-5},{5,5}},
              rotation=90,
              origin={-70,-135})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Ceramic_1_4(G=2*TEG.N_TE
              *TEG.A*lambda_Cer/(d_Cer/2))       annotation (Placement(
              transformation(
              extent={{-5,-5},{5,5}},
              rotation=90,
              origin={-70,-106})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Copper_1_3(G=2*TEG.N_TE
              *TEG.A*lambda_Cu/(d_Cu/2))      annotation (Placement(
              transformation(
              extent={{-5,-5},{5,5}},
              rotation=90,
              origin={-45,-135})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Copper_1_4(G=2*TEG.N_TE
              *TEG.A*lambda_Cu/(d_Cu/2))      annotation (Placement(
              transformation(
              extent={{-5,-5},{5,5}},
              rotation=90,
              origin={-45,-105})));
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor
          heatCapacitor_Ceramic_3(                                     T(start=
                TEG.T_0), C=3*d_Cer*TEG.N_TE*TEG.A*rho_Cer*c_Cer)
                          annotation (Placement(transformation(
              extent={{-5,-5},{5,5}},
              rotation=270,
              origin={-62,-120})));
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor
          heatCapacitor_Copper_3(T(start=TEG.T_0), C=3*d_Cu*TEG.N_TE*TEG.A*
              rho_Cu*c_Cu)
                    annotation (Placement(transformation(
              extent={{-5,-5},{5,5}},
              rotation=270,
              origin={-37,-120})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Copper_2_1(G=2*TEG.N_TE
              *TEG.A*lambda_Cu/(d_Cu/2))      annotation (Placement(
              transformation(
              extent={{-5,-5},{5,5}},
              rotation=90,
              origin={64,-5})));
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor
          heatCapacitor_Copper_2(T(start=TEG.T_0), C=3*d_Cu*TEG.N_TE*TEG.A*
              rho_Cu*c_Cu)
                    annotation (Placement(transformation(
              extent={{-5,-5},{5,5}},
              rotation=270,
              origin={73,10})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Copper_2_2(G=2*TEG.N_TE
              *TEG.A*lambda_Cu/(d_Cu/2))      annotation (Placement(
              transformation(
              extent={{-5,-5},{5,5}},
              rotation=90,
              origin={64,25})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Ceramic_2_1(G=2*TEG.N_TE
              *TEG.A*lambda_Cer/(d_Cer/2))       annotation (Placement(
              transformation(
              extent={{-5,-5},{5,5}},
              rotation=90,
              origin={90,-5})));
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor
          heatCapacitor_Ceramic_2(                                     T(start=
                TEG.T_0), C=3*d_Cer*TEG.N_TE*TEG.A*rho_Cer*c_Cer)
                          annotation (Placement(transformation(
              extent={{-5,-5},{5,5}},
              rotation=270,
              origin={99,10})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Ceramic_2_2(G=2*TEG.N_TE
              *TEG.A*lambda_Cer/(d_Cer/2))       annotation (Placement(
              transformation(
              extent={{-5,-5},{5,5}},
              rotation=90,
              origin={90,25})));
        ThermoelectricGenerator_V5_7.Examples.IEEE_Examples.Components.Heat_transfer
          thermal_radiation(
          T1=TEG.T_0,
          d=d_Cer,
          lambda=lambda_Cer)
          annotation (Placement(transformation(extent={{116,0},{136,21}})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Copper_2_3(G=2*TEG.N_TE
              *TEG.A*lambda_Cu/(d_Cu/2))      annotation (Placement(
              transformation(
              extent={{-5,-5},{5,5}},
              rotation=90,
              origin={68,-135})));
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor
          heatCapacitor_Copper_4(T(start=TEG.T_0), C=3*d_Cu*TEG.N_TE*TEG.A*
              rho_Cu*c_Cu)
                    annotation (Placement(transformation(
              extent={{-5,-5},{5,5}},
              rotation=270,
              origin={75,-120})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Copper_2_4(G=2*TEG.N_TE
              *TEG.A*lambda_Cu/(d_Cu/2))      annotation (Placement(
              transformation(
              extent={{-5,-5},{5,5}},
              rotation=90,
              origin={68,-105})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Ceramic_2_3(G=2*TEG.N_TE
              *TEG.A*lambda_Cer/(d_Cer/2))       annotation (Placement(
              transformation(
              extent={{-5,-5},{5,5}},
              rotation=90,
              origin={93,-135})));
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor
          heatCapacitor_Ceramic_4(                                     T(start=
                TEG.T_0), C=3*d_Cer*TEG.N_TE*TEG.A*rho_Cer*c_Cer)
                          annotation (Placement(transformation(
              extent={{-5,-5},{5,5}},
              rotation=270,
              origin={101,-120})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor Ceramic_2_4(G=2*TEG.N_TE
              *TEG.A*lambda_Cer/(d_Cer/2))       annotation (Placement(
              transformation(
              extent={{-5,-5},{5,5}},
              rotation=90,
              origin={93,-105})));
        ThermoelectricGenerator_V5_7.Examples.IEEE_Examples.Components.Heat_transfer
          thermal_radiation1(
          T1=TEG.T_0,
          d=d_Cer,
          lambda=lambda_Cer) annotation (Placement(transformation(extent={{114,
                  -130},{134,-109}})));
      equation
        connect(voltageSensor_TrDP_Int.p, Load_resistor.p) annotation (Line(
            points={{-22,81},{-30,81},{-30,55},{-24,55}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(voltageSensor_TrDP_Int.n, Load_resistor.n) annotation (Line(
            points={{2,81},{10,81},{10,55},{4,55}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(currentSensor.p, Load_resistor.n) annotation (Line(
            points={{18,55},{4,55}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(currentSensor.n, ground.p) annotation (Line(
            points={{42,55},{47,55},{47,-6}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TEG.p, Load_resistor.p) annotation (Line(
            points={{-10.7,-6.97273},{-30,-6.97273},{-30,55},{-24,55}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TEG.n, ground.p) annotation (Line(
            points={{-10.7,27.6364},{-22,27.6364},{-22,38},{47,38},{47,-6}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(voltageSensor_StAP.p, Load_resistor1.p) annotation (Line(
            points={{-20,-51},{-28,-51},{-28,-77},{-15,-77}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(voltageSensor_StAP.n, Load_resistor1.n) annotation (Line(
            points={{4,-51},{17,-51},{17,-77},{13,-77}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(currentSensor1.p, Load_resistor1.n) annotation (Line(
            points={{20,-77},{13,-77}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_A.n, TE_STATIC_B.n) annotation (Line(
            points={{6.4,-97},{13,-97},{13,-112},{6.4,-112}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_B.p, Load_resistor1.p) annotation (Line(
            points={{-6.32,-112.16},{-28,-112.16},{-28,-77},{-15,-77}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_A.p, currentSensor1.n) annotation (Line(
            points={{-6.32,-97.16},{-17,-97.16},{-17,-92},{52,-92},{52,-77},{44,-77}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));

        connect(ground1.p, currentSensor1.n) annotation (Line(
            points={{52,-94},{52,-77},{44,-77}},
            color={0,0,255},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_B.port_a, TE_STATIC_A.port_a) annotation (Line(
            points={{-6.32,-120},{-11,-120},{-11,-105},{-6.32,-105}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(TE_STATIC_A.port_b, TE_STATIC_B.port_b) annotation (Line(
            points={{6.4,-105},{12,-105},{12,-120},{6.4,-120}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(T_h1.port, Air_Gap.port_a) annotation (Line(
            points={{-115,10},{-109,10}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(Air_Gap.port_b, HTP.port_a) annotation (Line(
            points={{-99,10},{-95,10}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(Air_Gap1.port_b, HTP1.port_a) annotation (Line(
            points={{-110,-120},{-105,-120}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(Copper_1_4.port_b, TE_STATIC_B.port_a) annotation (Line(
            points={{-45,-100},{-31,-100},{-31,-120},{-6.32,-120}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(T_h1.port, Air_Gap1.port_a) annotation (Line(
            points={{-115,10},{-112,10},{-112,-96},{-126,-96},{-126,-120},{-120,-120}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));

        connect(TE_STATIC_B.port_b, Copper_2_3.port_a) annotation (Line(
            points={{6.4,-120},{60,-120},{60,-144},{68,-144},{68,-140}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));

        connect(HTP.port_b, Ceramic_1_1.port_a) annotation (Line(
            points={{-85,10},{-77,10},{-77,-13},{-70,-13},{-70,-10}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(Ceramic_1_1.port_b, Ceramic_1_2.port_a) annotation (Line(
            points={{-70,0},{-70,20}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(heatCapacitor_Ceramic_1.port, Ceramic_1_1.port_b) annotation (
            Line(
            points={{-67,10},{-70,10},{-70,0}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Ceramic_1_2.port_b, Copper_1_1.port_a) annotation (Line(
            points={{-70,30},{-70,33},{-56,33},{-56,10},{-52,10},{-52,-13},{-44,-13},
                {-44,-10}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Copper_1_1.port_b, Copper_1_2.port_a) annotation (Line(
            points={{-44,0},{-44,20}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(heatCapacitor_Copper_1.port, Copper_1_1.port_b) annotation (Line(
            points={{-41,10},{-44,10},{-44,0}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Copper_1_2.port_b, TEG.port_a) annotation (Line(
            points={{-44,30},{-44,32},{-26,32},{-26,10.5773},{-10.8125,10.5773}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Ceramic_2_1.port_b, Ceramic_2_2.port_a) annotation (Line(
            points={{90,0},{90,20}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(heatCapacitor_Ceramic_2.port, Ceramic_2_1.port_b) annotation (
            Line(
            points={{94,10},{90,10},{90,0}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Copper_2_1.port_a, TEG.port_b) annotation (Line(
            points={{64,-10},{64,-13},{56,-13},{56,10.5773},{30.8125,10.5773}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Copper_2_1.port_b, Copper_2_2.port_a) annotation (Line(
            points={{64,0},{64,20}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(heatCapacitor_Copper_2.port, Copper_2_1.port_b) annotation (Line(
            points={{68,10},{64,10},{64,0}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Copper_2_2.port_b, Ceramic_2_1.port_a) annotation (Line(
            points={{64,30},{64,33},{79,33},{79,10},{83,10},{83,-13},{90,-13},{90,
                -10}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));

        connect(Ceramic_2_2.port_b, thermal_radiation.port_a) annotation (Line(
            points={{90,30},{90,33},{105,33},{105,10.5},{116.2,10.5}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(HTP1.port_b, Ceramic_1_3.port_a) annotation (Line(
            points={{-95,-120},{-78,-120},{-78,-144},{-70,-144},{-70,-140}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Ceramic_1_3.port_b, Ceramic_1_4.port_a) annotation (Line(
            points={{-70,-130},{-70,-111}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(heatCapacitor_Ceramic_3.port, Ceramic_1_3.port_b) annotation (
            Line(
            points={{-67,-120},{-70,-120},{-70,-130}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Ceramic_1_4.port_b, Copper_1_3.port_a) annotation (Line(
            points={{-70,-101},{-70,-98},{-56,-98},{-56,-120},{-51,-120},{-51,-144},
                {-45,-144},{-45,-140}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Copper_1_3.port_b, Copper_1_4.port_a) annotation (Line(
            points={{-45,-130},{-45,-110}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(heatCapacitor_Copper_3.port, Copper_1_3.port_b) annotation (Line(
            points={{-42,-120},{-45,-120},{-45,-130}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Copper_2_3.port_b, Copper_2_4.port_a) annotation (Line(
            points={{68,-130},{68,-110}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(heatCapacitor_Copper_4.port, Copper_2_3.port_b) annotation (Line(
            points={{70,-120},{68,-120},{68,-130}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Copper_2_4.port_b, Ceramic_2_3.port_a) annotation (Line(
            points={{68,-100},{68,-98},{80,-98},{80,-120},{86,-120},{86,-145},{93,
                -145},{93,-140}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Ceramic_2_3.port_b, Ceramic_2_4.port_a) annotation (Line(
            points={{93,-130},{93,-110}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(heatCapacitor_Ceramic_4.port, Ceramic_2_3.port_b) annotation (
            Line(
            points={{96,-120},{93,-120},{93,-130}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(Ceramic_2_4.port_b, thermal_radiation1.port_a) annotation (Line(
            points={{93,-100},{93,-98},{108,-98},{108,-119.5},{114.2,-119.5}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        annotation (
          Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"),       Diagram(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-150,-150},{150,110}},
              grid={1,1}), graphics={Rectangle(
                    extent={{-80,-30},{-54,50}},
                    lineColor={215,215,215},
                    lineThickness=0.5,
                    fillPattern=FillPattern.Forward,
                    fillColor={215,215,215}),Rectangle(
                    extent={{55,-30},{81,50}},
                    lineColor={255,170,85},
                    lineThickness=0.5,
                    fillColor={255,170,85},
                    fillPattern=FillPattern.Forward),Rectangle(
                    extent={{81,-30},{107,50}},
                    lineColor={215,215,215},
                    lineThickness=0.5,
                    fillPattern=FillPattern.Forward,
                    fillColor={215,215,215}),Rectangle(
                    extent={{-80,-150},{-54,-90}},
                    lineColor={215,215,215},
                    lineThickness=0.5,
                    fillPattern=FillPattern.Forward,
                    fillColor={215,215,215}),Rectangle(
                    extent={{-54,-150},{-28,-90}},
                    lineColor={255,170,85},
                    lineThickness=0.5,
                    fillColor={255,170,85},
                    fillPattern=FillPattern.Forward),Rectangle(
                    extent={{58,-150},{84,-90}},
                    lineColor={255,170,85},
                    lineThickness=0.5,
                    fillColor={255,170,85},
                    fillPattern=FillPattern.Forward),Rectangle(
                    extent={{84,-150},{110,-90}},
                    lineColor={215,215,215},
                    lineThickness=0.5,
                    fillPattern=FillPattern.Forward,
                    fillColor={215,215,215}),Rectangle(
                    extent={{-54,-30},{-28,50}},
                    lineColor={255,170,85},
                    lineThickness=0.5,
                    fillColor={255,170,85},
                    fillPattern=FillPattern.Forward)}),
          experiment(StopTime=35),
          experimentSetupOutput,
          Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-150,-150},{150,110}},
              grid={1,1})));
      end TEG_TrDP_alpha_Int_TEG_StAP_compared_with_measurement;

      package Components

        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

        model Heat_transfer "Heat transfer from surface to environment"

          //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

          Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a annotation (
              Placement(transformation(extent={{-108,-10},{-88,10}}),
                iconTransformation(extent={{-108,-10},{-88,10}})));

          parameter Modelica.SIunits.Area A=0.04*0.04 "area";
          parameter Modelica.SIunits.Temp_K T1=300 "ambient temperature";
          parameter Real R_SE=0.04;
          // value from DIN EN ISO 6946, table 1
          parameter Real R_SI=0.10;
          // value from DIN EN ISO 6946, table 1
          parameter Real d=0.001 "thickness";
          parameter Real lambda=15 "heat conductance";

          Modelica.SIunits.HeatFlowRate Q_flow;
          Real k;
          Modelica.SIunits.Temp_K T2;

        equation
          port_a.Q_flow = Q_flow;
          port_a.T = T2;

          k = 1/(R_SE + (d/lambda) + R_SI);
          //equation from "Wrmebertragung - Grundlagen und Praxis", Peter von Bckh and Thomas Wetzel, Springer, page 22, equation 2.15 and DIN EN ISO 6946

          Q_flow = k*A*(T2 - T1);
          //equation from "Wrmebertragung - Grundlagen und Praxis", Peter von Bckh and Thomas Wetzel, Springer, page 8, equation 1.14

          annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"),       Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,
                    100}}), graphics={Rectangle(
                        extent={{-100,100},{-40,-100}},
                        lineColor={0,0,0},
                        fillColor={175,175,175},
                        fillPattern=FillPattern.Solid),Line(
                        points={{-40,70},{-20,80},{0,60},{20,80},{40,60},{60,80},
                    {74,68},{94,68}},
                        color={255,0,0},
                        smooth=Smooth.Bezier),Line(
                        points={{94,68},{80,60}},
                        color={255,0,0},
                        smooth=Smooth.None),Line(
                        points={{7,-10},{-7,-4}},
                        color={255,0,0},
                        smooth=Smooth.None,
                        origin={87,78},
                        rotation=360),Line(
                        points={{-40,28},{-20,38},{0,18},{20,38},{40,18},{60,38},
                    {74,26},{94,26}},
                        color={255,0,0},
                        smooth=Smooth.Bezier),Line(
                        points={{94,26},{80,18}},
                        color={255,0,0},
                        smooth=Smooth.None),Line(
                        points={{7,-10},{-7,-4}},
                        color={255,0,0},
                        smooth=Smooth.None,
                        origin={87,36},
                        rotation=360),Line(
                        points={{-40,-12},{-20,-2},{0,-22},{20,-2},{40,-22},{60,-2},
                    {74,-14},{94,-14}},
                        color={255,0,0},
                        smooth=Smooth.Bezier),Line(
                        points={{94,-14},{80,-22}},
                        color={255,0,0},
                        smooth=Smooth.None),Line(
                        points={{7,-10},{-7,-4}},
                        color={255,0,0},
                        smooth=Smooth.None,
                        origin={87,-4},
                        rotation=360),Line(
                        points={{-40,-54},{-20,-44},{0,-64},{20,-44},{40,-64},{60,
                    -44},{74,-56},{94,-56}},
                        color={255,0,0},
                        smooth=Smooth.Bezier),Line(
                        points={{94,-56},{80,-64}},
                        color={255,0,0},
                        smooth=Smooth.None),Line(
                        points={{7,-10},{-7,-4}},
                        color={255,0,0},
                        smooth=Smooth.None,
                        origin={87,-46},
                        rotation=360)}));
        end Heat_transfer;

        model measurement_table
          "Arithmetic average of three series of measurements (cf. Fig. 11 of paper referenced in 'Documentation' of this model)"

          //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

          Modelica.Blocks.Sources.TimeTable measurement(table=[0, 0.02278633;
                0.22, 0.12207; 0.44, 0.23763; 0.66, 0.455729; 0.88, 0.738932333;
                1.1, 0.968424667; 1.32, 1.153971; 1.54, 1.280924667; 1.76,
                1.380208333; 1.98, 1.448567667; 2.2, 1.495768; 2.42, 1.520182333;
                2.64, 1.531575667; 2.86, 1.526692667; 3.08, 1.518554333; 3.3,
                1.510416667; 3.52, 1.489258; 3.74, 1.468099333; 3.96, 1.427408667;
                4.18, 1.40625; 4.4, 1.376953; 4.62, 1.346028667; 4.84,
                1.324869667; 5.06, 1.293945333; 5.28, 1.264648333; 5.5,
                1.241861667; 5.72, 1.214192667; 5.94, 1.191406333; 6.16,
                1.157226333; 6.38, 1.131184667; 6.6, 1.106770667; 6.82,
                1.079101333; 7.04, 1.054687667; 7.7, 0.984700333; 8.36,
                0.914713667; 9.02, 0.849609; 9.68, 0.794271; 10.34, 0.735677; 11,
                0.686849; 11.66, 0.641276; 12.32, 0.597331; 12.98, 0.558268;
                13.64, 0.522461; 14.3, 0.485026; 14.96, 0.452474; 15.62,
                0.424804667; 16.28, 0.398763; 16.94, 0.367838333; 17.6, 0.349935;
                18.26, 0.330403667; 18.92, 0.312499667; 19.58, 0.294596333; 20.24,
                0.279948; 20.9, 0.268554667; 21.56, 0.255533667; 22.22,
                0.242513333; 22.88, 0.231119667; 23.54, 0.222981333; 24.2,
                0.216471667; 24.86, 0.205078; 25.52, 0.200195333; 26.18,
                0.198567667; 26.84, 0.192057333; 27.5, 0.188802; 28.16,
                0.185546667; 28.82, 0.177408667; 29.92, 0.169270667; 31.02,
                0.157877667; 32.12, 0.146484667; 33.22, 0.096028667; 34.32,
                0.094401; 35.42, 0.089518333; 36.52, 0.084635333; 37.62,
                0.084635333; 38.72, 0.078125; 39.82, 0.071614333; 40.04,
                0.076497333; 41.14, 0.058594; 42.24, 0.039062667; 43.12,
                0.035807333])
            annotation (Placement(transformation(extent={{-39,-1},{-19,19}})));

          Real load_resistance=2.7;
          //see: TEG_Examples.TEG_TrDP_alpha_Int_TEG_StAP_compared_with_measurement
          Real Power_measuerment=(measurement.y*measurement.y)/load_resistance;

          annotation (
            Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),         experiment(StopTime=35),
            experimentSetupOutput);
        end measurement_table;
      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));
      end Components;
      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));
    end IEEE_Examples;

    package ECT_Examples
      "Examples from paper: M. Nesarajah, L. Exel, and G. Frey, ''Modelica Library for Dynamic Simulation of Thermoelectric Generators'', Proceedings of the 11th European Conference on Thermoelectrics, Noordwijk, The Netherlands, Paper ID 2952254, 2013"

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

    extends Modelica.Icons.ExamplesPackage;

      model HeatingSystem_mppt
        "TEG connected with a simple model of a heating system, based on Modelica.Fluid.Examples.HeatingSystem"

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

        extends Modelica.Icons.Example;
         replaceable package Medium =
            Modelica.Media.Water.StandardWater
           constrainedby Modelica.Media.Interfaces.PartialMedium;

        Modelica.Fluid.Vessels.OpenTank tank(
          redeclare package Medium = Medium,
          crossArea=0.01,
          height=2,
          level_start=1,
          nPorts=2,
          massDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial,
          use_HeatTransfer=true,
          portsData={Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=
              0.01),Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=
              0.01)},
          redeclare model HeatTransfer =
              Modelica.Fluid.Vessels.BaseClasses.HeatTransfer.IdealHeatTransfer
              (                                                                  k=10),
          ports(each p(start=1e5)),
          s(each start=1))
                    annotation (Placement(transformation(extent={{-46,36},{-30,
                  52}},
                rotation=0)));
        Modelica.Fluid.Machines.ControlledPump pump(
          redeclare package Medium = Medium,
          N_nominal=1500,
          use_T_start=true,
          T_start=Modelica.SIunits.Conversions.from_degC(40),
          m_flow_start=0.01,
          m_flow_nominal=0.01,
          control_m_flow=false,
          allowFlowReversal=false,
          p_a_start=110000,
          p_b_start=130000,
          p_a_nominal=110000,
          p_b_nominal=130000)
          annotation (Placement(transformation(extent={{-24,26},{-8,42}},  rotation=
                 0)));
        Modelica.Thermal.HeatTransfer.Sources.FixedTemperature T_ambient(T=system.T_ambient)
          annotation (Placement(transformation(extent={{-70,19},{-56,33}}, rotation=
                 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor wall(G=1.6e3/20)
          annotation (Placement(transformation(
              origin={-9,3},
              extent={{5,-5},{-5,5}},
              rotation=270)));
        inner Modelica.Fluid.System system(
            m_flow_small=1e-4,
          T_ambient(displayUnit="degC") = 293.15,
          energyDynamics=Modelica.Fluid.Types.Dynamics.SteadyStateInitial,
          momentumDynamics=Modelica.Fluid.Types.Dynamics.SteadyState,
          allowFlowReversal=true)
                              annotation (Placement(transformation(extent={{-68,42},
                  {-54,56}},  rotation=0)));
        Modelica.Fluid.Pipes.DynamicPipe heater(
          redeclare package Medium = Medium,
          use_T_start=true,
          T_start=Modelica.SIunits.Conversions.from_degC(80),
          length=2,
          redeclare model HeatTransfer =
              Modelica.Fluid.Pipes.BaseClasses.HeatTransfer.IdealFlowHeatTransfer,
          diameter=0.01,
          nNodes=1,
          modelStructure=Modelica.Fluid.Types.ModelStructure.a_vb,
          redeclare model FlowModel =
              Modelica.Fluid.Pipes.BaseClasses.FlowModels.DetailedPipeFlow,
          use_HeatTransfer=true)
          annotation (Placement(transformation(extent={{16,26},{32,42}}, rotation=0)));

        Modelica.Fluid.Pipes.DynamicPipe radiator(
          use_T_start=true,
          redeclare package Medium = Medium,
          length=10,
          T_start=Modelica.SIunits.Conversions.from_degC(40),
          redeclare model HeatTransfer =
              Modelica.Fluid.Pipes.BaseClasses.HeatTransfer.IdealFlowHeatTransfer,
          diameter=0.01,
          nNodes=1,
          redeclare model FlowModel =
              Modelica.Fluid.Pipes.BaseClasses.FlowModels.DetailedPipeFlow,
          modelStructure=Modelica.Fluid.Types.ModelStructure.av_b,
          use_HeatTransfer=true)
          annotation (Placement(transformation(extent={{0,-22},{-16,-6}}, rotation=
                  0)));

      protected
        Modelica.Blocks.Interfaces.RealOutput T_forward
          annotation (Placement(transformation(extent={{66,40},{78,52}},   rotation=
                 0)));
        Modelica.Blocks.Interfaces.RealOutput T_return
          annotation (Placement(transformation(extent={{4,-4},{-4,4}},
                rotation=0,
              origin={-58,-6})));
      public
        Modelica.Fluid.Sensors.Temperature sensor_T_forward(redeclare package
            Medium =
              Medium)
          annotation (Placement(transformation(extent={{44,40},{58,52}},   rotation=
                 0)));
        Modelica.Fluid.Sensors.Temperature sensor_T_return(redeclare package
            Medium =
              Medium)
          annotation (Placement(transformation(extent={{-38,-12},{-54,2}},
                rotation=0)));
      protected
        Modelica.Blocks.Interfaces.RealOutput tankLevel
                                       annotation (Placement(transformation(extent={{-28,46},
                  {-20,54}},          rotation=0)));
      public
        Modelica.Fluid.Pipes.DynamicPipe pipe(
          redeclare package Medium = Medium,
          use_T_start=true,
          T_start=Modelica.SIunits.Conversions.from_degC(80),
          diameter=0.01,
          redeclare model FlowModel =
              Modelica.Fluid.Pipes.BaseClasses.FlowModels.DetailedPipeFlow,
          length=10,
          redeclare model HeatTransfer =
              Modelica.Fluid.Pipes.BaseClasses.HeatTransfer.IdealFlowHeatTransfer,
          nNodes=2,
          use_HeatTransfer=false)
          annotation (Placement(transformation(extent={{-8,-8},{8,8}},   rotation=-90,
              origin={72,10})));

        Modelica.Fluid.Pipes.DynamicPipe flange(
          use_T_start=true,
          redeclare package Medium = Medium,
          T_start=Modelica.SIunits.Conversions.from_degC(40),
          redeclare model FlowModel =
              Modelica.Fluid.Pipes.BaseClasses.FlowModels.DetailedPipeFlow,
          modelStructure=Modelica.Fluid.Types.ModelStructure.av_b,
          use_HeatTransfer=true,
          length=0.5,
          diameter=0.01,
          nNodes=2,
          redeclare model HeatTransfer =
              Modelica.Fluid.Pipes.BaseClasses.HeatTransfer.IdealFlowHeatTransfer)
          annotation (Placement(transformation(extent={{34,-22},{18,-6}}, rotation=
                  0)));

        TEG_Module            tEG_Module(
          N=199,
          Length=0.04,
          Breadth=0.04,
          T_CP1=0.001,
          T_CP2=0.001,
          A=0.0014*0.0014,
          L=0.001,
          redeclare ThermoelectricGenerator_V5_7.Packaging.seq_1D_with_storing
            packaging_left(S=2, redeclare
              ThermoelectricGenerator_V5_7.Packaging_Material_Data.Ceramic_Al2O3
              Material),
          redeclare ThermoelectricGenerator_V5_7.Packaging.seq_1D_with_storing
            packaging_right(S=2),
          redeclare
            ThermoelectricGenerator_V5_7.Inner_TEG.CTEL_1D_dyn_seq_intalpha_contact_res
            inner_TEG(
            Thickness_conn=0.0004,
            redeclare
              ThermoelectricGenerator_V5_7.Packaging_Material_Data.Aluminium
              Material_connector,
            redeclare
              ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_p_Thermonamic
              Material_A,
            redeclare
              ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_n_Thermonamic
              Material_B,
            redeclare
              ThermoelectricGenerator_V5_7.Inner_TEG.Components_for_leg_connection.contact_and_wire_res
              leg_conn_elec,
            S=4,
            redeclare
              ThermoelectricGenerator_V5_7.Inner_TEG.Components_for_leg_connection.res_and_storage
              leg_conn_thermal_left(redeclare
                ThermoelectricGenerator_V5_7.Packaging_Material_Data.Aluminium
                Material),
            redeclare
              ThermoelectricGenerator_V5_7.Inner_TEG.Components_for_leg_connection.res_and_storage
              leg_conn_thermal_right(redeclare
                ThermoelectricGenerator_V5_7.Packaging_Material_Data.Aluminium
                Material)),
          T_0=293.15)             annotation (Placement(transformation(
              extent={{-20.5,-19.5},{20.5,19.5}},
              rotation=180,
              origin={42.5,-65.5})));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow burner(alpha=-0.5,
            T_ref=343.15)
          annotation (Placement(transformation(extent={{-7,-7},{7,7}},
              rotation=270,
              origin={25,47})));
        Modelica.Blocks.Interaction.Show.RealValue realValue annotation (
            Placement(transformation(
              extent={{-7,-7},{7,7}},
              rotation=180,
              origin={-55,-65})));
        Modelica.Fluid.Valves.ValveIncompressible valve(
          redeclare package Medium = Medium,
          CvData=Modelica.Fluid.Types.CvTypes.OpPoint,
          m_flow_nominal=0.01,
          show_T=true,
          allowFlowReversal=false,
          dp_nominal=10000)
          annotation (Placement(transformation(extent={{64,-22},{48,-6}},rotation=0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor wall1(G=6)
          annotation (Placement(transformation(
              origin={27,5},
              extent={{5,-5},{-5,5}},
              rotation=270)));
        Modelica.Blocks.Sources.RealExpression Burner_power(y=1600)
          annotation (Placement(transformation(extent={{2,42},{18,56}})));
        Modelica.Blocks.Sources.TimeTable timeTable(offset=0, table=[0,0.05;
              3500,0.05; 3600,0.05; 7100,0.05; 7200,0.05; 10700,0.05; 10800,
              0.05; 14300,0.05; 14400,0.05; 17900,0.05; 18000,0.05; 21500,0.05;
              21600,1; 25100,1; 25200,1; 28799,1; 28950,0.05; 32300,0.05; 32400,
              0.05; 35900,0.05; 36000,0.05; 39500,0.05; 39600,0.05; 43100,0.05;
              43200,0.05; 46700,0.05; 46800,0.05; 50300,0.05; 50400,0.05; 53900,
              0.05; 54000,0.05; 57500,0.05; 57600,0.05; 61100,0.05; 61200,1;
              64700,1; 64800,1; 68300,1; 68400,1; 71900,1; 72000,1; 75500,1;
              75600,1; 79199,1; 79400,0.05; 82700,0.05; 82800,0.05])
          annotation (Placement(transformation(extent={{40,2},{50,12}})));
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C=150)
          annotation (Placement(transformation(extent={{12,-4},{18,2}})));
        Modelica.Blocks.Continuous.Integrator integrator annotation (Placement(
              transformation(extent={{-98,-58},{-88,-48}})));
        System_Components.simple_heatsink_with_heat_cap
          simple_heatsink_with_heat_cap(heatCapacitor(T(start=293.15)))
                                        annotation (Placement(transformation(
              extent={{-10,-12},{10,12}},
              rotation=180,
              origin={12,-64})));
        System_Components.MPPT_compact
                            mPPT_compact(
          Temp_ref(displayUnit="K") = 300,
          R_ref=2.05,
          alpha=1.3/300)                 annotation (Placement(transformation(
              extent={{-10,-10},{10,10}},
              rotation=270,
              origin={-20,-64})));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor TEG_HOT
          annotation (Placement(transformation(extent={{76,-114},{84,-106}})));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor TEG_COLD
          annotation (Placement(transformation(extent={{12,-116},{20,-108}})));
      equation
      tankLevel = tank.level;
        connect(sensor_T_return.port, radiator.port_b)
                                                  annotation (Line(points={{-46,-12},{
                -46,-14},{-16,-14}},color={0,127,255}));
        connect(tank.ports[2], pump.port_a) annotation (Line(
            points={{-36.4,36},{-36.4,34},{-24,34}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(sensor_T_forward.port, heater.port_b)
                                                    annotation (Line(
            points={{51,40},{51,34},{32,34}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(heater.port_b, pipe.port_a) annotation (Line(
            points={{32,34},{72,34},{72,18}},
            color={0,127,255},
            smooth=Smooth.None), Advanced(
                                InvisibleConnections =        true));
        connect(radiator.port_b, tank.ports[1]) annotation (Line(
            points={{-16,-14},{-39.6,-14},{-39.6,36}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(flange.port_b, radiator.port_a) annotation (Line(
            points={{18,-14},{0,-14}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(burner.port, heater.heatPorts[1]) annotation (Line(
            points={{25,40},{24.08,40},{24.08,37.52}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(pump.port_b, heater.port_a) annotation (Line(
            points={{-8,34},{16,34}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(sensor_T_forward.T, T_forward) annotation (Line(
            points={{55.9,46},{72,46}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(radiator.heatPorts[1], wall.port_a) annotation (Line(
            points={{-8.08,-10.48},{-8.08,-2.8},{-9,-2.8},{-9,-2}},
            color={127,0,0},
            smooth=Smooth.None));
        connect(T_return, sensor_T_return.T) annotation (Line(
            points={{-58,-6},{-58,-5},{-51.6,-5}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(flange.port_a, valve.port_b) annotation (Line(
            points={{34,-14},{48,-14}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(T_ambient.port, wall1.port_b) annotation (Line(
            points={{-56,26},{-52,26},{-52,26},{-46,26},{-46,16},{27,16},{27,10}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(Burner_power.y, burner.Q_flow) annotation (Line(
            points={{18.8,49},{20,49},{20,54},{25,54}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(timeTable.y, valve.opening) annotation (Line(
            points={{50.5,7},{56,7},{56,-7.6}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(flange.heatPorts[1], wall1.port_a) annotation (Line(
            points={{27.16,-10.48},{27.16,8.88178e-016},{27,8.88178e-016}},
            color={127,0,0},
            smooth=Smooth.None));
        connect(valve.port_a, pipe.port_b) annotation (Line(
            points={{64,-14},{72,-14},{72,2}},
            color={0,127,255},
            smooth=Smooth.None));
        connect(simple_heatsink_with_heat_cap.port_a, tEG_Module.port_b)
          annotation (Line(
            points={{22.2,-64},{24,-64},{24,-64.3529},{26.3278,-64.3529}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(simple_heatsink_with_heat_cap.port_b, T_ambient.port) annotation (
            Line(
            points={{1.8,-64},{4,-64},{4,16},{-46,16},{-46,26},{-56,26}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(realValue.numberPort, integrator.u) annotation (Line(
            points={{-46.95,-65},{-40,-65},{-40,-78},{-104,-78},{-104,-53},{-99,
                -53}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(mPPT_compact.n, tEG_Module.pin_n) annotation (Line(
            points={{-20,-74},{-20,-90},{70,-90},{70,-76.0529},{60.7222,
                -76.0529}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(tEG_Module.pin_p, mPPT_compact.p) annotation (Line(
            points={{60.7222,-52.8824},{70,-52.8824},{70,-44},{-20,-44},{-20,
                -54}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(TEG_HOT.port, tEG_Module.port_a)           annotation (Line(
            points={{76,-110},{76,-64.3529},{60.7222,-64.3529}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(tEG_Module.port_b, TEG_COLD.port)           annotation (Line(
            points={{26.3278,-64.3529},{26.3278,-112},{12,-112}},
            color={191,0,0},
            smooth=Smooth.None));
          mPPT_compact.Temp=(TEG_HOT.T-TEG_COLD.T)/2+TEG_COLD.T;

        connect(flange.heatPorts[2], tEG_Module.port_a) annotation (Line(
            points={{24.68,-10.48},{24.68,-4},{76,-4},{76,-64.3529},{60.7222,
                -64.3529}},
            color={127,0,0},
            smooth=Smooth.None));
        connect(flange.heatPorts[1], heatCapacitor.port) annotation (Line(
            points={{27.16,-10.48},{19.96,-10.48},{19.96,-4},{15,-4}},
            color={127,0,0},
            smooth=Smooth.None));
        connect(realValue.numberPort, mPPT_compact.y) annotation (Line(
            points={{-46.95,-65},{-40,-65},{-40,-64.8},{-31,-64.8}},
            color={0,0,127},
            smooth=Smooth.None));
        connect(wall.port_b, wall1.port_b) annotation (Line(
            points={{-9,8},{-10,8},{-10,16},{27,16},{27,10}},
            color={191,0,0},
            smooth=Smooth.None));
      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),       Advanced( InvisibleConnections =        true),Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                  -120},{100,60}}),
                            graphics={Text(
                extent={{-56,-60},{-32,-56}},
                lineColor={0,0,0},
                fillColor={215,215,215},
                fillPattern=FillPattern.Solid,
                textString="Power  [W]")}),
                             Icon(coordinateSystem(preserveAspectRatio=false, extent={{-120,
                  -120},{100,60}}),  graphics),
                                   Documentation(info="<html>
<p>
Simple heating system with a closed flow cycle. It is set up for steady-state initial values.
After 2000s of simulation time the valve fully opens. A simple idealized control is embedded
into the respective components, so that the heating system can be regulated with the valve:
the pump controls the pressure, the burner controls the temperature.
</p>
<p>
One can investigate the temperatures and flows for different settings of <code>system.energyDynamics</code>
(see Assumptions tab of the system object).
With <code>system.energyDynamics==Types.Dynamics.SteadyState</code> all but one dynamic states are eliminated.
The left state <code>tank.m</code> is to account for the closed flow cycle. It is constant as outflow and inflow are equal
in a steady-state simulation.
</p>
<p>
Note that a closed flow cycle generally causes circular equalities for the mass flow rates and leaves the pressure undefined.
This is why the tank.massDynamics, i.e., the tank level determining the port pressure, is modified locally to Types.Dynamics.FixedInitial.
</p>
<p>
Also note that the tank is thermally isolated againts its ambient. This way the temperature of the tank is also
well defined for zero flow rate in the heating system, e.g., for valveOpening.offset=0 at the beginning of a simulation.
The pipe however is assumed to be perfectly isolated.
If steady-state values shall be obtained with the valve fully closed, then a thermal
coupling between the pipe and its ambient should be defined as well.
</p>
<p>
Moreover it is worth noting that the idealized direct connection between the heater and the pipe, resulting in equal port pressures,
is treated as high-index DAE, as opposed to a nonlinear equation system for connected pressure loss correlations. A pressure loss correlation
could be additionally introduced to model the fitting between the heater and the pipe, e.g., to adapt different diameters.
</p>

<img src=\"modelica://Modelica/Resources/Images/Fluid/Examples/HeatingSystem.png\" border=\"1\">
</html>
"),       experiment(
            StopTime=86400,
            __Dymola_NumberOfIntervals=5000,
            __Dymola_Algorithm="Dassl"),
          __Dymola_Commands(file(ensureSimulated=true)=
              "modelica://Modelica/Resources/Scripts/Dymola/Fluid/HeatingSystem/plotResults.mos"
              "plotResults"),
          __Dymola_experimentSetupOutput);
      end HeatingSystem_mppt;
    annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));
    end ECT_Examples;

  annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));
  end Examples;

  package Inner_TEG
    "package contains more or less detailed models of CTELs (Connected Thermoelectric Legs)"

  //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

  extends Modelica.Icons.Package;
    partial model CTEL_base
      "base class for all CTEL models, which defines the connectors of the components"

    //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      parameter Modelica.SIunits.Temperature T_0=295.15
        "Initial homogeneous temperature of element";
      parameter Integer N_TE
        "if concatenation is modeled: Number of TE (of the same type) at identical temperature (el. in series, thermally in parallel)"
                                                                                                            annotation(dialog(group="Parameters of TEG-leg"));
      parameter Modelica.SIunits.Area A "Cross section area"
                                                            annotation(dialog(group="Parameters of TEG-leg"));

      parameter Modelica.SIunits.Thickness L "Thickness of thermoelement"
                                                                         annotation(dialog(group="Parameters of TEG-leg"));

      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a annotation (
          Placement(transformation(extent={{-95,-10},{-75,10}}),
            iconTransformation(extent={{-103,0},{-82,21}})));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b annotation (
          Placement(transformation(extent={{78,-10},{98,10}}),
            iconTransformation(extent={{82,0},{103,21}})));

      Modelica.Electrical.Analog.Interfaces.NegativePin n "Negative pin"
        annotation (Placement(transformation(extent={{-95,70},{-75,90}}),
            iconTransformation(extent={{-102,70},{-82,90}})));
      Modelica.Electrical.Analog.Interfaces.PositivePin p
        "Positive pin (potential p.v > n.v for positive voltage drop v)"
        annotation (Placement(transformation(extent={{-95,-88},{-75,-68}}),
            iconTransformation(extent={{-102,-71},{-82,-51}})));

      Real eta_TEG=if noEvent(abs(port_a.Q_flow) > 0) then (p.v - n.v)*n.i/port_a.Q_flow
           else 0 if Mode == "TEG" "Efficieny of TEG";
      Real COP_Cooler=if noEvent(abs((p.v - n.v)*p.i) > 0) then port_b.Q_flow/((p.v - n.v)
          *p.i) else 0 if Mode == "PELTIER COOLER"
        "Coefficient of performance of Peltier Cooler";
      Real COP_Carnot= if noEvent(abs(port_a.T - port_b.T)>0) then (port_a.T)/(port_a.T - port_b.T) else 0 if Mode ==
        "PELTIER COOLER"
        "Coefficient of performance in corresponding Carnot process";
      Real eta_Carnot=1 - (port_b.T)/(port_a.T) if Mode == "TEG";

     parameter String Mode="TEG"
        "Select operation mode ( -> Determines whether 'eta_TEG' or 'COP_Cooler' is calculated)"
        annotation (choices(choice="TEG"
            "TEG (Thermoelectric Generator)    -> calculate 'eta_TEG'", choice=
              "PELTIER COOLER" "PELTIER COOLER   -> calculate 'COP_Cooler'"),
          dialog(group=
              "Efficiency Calculation - assuming 'port_0.T' > 'port_L.T' (!)"));

      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),               Diagram(graphics));
    end CTEL_base;

    model CTEL_1D_static
      "TE device - simple static model NO transient modeling"

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends CTEL_base;

      final parameter Boolean ThomsonEffect=false "Activate Thomson Effect";

      replaceable
        ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase Material_A
        constrainedby
        ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase
        "Material of A-legs" annotation (choicesAllMatching=true, dialog(group=
              "Materials", absoluteWidth=30));

      replaceable
        ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase Material_B
        constrainedby
        ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase
        "Material of B-legs" annotation (choicesAllMatching=true, dialog(group=
              "Materials", absoluteWidth=30));

      Components_for_TEL.ThermoelectricElement_STATIC
                            thermoelectricElement(
        Material=Material_A,
        N_TE=N_TE,
        A=A,
        L=L,
        ThomsonEffect=ThomsonEffect,
        T_0=T_0)
        annotation (Placement(transformation(extent={{-10,24},{10,44}})));
      Components_for_TEL.ThermoelectricElement_STATIC
                            thermoelectricElement1(
        Material=Material_B,
        N_TE=N_TE,
        A=A,
        L=L,
        ThomsonEffect=ThomsonEffect,
        T_0=T_0)
        annotation (Placement(transformation(extent={{-8,-46},{12,-26}})));

    equation
      connect(port_a, thermoelectricElement.port_a) annotation (Line(
          points={{-85,0},{-14,0},{-14,29},{-7.9,29}},
          color={191,0,0},
          smooth=Smooth.None));
      connect(thermoelectricElement1.port_a, thermoelectricElement.port_a)
        annotation (Line(
          points={{-5.9,-41},{-14,-41},{-14,29},{-7.9,29}},
          color={191,0,0},
          smooth=Smooth.None));
      connect(thermoelectricElement1.p, p) annotation (Line(
          points={{-5.9,-31.2},{-58,-31.2},{-58,-82},{-85,-82},{-85,-78}},
          color={0,0,255},
          smooth=Smooth.None));
      connect(thermoelectricElement1.n, thermoelectricElement.n) annotation (
          Line(
          points={{10,-31},{20,-31},{20,38},{8,38},{8,39}},
          color={0,0,255},
          smooth=Smooth.None));
      connect(thermoelectricElement.p, n) annotation (Line(
          points={{-7.9,38.8},{-60,38.8},{-60,80},{-85,80}},
          color={0,0,255},
          smooth=Smooth.None));
      connect(thermoelectricElement.port_b, port_b) annotation (Line(points={{8,
              29},{16,29},{16,0},{88,0}}, color={191,0,0}));
      connect(thermoelectricElement1.port_b, port_b) annotation (Line(points={{
              10,-41},{16,-41},{16,0},{88,0}}, color={191,0,0}));
      annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{
                -100,-100},{100,100}})),
                                     Icon(graphics={Rectangle(
              extent={{-100,100},{100,-100}},
              lineColor={0,0,255},
              fillColor={135,135,135},
              fillPattern=FillPattern.Solid), Text(
              extent={{0,8},{0,-6}},
              lineColor={0,0,255},
              textString="Static")}), Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));
    end CTEL_1D_static;

    model CTEL_1D_dyn_seq
      "1D transient model: N couples (therm.: parallel, elec.: in series)"

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends CTEL_base;

      replaceable
        ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase Material_A
        constrainedby
        ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase
        "Material of A-legs" annotation (choicesAllMatching=true, dialog(group=
              "Materials", absoluteWidth=30));

      replaceable
        ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase Material_B
        constrainedby
        ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase
        "Material of B-legs" annotation (choicesAllMatching=true, dialog(group=
              "Materials", absoluteWidth=30));

     parameter Integer S=1
        "Number of 1D spatial discretization steps within legs"
        annotation (dialog(absoluteWidth=40));

      Modelica.SIunits.Resistance R=sum(Leg_A.TE[i].elecResistor.R + Leg_B.TE[i].elecResistor.R
          for i in 1:S) "Total el. resistance";

      Components_for_TEL.TE_Leg
             Leg_A(
        materialName="Material_A",
        Material=Material_A,
        T_0=T_0,
        S=S,
        A=A,
        L=L,
        N_TE=N_TE)
        annotation (Placement(transformation(extent={{-37,31},{41,109}})));
      Components_for_TEL.TE_Leg
             Leg_B(
        materialName="Material_B",
        Material=Material_B,
        T_0=T_0,
        S=S,
        A=A,
        L=L,
        N_TE=N_TE)
        annotation (Placement(transformation(extent={{-36,-61},{42,17}})));
    equation

      connect(Leg_B.port_0, port_a) annotation (Line(
          points={{-30.4425,-25.8025},{-57.2212,-25.8025},{-57.2212,0},{-85,0}},
          color={191,0,0},
          thickness=0.5,
          smooth=Smooth.None));

      connect(Leg_B.port_L, port_b) annotation (Line(
          points={{36.8325,-25.8025},{62.9163,-25.8025},{62.9163,0},{88,0}},
          color={191,0,0},
          thickness=0.5,
          smooth=Smooth.None));
      connect(Leg_A.port_0, port_a) annotation (Line(
          points={{-31.4425,66.1975},{-57,66.1975},{-57,0},{-85,0}},
          color={191,0,0},
          thickness=0.5,
          smooth=Smooth.None));
      connect(Leg_A.port_L, port_b) annotation (Line(
          points={{35.8325,66.1975},{63,66.1975},{63,0},{88,0}},
          color={191,0,0},
          thickness=0.5,
          smooth=Smooth.None));
      connect(Leg_A.n, Leg_B.n) annotation (Line(
          points={{35.8325,80.4325},{48,80.4325},{48,-11.5675},{36.8325,
              -11.5675}},
          color={0,0,255},
          thickness=0.5,
          smooth=Smooth.None));

      connect(n, Leg_A.p) annotation (Line(
          points={{-85,80},{-58.27,80},{-58.27,80.335},{-31.54,80.335}},
          color={0,0,255},
          thickness=0.5,
          smooth=Smooth.None));
      connect(p, Leg_B.p) annotation (Line(
          points={{-85,-78},{-56.77,-78},{-56.77,-11.665},{-30.54,-11.665}},
          color={0,0,255},
          thickness=0.5,
          smooth=Smooth.None));
      annotation (
        Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),     Diagram(coordinateSystem(
            preserveAspectRatio=true,
            extent={{-120,-110},{120,110}},
            grid={1,1}), graphics),
        Icon(coordinateSystem(
            preserveAspectRatio=true,
            extent={{-120,-110},{120,110}},
            grid={1,1}), graphics={
            Text(
              extent={{-100,-83},{100,-109}},
              lineColor={184,0,0},
              fillColor={0,166,0},
              fillPattern=FillPattern.Solid,
              textString="%name",
              lineThickness=0.5),
            Text(
              extent={{-101,112},{-101,88}},
              lineColor={0,0,255},
              lineThickness=0.5,
              fillPattern=FillPattern.VerticalCylinder,
              fillColor={0,0,255},
              textString="n"),
            Text(
              extent={{-100,-22},{-100,-46}},
              lineColor={0,0,255},
              lineThickness=0.5,
              fillPattern=FillPattern.VerticalCylinder,
              fillColor={0,0,255},
              textString="p"),
            Rectangle(
              extent={{-80,98},{81,-82}},
              lineColor={184,0,0},
              lineThickness=0.5,
              fillColor={245,245,245},
              fillPattern=FillPattern.Solid),
            Text(
              extent={{-101,41},{-101,25}},
              lineColor={184,0,0},
              lineThickness=0.5,
              textString="port_0"),
            Text(
              extent={{101,40},{101,24}},
              lineColor={184,0,0},
              lineThickness=0.5,
              textString="port_L"),
            Rectangle(
              extent={{-79,89},{-75,-73}},
              lineColor={135,135,135},
              fillColor={175,175,175},
              fillPattern=FillPattern.Solid),
            Rectangle(
              extent={{75,89},{79,-73}},
              lineColor={135,135,135},
              fillColor={175,175,175},
              fillPattern=FillPattern.Solid),
            Rectangle(extent={{-71,-53},{71,-73}}, lineColor={0,127,0}),
            Text(
              extent={{0,-54},{0,-72}},
              lineColor={0,127,0},
              fillColor={255,128,0},
              fillPattern=FillPattern.Solid,
              textString="Material_B"),
            Rectangle(
              extent={{-75,-11},{-71,-73}},
              lineColor={135,135,135},
              fillColor={0,0,255},
              fillPattern=FillPattern.Solid),
            Line(
              points={{-82,-63},{-72,-63},{-72,-53}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5),
            Line(
              points={{-72,69},{-72,79},{-80,79}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5),
            Rectangle(
              extent={{71,-21},{75,-73}},
              lineColor={135,135,135},
              fillColor={0,0,255},
              fillPattern=FillPattern.Solid),
            Rectangle(
              extent={{-75,89},{-71,21}},
              lineColor={135,135,135},
              fillColor={0,0,255},
              fillPattern=FillPattern.Solid),
            Rectangle(extent={{-71,-21},{71,-41}}, lineColor={255,200,2}),
            Text(
              extent={{0,-22},{0,-40}},
              lineColor={255,200,2},
              fillColor={255,128,0},
              fillPattern=FillPattern.Solid,
              textString="Material_A"),
            Text(
              extent={{0,56},{0,38}},
              lineColor={0,127,0},
              fillColor={255,128,0},
              fillPattern=FillPattern.Solid,
              textString="Material_B"),
            Rectangle(extent={{-71,57},{71,37}}, lineColor={0,127,0}),
            Rectangle(extent={{-71,89},{72,69}}, lineColor={255,200,2}),
            Text(
              extent={{0,88},{0,70}},
              lineColor={255,200,2},
              fillColor={255,128,0},
              fillPattern=FillPattern.Solid,
              textString="Material_A"),
            Rectangle(
              extent={{71,89},{75,37}},
              lineColor={135,135,135},
              fillColor={0,0,255},
              fillPattern=FillPattern.Solid),
            Text(
              extent={{0,53},{0,9}},
              lineColor={0,0,0},
              lineThickness=0.5,
              fillPattern=FillPattern.Solid,
              textString="."),
            Text(
              extent={{0,24},{0,-20}},
              lineColor={0,0,0},
              lineThickness=0.5,
              fillPattern=FillPattern.Solid,
              textString="."),
            Text(
              extent={{0,38},{0,-6}},
              lineColor={0,0,0},
              lineThickness=0.5,
              fillPattern=FillPattern.Solid,
              textString=".")}));
    end CTEL_1D_dyn_seq;

    model CTEL_1D_dyn_seq_intalpha
      "1D transient model int_alpha: N couples (therm.: parallel, elec.: in series)"

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends CTEL_base;

      parameter Integer S=2
        "Number of 1D spatial discretization steps within legs"
        annotation (dialog(absoluteWidth=40));

      replaceable
        ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase Material_A
        constrainedby
        ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase
        "Material of A-legs" annotation (choicesAllMatching=true, dialog(group=
              "Materials", absoluteWidth=30));

      replaceable
        ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase Material_B
        constrainedby
        ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase
        "Material of B-legs" annotation (choicesAllMatching=true, dialog(group=
              "Materials", absoluteWidth=30));

      Modelica.SIunits.Resistance R=sum(Leg_A.TE[i].elecResistor.R + Leg_B.TE[i].elecResistor.R
          for i in 1:S) "Total el. resistance";

      Components_for_TEL.TE_Leg_Int_alpha
                       Leg_A(
        materialName="Material_A",
        Material=Material_A,
        T_0=T_0,
        S=S,
        A=A,
        L=L,
        N_TE=N_TE)
        annotation (Placement(transformation(extent={{-37,31},{41,109}})));
      Components_for_TEL.TE_Leg_Int_alpha
                       Leg_B(
        materialName="Material_B",
        Material=Material_B,
        T_0=T_0,
        S=S,
        A=A,
        L=L,
        N_TE=N_TE)
        annotation (Placement(transformation(extent={{-36,-61},{42,17}})));
    equation

      connect(Leg_B.port_0, port_a) annotation (Line(
          points={{-30.4425,-25.8025},{-57.2212,-25.8025},{-57.2212,0},{-85,0}},
          color={191,0,0},
          thickness=0.5,
          smooth=Smooth.None));

      connect(Leg_B.port_L, port_b) annotation (Line(
          points={{36.8325,-25.8025},{62.9163,-25.8025},{62.9163,0},{88,0}},
          color={191,0,0},
          thickness=0.5,
          smooth=Smooth.None));
      connect(Leg_A.port_0, port_a) annotation (Line(
          points={{-31.4425,66.1975},{-57,66.1975},{-57,0},{-85,0}},
          color={191,0,0},
          thickness=0.5,
          smooth=Smooth.None));
      connect(Leg_A.port_L, port_b) annotation (Line(
          points={{35.8325,66.1975},{63,66.1975},{63,0},{88,0}},
          color={191,0,0},
          thickness=0.5,
          smooth=Smooth.None));
      connect(Leg_A.n, Leg_B.n) annotation (Line(
          points={{35.8325,80.4325},{48,80.4325},{48,-11.5675},{36.8325,
              -11.5675}},
          color={0,0,255},
          thickness=0.5,
          smooth=Smooth.None));

      connect(n, Leg_A.p) annotation (Line(
          points={{-85,80},{-58.27,80},{-58.27,80.335},{-31.54,80.335}},
          color={0,0,255},
          thickness=0.5,
          smooth=Smooth.None));
      connect(p, Leg_B.p) annotation (Line(
          points={{-85,-78},{-56.77,-78},{-56.77,-11.665},{-30.54,-11.665}},
          color={0,0,255},
          thickness=0.5,
          smooth=Smooth.None));
      annotation (
        Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),     Diagram(coordinateSystem(
            preserveAspectRatio=true,
            extent={{-120,-110},{120,110}},
            grid={1,1}), graphics),
        Icon(coordinateSystem(
            preserveAspectRatio=true,
            extent={{-120,-110},{120,110}},
            grid={1,1}), graphics={
            Text(
              extent={{-100,-83},{100,-109}},
              lineColor={184,0,0},
              fillColor={0,166,0},
              fillPattern=FillPattern.Solid,
              textString="%name",
              lineThickness=0.5),
            Text(
              extent={{-101,112},{-101,88}},
              lineColor={0,0,255},
              lineThickness=0.5,
              fillPattern=FillPattern.VerticalCylinder,
              fillColor={0,0,255},
              textString="n"),
            Text(
              extent={{-100,-22},{-100,-46}},
              lineColor={0,0,255},
              lineThickness=0.5,
              fillPattern=FillPattern.VerticalCylinder,
              fillColor={0,0,255},
              textString="p"),
            Rectangle(
              extent={{-80,98},{81,-82}},
              lineColor={184,0,0},
              lineThickness=0.5,
              fillColor={245,245,245},
              fillPattern=FillPattern.Solid),
            Text(
              extent={{-101,41},{-101,25}},
              lineColor={184,0,0},
              lineThickness=0.5,
              textString="port_0"),
            Text(
              extent={{101,40},{101,24}},
              lineColor={184,0,0},
              lineThickness=0.5,
              textString="port_L"),
            Rectangle(
              extent={{-79,89},{-75,-73}},
              lineColor={135,135,135},
              fillColor={175,175,175},
              fillPattern=FillPattern.Solid),
            Rectangle(
              extent={{75,89},{79,-73}},
              lineColor={135,135,135},
              fillColor={175,175,175},
              fillPattern=FillPattern.Solid),
            Rectangle(extent={{-71,-53},{71,-73}}, lineColor={0,127,0}),
            Text(
              extent={{0,-54},{0,-72}},
              lineColor={0,127,0},
              fillColor={255,128,0},
              fillPattern=FillPattern.Solid,
              textString="Material_B"),
            Rectangle(
              extent={{-75,-11},{-71,-73}},
              lineColor={135,135,135},
              fillColor={0,0,255},
              fillPattern=FillPattern.Solid),
            Line(
              points={{-82,-63},{-72,-63},{-72,-53}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5),
            Line(
              points={{-72,69},{-72,79},{-80,79}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5),
            Rectangle(
              extent={{71,-21},{75,-73}},
              lineColor={135,135,135},
              fillColor={0,0,255},
              fillPattern=FillPattern.Solid),
            Rectangle(
              extent={{-75,89},{-71,21}},
              lineColor={135,135,135},
              fillColor={0,0,255},
              fillPattern=FillPattern.Solid),
            Rectangle(extent={{-71,-21},{71,-41}}, lineColor={255,200,2}),
            Text(
              extent={{0,-22},{0,-40}},
              lineColor={255,200,2},
              fillColor={255,128,0},
              fillPattern=FillPattern.Solid,
              textString="Material_A"),
            Text(
              extent={{0,56},{0,38}},
              lineColor={0,127,0},
              fillColor={255,128,0},
              fillPattern=FillPattern.Solid,
              textString="Material_B"),
            Rectangle(extent={{-71,57},{71,37}}, lineColor={0,127,0}),
            Rectangle(extent={{-71,89},{72,69}}, lineColor={255,200,2}),
            Text(
              extent={{0,88},{0,70}},
              lineColor={255,200,2},
              fillColor={255,128,0},
              fillPattern=FillPattern.Solid,
              textString="Material_A"),
            Rectangle(
              extent={{71,89},{75,37}},
              lineColor={135,135,135},
              fillColor={0,0,255},
              fillPattern=FillPattern.Solid),
            Text(
              extent={{0,53},{0,9}},
              lineColor={0,0,0},
              lineThickness=0.5,
              fillPattern=FillPattern.Solid,
              textString="."),
            Text(
              extent={{0,24},{0,-20}},
              lineColor={0,0,0},
              lineThickness=0.5,
              fillPattern=FillPattern.Solid,
              textString="."),
            Text(
              extent={{0,38},{0,-6}},
              lineColor={0,0,0},
              lineThickness=0.5,
              fillPattern=FillPattern.Solid,
              textString=".")}));
    end CTEL_1D_dyn_seq_intalpha;

    model CTEL_1D_dyn_seq_intalpha_contact_res
      "as int_alpha surplus additional modeling of wires which connect TE-legs"

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends CTEL_base;

      parameter Integer S=2
        "Number of 1D spatial discretization steps within legs"                    annotation(dialog(group="Parameters of TEG-leg"));
      parameter Modelica.SIunits.Thickness Thickness_conn
        "Thickness of Connector"
        annotation (dialog(absoluteWidth=40, group="Parameters of TEG-leg connectors"));

      replaceable
        ThermoelectricGenerator_V5_7.Packaging_Material_Data.MaterialBase Material_connector
        constrainedby
        ThermoelectricGenerator_V5_7.Packaging_Material_Data.MaterialBase
        "Material of leg connector" annotation (choicesAllMatching=true, dialog(
            group="Parameters of TEG-leg connectors"));

      replaceable
        ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase Material_A
        constrainedby
        ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase
        "Material of A-legs" annotation (choicesAllMatching=true, dialog(group=
              "Parameters of TEG-leg", absoluteWidth=30));

      replaceable
        ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase Material_B
        constrainedby
        ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase
        "Material of B-legs" annotation (choicesAllMatching=true, dialog(group=
              "Parameters of TEG-leg", absoluteWidth=30));

      Modelica.SIunits.Resistance R=sum(Leg_A.TE[i].elecResistor.R + Leg_B.TE[i].elecResistor.R
          for i in 1:S)+leg_conn_elec.overall_res "Total el. resistance";

      Components_for_TEL.TE_Leg_Int_alpha
                       Leg_A(
        materialName="Material_A",
        Material=Material_A,
        T_0=T_0,
        S=S,
        A=A,
        L=L,
        N_TE=N_TE)
        annotation (Placement(transformation(extent={{-43,31},{35,109}})));
      Components_for_TEL.TE_Leg_Int_alpha
                       Leg_B(
        materialName="Material_B",
        Material=Material_B,
        T_0=T_0,
        S=S,
        A=A,
        L=L,
        N_TE=N_TE)
        annotation (Placement(transformation(extent={{-40,-74},{38,4}})));
     replaceable
        ThermoelectricGenerator_V5_7.Inner_TEG.Components_for_leg_connection.no_contact_and_no_wire_res
        leg_conn_elec constrainedby
        ThermoelectricGenerator_V5_7.Inner_TEG.Components_for_leg_connection.Leg_connector_electrical_base(
        Thickness=Thickness_conn,
        Breadth=sqrt(A),
        Length=3*sqrt(A),
        N_TE=N_TE,
        Material=Material_connector) annotation (
        choicesAllMatching=true,
        dialog(group="Parameters of TEG-leg connectors"),
        Placement(transformation(
            extent={{-10,-10},{10,10}},
            rotation=270,
            origin={44,31})));
      replaceable
        ThermoelectricGenerator_V5_7.Inner_TEG.Components_for_leg_connection.no_res_no_storage
        leg_conn_thermal_left constrainedby
        ThermoelectricGenerator_V5_7.Inner_TEG.Components_for_leg_connection.Leg_connector_thermal_base(
        Thickness=Thickness_conn,
        Breadth=sqrt(A),
        Length=3*sqrt(A),
        N_TE=N_TE,
        Material=Material_connector) annotation (
        choicesAllMatching=true,
        dialog(group="Parameters of TEG-leg connectors"),
        Placement(transformation(
            extent={{-10,-10},{10,10}},
            rotation=0,
            origin={-61,18})));
      replaceable
        ThermoelectricGenerator_V5_7.Inner_TEG.Components_for_leg_connection.no_res_no_storage
        leg_conn_thermal_right constrainedby
        ThermoelectricGenerator_V5_7.Inner_TEG.Components_for_leg_connection.Leg_connector_thermal_base(
        Thickness=Thickness_conn,
        Breadth=sqrt(A),
        Length=3*sqrt(A),
        N_TE=N_TE,
        Material=Material_connector) annotation (
        choicesAllMatching=true,
        dialog(group="Parameters of TEG-leg connectors"),
        Placement(transformation(
            extent={{-10,-10},{10,10}},
            rotation=0,
            origin={72,32})));
    equation

      connect(port_a, leg_conn_thermal_left.port_a) annotation (Line(
          points={{-85,0},{-71,0},{-71,18}},
          color={191,0,0},
          smooth=Smooth.None));
      connect(Leg_A.port_0, leg_conn_thermal_left.port_b) annotation (Line(
          points={{-37.4425,66.1975},{-51,66.1975},{-51,18}},
          color={191,0,0},
          smooth=Smooth.None));
      connect(leg_conn_thermal_left.port_b, Leg_B.port_0) annotation (Line(
          points={{-51,18},{-51,-38.8025},{-34.4425,-38.8025}},
          color={191,0,0},
          smooth=Smooth.None));
      connect(Leg_B.p, p) annotation (Line(
          points={{-34.54,-24.665},{-85,-24.665},{-85,-78}},
          color={0,0,255},
          smooth=Smooth.None));
      connect(Leg_A.p, n) annotation (Line(
          points={{-37.54,80.335},{-60.77,80.335},{-60.77,80},{-85,80}},
          color={0,0,255},
          smooth=Smooth.None));
      connect(Leg_B.n, leg_conn_elec.n) annotation (Line(
          points={{32.8325,-24.5675},{44,-24.5675},{44,21}},
          color={0,0,255},
          smooth=Smooth.None));
      connect(leg_conn_elec.p, Leg_A.n) annotation (Line(
          points={{44,41},{44,80.4325},{29.8325,80.4325}},
          color={0,0,255},
          smooth=Smooth.None));
      connect(Leg_A.port_L, leg_conn_thermal_right.port_a) annotation (Line(
          points={{29.8325,66.1975},{62,66.1975},{62,32}},
          color={191,0,0},
          smooth=Smooth.None));
      connect(leg_conn_thermal_right.port_a, Leg_B.port_L) annotation (Line(
          points={{62,32},{61,32},{61,-39},{32.8325,-39},{32.8325,-38.8025}},
          color={191,0,0},
          smooth=Smooth.None));
      connect(port_b, leg_conn_thermal_right.port_b) annotation (Line(
          points={{88,0},{82,0},{82,32}},
          color={191,0,0},
          smooth=Smooth.None));
      annotation (
        Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"),     Diagram(coordinateSystem(
            preserveAspectRatio=true,
            extent={{-120,-110},{120,120}},
            grid={1,1}), graphics),
        Icon(coordinateSystem(
            preserveAspectRatio=true,
            extent={{-120,-110},{120,120}},
            grid={1,1}), graphics={
            Text(
              extent={{-100,-83},{100,-109}},
              lineColor={184,0,0},
              fillColor={0,166,0},
              fillPattern=FillPattern.Solid,
              textString="%name",
              lineThickness=0.5),
            Text(
              extent={{-101,112},{-101,88}},
              lineColor={0,0,255},
              lineThickness=0.5,
              fillPattern=FillPattern.VerticalCylinder,
              fillColor={0,0,255},
              textString="n"),
            Text(
              extent={{-100,-22},{-100,-46}},
              lineColor={0,0,255},
              lineThickness=0.5,
              fillPattern=FillPattern.VerticalCylinder,
              fillColor={0,0,255},
              textString="p"),
            Rectangle(
              extent={{-80,98},{81,-82}},
              lineColor={184,0,0},
              lineThickness=0.5,
              fillColor={245,245,245},
              fillPattern=FillPattern.Solid),
            Text(
              extent={{-101,41},{-101,25}},
              lineColor={184,0,0},
              lineThickness=0.5,
              textString="port_a"),
            Text(
              extent={{101,40},{101,24}},
              lineColor={184,0,0},
              lineThickness=0.5,
              textString="port_b"),
            Rectangle(
              extent={{-79,89},{-75,-73}},
              lineColor={135,135,135},
              fillColor={175,175,175},
              fillPattern=FillPattern.Solid),
            Rectangle(
              extent={{75,89},{79,-73}},
              lineColor={135,135,135},
              fillColor={175,175,175},
              fillPattern=FillPattern.Solid),
            Rectangle(extent={{-71,-53},{71,-73}}, lineColor={0,127,0}),
            Text(
              extent={{0,-54},{0,-72}},
              lineColor={0,127,0},
              fillColor={255,128,0},
              fillPattern=FillPattern.Solid,
              textString="Material_B"),
            Rectangle(
              extent={{-75,-11},{-71,-73}},
              lineColor={135,135,135},
              fillColor={0,0,255},
              fillPattern=FillPattern.Solid),
            Line(
              points={{-82,-63},{-72,-63},{-72,-53}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5),
            Line(
              points={{-72,69},{-72,79},{-80,79}},
              color={0,0,255},
              smooth=Smooth.None,
              thickness=0.5),
            Rectangle(
              extent={{71,-21},{75,-73}},
              lineColor={135,135,135},
              fillColor={0,0,255},
              fillPattern=FillPattern.Solid),
            Rectangle(
              extent={{-75,89},{-71,21}},
              lineColor={135,135,135},
              fillColor={0,0,255},
              fillPattern=FillPattern.Solid),
            Rectangle(extent={{-71,-21},{71,-41}}, lineColor={255,200,2}),
            Text(
              extent={{0,-22},{0,-40}},
              lineColor={255,200,2},
              fillColor={255,128,0},
              fillPattern=FillPattern.Solid,
              textString="Material_A"),
            Text(
              extent={{0,56},{0,38}},
              lineColor={0,127,0},
              fillColor={255,128,0},
              fillPattern=FillPattern.Solid,
              textString="Material_B"),
            Rectangle(extent={{-71,57},{71,37}}, lineColor={0,127,0}),
            Rectangle(extent={{-71,89},{72,69}}, lineColor={255,200,2}),
            Text(
              extent={{0,88},{0,70}},
              lineColor={255,200,2},
              fillColor={255,128,0},
              fillPattern=FillPattern.Solid,
              textString="Material_A"),
            Rectangle(
              extent={{71,89},{75,37}},
              lineColor={135,135,135},
              fillColor={0,0,255},
              fillPattern=FillPattern.Solid),
            Text(
              extent={{0,53},{0,9}},
              lineColor={0,0,0},
              lineThickness=0.5,
              fillPattern=FillPattern.Solid,
              textString="."),
            Text(
              extent={{0,24},{0,-20}},
              lineColor={0,0,0},
              lineThickness=0.5,
              fillPattern=FillPattern.Solid,
              textString="."),
            Text(
              extent={{0,38},{0,-6}},
              lineColor={0,0,0},
              lineThickness=0.5,
              fillPattern=FillPattern.Solid,
              textString=".")}));
    end CTEL_1D_dyn_seq_intalpha_contact_res;

    package Components_for_TEL "components for the CTEL models"
    extends Modelica.Icons.Package;

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      package Base_Components
      extends Modelica.Icons.Package;

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

        package Functions
          //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')
        extends Modelica.Icons.Package;

          function Calculate_alpha
            "Calculation of temperature-dependent Seebeck Coefficient from table data"

            //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

            input Integer ID_alpha;
            input
              ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase
              DataRecord;
            input Modelica.SIunits.Temperature T;
            output Real alpha;

          algorithm
            alpha := Interpolation_2(
                    ID_alpha,
                    T,
                    false,
                    DataRecord.alpha);

            annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"));
          end Calculate_alpha;

          function Calculate_rho_el
            "Calculation of temperature-dependent electrical resistivity from table data"

            //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

            input Integer ID_rho_el;
            input
              ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase
              DataRecord;
            input Modelica.SIunits.Temperature T;
            output Real rho_el;

          algorithm
            rho_el := Interpolation_2(
                    ID_rho_el,
                    T,
                    false,
                    DataRecord.rho_el);

            annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));
          end Calculate_rho_el;

          function Calculate_lambda
            "Calculation of temperature-dependent thermal conductivity from table data"

            //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

            input Integer ID_lambda;
            input
              ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase
              DataRecord;
            input Modelica.SIunits.Temperature T;
            output Real lambda;

          algorithm
            lambda := Interpolation_2(
                    ID_lambda,
                    T,
                    false,
                    DataRecord.lambda);

            annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"));
          end Calculate_lambda;

          function Interpolation_2
            "Linear interpolation of 1D table (according to table model from Modelica Std. Library)"

            //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

            input Integer tableID;
            input Real u;
            input Boolean tableOnFile=false
              "true, if table is defined on file or in function usertab";
            input Real table[:, :]=fill(
                      0.0,
                      0,
                      2)
              "table matrix (grid = first column; e.g., table=[0,2])";
            output Real y "Interpolated value";

          protected
            Integer column=2 "columns of table to be interpolated";

          algorithm
            y := if not tableOnFile and size(table, 1) == 1 then table[1,
              column] else tableIpo(
                        tableID,
                        column,
                        u);

            annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"));
          end Interpolation_2;

          function tableInit
            "Initialize 1-dim. table defined by matrix (for details see: Modelica/C-Sources/ModelicaTables.h)"

            //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

            input String tableName;
            input String fileName;
            input Real table[:, :];
            input Modelica.Blocks.Types.Smoothness smoothness;
            output Integer tableID;
          external"C" tableID = ModelicaTables_CombiTable1D_init(
                    tableName,
                    fileName,
                    table,
                    size(table, 1),
                    size(table, 2),
                    smoothness);

            annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),         Library="ModelicaExternalC");
          end tableInit;

          function tableIpo
            "Interpolate 1-dim. table defined by matrix (for details see: Modelica/C-Sources/ModelicaTables.h)"

            //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

            input Integer tableID;
            input Integer icol;
            input Real u;
            output Real value;
          external"C" value = ModelicaTables_CombiTable1D_interpolate(
                    tableID,
                    icol,
                    u);

            annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),         Library="ModelicaExternalC");
          end tableIpo;

          annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));
        end Functions;

        package Connectors
        extends Modelica.Icons.InterfacesPackage;

          //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

          connector HeatPort_a
            "Thermal port for 1-dim. heat transfer (filled rectangular icon)  [From Modelica Std. Library]"

            extends Modelica.Thermal.HeatTransfer.Interfaces.HeatPort;

            annotation (
              Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"),           defaultComponentName="port_a",
              Documentation(info="<HTML>
<p>This connector is used for 1-dimensional heat flow between components.
The variables in the connector are:</p>
<pre>
   T       Temperature in [Kelvin].
   Q_flow  Heat flow rate in [Watt].
</pre>
<p>According to the Modelica sign convention, a <b>positive</b> heat flow
rate <b>Q_flow</b> is considered to flow <b>into</b> a component. This
convention has to be used whenever this connector is used in a model
class.</p>
<p>Note, that the two connector classes <b>HeatPort_a</b> and
<b>HeatPort_b</b> are identical with the only exception of the different
<b>icon layout</b>.</p></HTML>
"),           Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
                      100,100}}), graphics={Rectangle(
                    extent={{-100,100},{100,-100}},
                    lineColor={191,0,0},
                    fillColor={191,0,0},
                    fillPattern=FillPattern.Solid)}),
              Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},
                      {100,100}}), graphics={Rectangle(
                    extent={{-50,50},{50,-50}},
                    lineColor={191,0,0},
                    fillColor={191,0,0},
                    fillPattern=FillPattern.Solid), Text(
                    extent={{-120,120},{100,60}},
                    lineColor={191,0,0},
                    textString="%name")}));
          end HeatPort_a;

          connector HeatPort_b
            "Thermal port for 1-dim. heat transfer (unfilled rectangular icon)  [From Modelica Std. Library]"

            extends Modelica.Thermal.HeatTransfer.Interfaces.HeatPort;

            annotation (
              Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"),           defaultComponentName="port_b",
              Documentation(info="<HTML>
<p>This connector is used for 1-dimensional heat flow between components.
The variables in the connector are:</p>
<pre>
   T       Temperature in [Kelvin].
   Q_flow  Heat flow rate in [Watt].
</pre>
<p>According to the Modelica sign convention, a <b>positive</b> heat flow
rate <b>Q_flow</b> is considered to flow <b>into</b> a component. This
convention has to be used whenever this connector is used in a model
class.</p>
<p>Note, that the two connector classes <b>HeatPort_a</b> and
<b>HeatPort_b</b> are identical with the only exception of the different
<b>icon layout</b>.</p></HTML>
"),           Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},
                      {100,100}}), graphics={Rectangle(
                    extent={{-50,50},{50,-50}},
                    lineColor={191,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid), Text(
                    extent={{-100,120},{120,60}},
                    lineColor={191,0,0},
                    textString="%name")}),
              Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
                      100,100}}), graphics={Rectangle(
                    extent={{-100,100},{100,-100}},
                    lineColor={191,0,0},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid)}));
          end HeatPort_b;

          partial model Element1D
            "Partial heat transfer element with two HeatPort connectors that does not store energy  [From Modelica Std. Library]"

            Modelica.SIunits.HeatFlowRate Q_flow
              "Heat flow rate from port_a -> port_b";
            Modelica.SIunits.TemperatureDifference dT "port_a.T - port_b.T";
          public
            HeatPort_a port_a annotation (Placement(transformation(extent={{-110,-10},
                      {-90,10}}, rotation=0)));
            HeatPort_b port_b annotation (Placement(transformation(extent={{90,-10},
                      {110,10}},rotation=0)));
          equation
            dT = port_a.T - port_b.T;
            port_a.Q_flow = Q_flow;
            port_b.Q_flow = -Q_flow;
            annotation (
              Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"),           Documentation(info="<HTML>
<p>
This partial model contains the basic connectors and variables to
allow heat transfer models to be created that <b>do not store energy</b>,
This model defines and includes equations for the temperature
drop across the element, <b>dT</b>, and the heat flow rate
through the element from port_a to port_b, <b>Q_flow</b>.
</p>
<p>
By extending this model, it is possible to write simple
constitutive equations for many types of heat transfer components.
</p>
</HTML>
"),           Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
                      100,100}}), graphics),
              Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},
                      {100,100}}), graphics));
          end Element1D;

          connector PositivePin
            "Positive pin of an electric component  [From Modelica Std. Library]"

            Modelica.SIunits.Voltage v "Potential at the pin" annotation (
                unassignedMessage="An electrical potential cannot be uniquely calculated.
The reason could be that
- a ground object is missing (Modelica.Electrical.Analog.Basic.Ground)
  to define the zero potential of the electrical circuit, or
- a connector of an electrical component is not connected.");
            flow Modelica.SIunits.Current i "Current flowing into the pin"
              annotation (unassignedMessage="An electrical current cannot be uniquely calculated.
The reason could be that
- a ground object is missing (Modelica.Electrical.Analog.Basic.Ground)
  to define the zero potential of the electrical circuit, or
- a connector of an electrical component is not connected.");
            annotation (
              Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>  
**************************************************************************** <p>
</html>
"),           defaultComponentName="pin_p",
              Documentation(info="<html><p>Connectors PositivePin
and NegativePin are nearly identical.
The only difference is that the icons are different in order
to identify more easily the pins of a component. Usually,
connector PositivePin is used for the positive and
connector NegativePin for the negative pin of an electrical
component.</p></html>",     revisions="<html>
<ul>
<li><i> 1998   </i>
       by Christoph Clauss<br> initially implemented<br>
       </li>
</ul>
</html>"),    Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
                      100,100}}), graphics={Rectangle(
                    extent={{-100,100},{100,-100}},
                    lineColor={0,0,255},
                    fillColor={0,0,255},
                    fillPattern=FillPattern.Solid)}),
              Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},
                      {100,100}}), graphics={Rectangle(
                    extent={{-40,40},{40,-40}},
                    lineColor={0,0,255},
                    fillColor={0,0,255},
                    fillPattern=FillPattern.Solid), Text(
                    extent={{-160,110},{40,50}},
                    lineColor={0,0,255},
                    textString="%name")}));
          end PositivePin;

          connector NegativePin
            "Negative pin of an electric component  [From Modelica Std. Library]"

            Modelica.SIunits.Voltage v "Potential at the pin" annotation (
                unassignedMessage="An electrical potential cannot be uniquely calculated.
The reason could be that
- a ground object is missing (Modelica.Electrical.Analog.Basic.Ground)
  to define the zero potential of the electrical circuit, or
- a connector of an electrical component is not connected.");
            flow Modelica.SIunits.Current i "Current flowing into the pin"
              annotation (unassignedMessage="An electrical current cannot be uniquely calculated.
The reason could be that
- a ground object is missing (Modelica.Electrical.Analog.Basic.Ground)
  to define the zero potential of the electrical circuit, or
- a connector of an electrical component is not connected.");
            annotation (
              Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"),           defaultComponentName="pin_n",
              Documentation(info="<html><p>Connectors PositivePin
and NegativePin are nearly identical.
The only difference is that the icons are different in order
to identify more easily the pins of a component. Usually,
connector PositivePin is used for the positive and
connector NegativePin for the negative pin of an electrical
component.</p></html>",     revisions="<html>
<li><i> 1998   </i>
       by Christoph Clauss<br> initially implemented<br>
       </li>
</ul>
</html>"),    Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
                      100,100}}), graphics={Rectangle(
                    extent={{-100,100},{100,-100}},
                    lineColor={0,0,255},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid)}),
              Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},
                      {100,100}}), graphics={Rectangle(
                    extent={{-40,40},{40,-40}},
                    lineColor={0,0,255},
                    fillColor={255,255,255},
                    fillPattern=FillPattern.Solid), Text(
                    extent={{-40,110},{160,50}},
                    textString="%name",
                    lineColor={0,0,255})}));
          end NegativePin;

          partial model OnePort
            "Component with two electrical pins p and n and current i from p to n  [From Modelica Std. Library]"

            Modelica.SIunits.Voltage v
              "Voltage drop between the two pins (= p.v - n.v)";
            Modelica.SIunits.Current i "Current flowing from pin p to pin n";
            PositivePin p
              "Positive pin (potential p.v > n.v for positive voltage drop v)"
              annotation (Placement(transformation(extent={{-110,-10},{-90,10}},
                    rotation=0)));
            NegativePin n "Negative pin"      annotation (Placement(transformation(
                    extent={{110,-10},{90,10}}, rotation=0)));
          equation
            v = p.v - n.v;
            0 = p.i + n.i;
            i = p.i;
            annotation (
              Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>  
**************************************************************************** <p>
</html>
"),           Documentation(info="<HTML>
<P>
Superclass of elements which have <b>two</b> electrical pins:
the positive pin connector <i>p</i>, and the negative pin
connector <i>n</i>. It is assumed that the current flowing
into pin p is identical to the current flowing out of pin n.
This current is provided explicitly as current i.
</P>
</HTML>
",         revisions=
                 "<html>
<ul>
<li><i> 1998   </i>
       by Christoph Clauss<br> initially implemented<br>
       </li>
</ul>
</html>"),    Diagram(coordinateSystem(
                  preserveAspectRatio=true,
                  extent={{-100,-100},{100,100}},
                  grid={2,2}), graphics={
                  Line(points={{-110,20},{-85,20}}, color={160,160,164}),
                  Polygon(
                    points={{-95,23},{-85,20},{-95,17},{-95,23}},
                    lineColor={160,160,164},
                    fillColor={160,160,164},
                    fillPattern=FillPattern.Solid),
                  Line(points={{90,20},{115,20}}, color={160,160,164}),
                  Line(points={{-125,0},{-115,0}}, color={160,160,164}),
                  Line(points={{-120,-5},{-120,5}}, color={160,160,164}),
                  Text(
                    extent={{-110,25},{-90,45}},
                    lineColor={160,160,164},
                    textString="i"),
                  Polygon(
                    points={{105,23},{115,20},{105,17},{105,23}},
                    lineColor={160,160,164},
                    fillColor={160,160,164},
                    fillPattern=FillPattern.Solid),
                  Line(points={{115,0},{125,0}}, color={160,160,164}),
                  Text(
                    extent={{90,45},{110,25}},
                    lineColor={160,160,164},
                    textString="i")}));
          end OnePort;
          annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>  
**************************************************************************** <p>
</html>
"));
        end Connectors;

        model ThermalConductor
          "Lumped temperature-dependent thermal element transporting heat without storing it"

          //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

          extends Base_Components.Connectors.Element1D;

          //**Begin helper interface for spatial discretized model****
          Integer ID_lambda;
          Modelica.Blocks.Interfaces.IntegerInput ID_lambda_input=ID_lambda if
            ID_extern_given;
          parameter Boolean ID_extern_given=false;
          // if model is used in a spatial discretized model (e.g TE_Leg) tables are initialized in outer model and ID_lambda is given by integer input ID_lambda_input
          //**End helper interface************************************

          String Table_lambda="NoName" annotation (dialog(enable=true));
          String File_lambda="NoName" annotation (dialog(enable=true));
          Real lambda_values[:, 2]={{0,0}} annotation (dialog(enable=true));

          Modelica.SIunits.ThermalConductivity lambda
            "(Variable) thermal conductivity";
          Modelica.SIunits.ThermalConductance G "Varialbe thermal conductance";
          Modelica.SIunits.Temperature T
            "Avg. temperature (used for calcultion of conductance 'G')";
          parameter Modelica.SIunits.Length L=0.01 "Length";
          parameter Modelica.SIunits.Area A=1 "Cross section area";

        equation
          when initial() then
            if not ID_extern_given then
              ID_lambda = Base_Components.Functions.tableInit(
                                              Table_lambda,File_lambda,lambda_values,1);
            end if;
          end when;

          T = (port_a.T + port_b.T)/2;
          lambda = Base_Components.Functions.Interpolation_2(
                ID_lambda,
                T,
                false,
                lambda_values);
          G = lambda*A/L;
          Q_flow = G*dT;
          annotation (
            Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"),         Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
                    100,100}}), graphics={
                Rectangle(
                  extent={{-90,70},{90,-70}},
                  lineColor={0,0,0},
                  pattern=LinePattern.None,
                  fillColor={192,192,192},
                  fillPattern=FillPattern.Backward),
                Line(
                  points={{-90,70},{-90,-70}},
                  color={0,0,0},
                  thickness=0.5),
                Line(
                  points={{90,70},{90,-70}},
                  color={0,0,0},
                  thickness=0.5),
                Text(
                  extent={{0,118},{0,72}},
                  textString="%name",
                  lineColor={0,0,255})}),
            Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},
                    {100,100}}), graphics={
                Line(
                  points={{-80,0},{80,0}},
                  color={255,0,0},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Text(
                  extent={{-26,-10},{27,-39}},
                  lineColor={255,0,0},
                  textString="Q_flow"),
                Text(
                  extent={{-80,50},{80,20}},
                  lineColor={0,0,0},
                  textString="dT = port_a.T - port_b.T")}),
            Documentation(info="<HTML>
<p>
This is a model for transport of heat without storing it.
It may be used for complicated geometries where
the thermal conductance G (= inverse of thermal resistance)
is determined by measurements and is assumed to be constant
over the range of operations. If the component consists mainly of
one type of material and a regular geometry, it may be calculated,
e.g., with one of the following equations:
</p>
<ul>
<li><p>
    Conductance for a <b>box</b> geometry under the assumption
    that heat flows along the box length:</p>
    <pre>
    G = k*A/L
    k: Thermal conductivity (material constant)
    A: Area of box
    L: Length of box
    </pre>
    </li>
<li><p>
    Conductance for a <b>cylindrical</b> geometry under the assumption
    that heat flows from the inside to the outside radius
    of the cylinder:</p>
    <pre>
    G = 2*pi*k*L/log(r_out/r_in)
    pi   : Modelica.Constants.pi
    k    : Thermal conductivity (material constant)
    L    : Length of cylinder
    log  : Modelica.Math.log;
    r_out: Outer radius of cylinder
    r_in : Inner radius of cylinder
    </pre>
    </li>
</li>
</ul>
<pre>
    Typical values for k at 20 degC in W/(m.K):
      aluminium   220
      concrete      1
      copper      384
      iron         74
      silver      407
      steel        45 .. 15 (V2A)
      wood         0.1 ... 0.2
</pre>
</HTML>
"));
        end ThermalConductor;

        model ThermalConductor_STATIC
          "Lumped thermal element transporting heat without storing it"

          //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

          extends Base_Components.Connectors.Element1D;

          Modelica.SIunits.ThermalConductance G=1
            "Constant thermal conductance of material"
          annotation (dialog(enable=true));

        equation
          Q_flow = G*dT;
          annotation (
            Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"),         Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
                    100,100}}), graphics={
                Rectangle(
                  extent={{-90,70},{90,-70}},
                  lineColor={0,0,0},
                  pattern=LinePattern.None,
                  fillColor={192,192,192},
                  fillPattern=FillPattern.Backward),
                Line(
                  points={{-90,70},{-90,-70}},
                  color={0,0,0},
                  thickness=0.5),
                Line(
                  points={{90,70},{90,-70}},
                  color={0,0,0},
                  thickness=0.5),
                Text(
                  extent={{-139,134},{141,74}},
                  textString="%name",
                  lineColor={0,0,255}),
                Text(
                  extent={{-115,-76},{113,-116}},
                  lineColor={0,0,0},
                  textString="G=%G")}),
            Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},
                    {100,100}}), graphics={
                Line(
                  points={{-80,0},{80,0}},
                  color={255,0,0},
                  thickness=0.5,
                  arrow={Arrow.None,Arrow.Filled}),
                Text(
                  extent={{-26,-10},{27,-39}},
                  lineColor={255,0,0},
                  textString="Q_flow"),
                Text(
                  extent={{-80,50},{80,20}},
                  lineColor={0,0,0},
                  textString="dT = port_a.T - port_b.T")}),
            Documentation(info="<HTML>
<p>
This is a model for transport of heat without storing it.
It may be used for complicated geometries where
the thermal conductance G (= inverse of thermal resistance)
is determined by measurements and is assumed to be constant
over the range of operations. If the component consists mainly of
one type of material and a regular geometry, it may be calculated,
e.g., with one of the following equations:
</p>
<ul>
<li><p>
    Conductance for a <b>box</b> geometry under the assumption
    that heat flows along the box length:</p>
    <pre>
    G = k*A/L
    k: Thermal conductivity (material constant)
    A: Area of box
    L: Length of box
    </pre>
    </li>
<li><p>
    Conductance for a <b>cylindrical</b> geometry under the assumption
    that heat flows from the inside to the outside radius
    of the cylinder:</p>
    <pre>
    G = 2*pi*k*L/log(r_out/r_in)
    pi   : Modelica.Constants.pi
    k    : Thermal conductivity (material constant)
    L    : Length of cylinder
    log  : Modelica.Math.log;
    r_out: Outer radius of cylinder
    r_in : Inner radius of cylinder
    </pre>
    </li>
</li>
</ul>
<pre>
    Typical values for k at 20 degC in W/(m.K):
      aluminium   220
      concrete      1
      copper      384
      iron         74
      silver      407
      steel        45 .. 15 (V2A)
      wood         0.1 ... 0.2
</pre>
</HTML>
"));
        end ThermalConductor_STATIC;

        model PeltierHeatFlow
          "Peltier heat flow (positive if current * alpha > 0), including Thomson effect"

          //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

          //**Begin helper interface for spatial discretized model****
          Modelica.Blocks.Interfaces.IntegerInput ID_alpha_input=ID_alpha if
            ID_extern_given;
          parameter Boolean ID_extern_given=false;
          // if model is used in a spatial discretized model (e.g TE_Leg) tables are initialized in outer model and ID_lambda is given by integer input ID_alpha_input
          Integer ID_alpha;
          //**End helper interface************************************

          String Table_alpha="NoName" annotation (dialog(enable=true));
          String File_alpha="NoName" annotation (dialog(enable=true));
          Real alpha_values[:, 2]={{0,0}} annotation (dialog(enable=true));

          parameter Integer N_TE=1
            "if concatenation is modeled: Number of TE (of the same type) at identical temperature (el. in series, thermally in parallel)";
          parameter Boolean ThomsonEffect=true "Activate Thomson Effect";

          Modelica.SIunits.SeebeckCoefficient alpha_a=Base_Components.Functions.Interpolation_2(
                  ID_alpha,
                  port_a.T,
                  false,
                  alpha_values)
            "Seebeck coefficient of 'Material' at temperature of 'port_a'";
          Modelica.SIunits.SeebeckCoefficient alpha_b=Base_Components.Functions.Interpolation_2(
                  ID_alpha,
                  port_b.T,
                  false,
                  alpha_values)
            "Seebeck coefficient of 'Material' at temperature of 'port_b'";
          Modelica.SIunits.SeebeckCoefficient alpha_c=Base_Components.Functions.Interpolation_2(
                  ID_alpha,
                  port_c.T,
                  false,
                  alpha_values)
            "Seebeck coefficient of 'Material' at temperature of 'port_c' (between 'port_a' and 'port_b')";

          Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a annotation (
              Placement(transformation(extent={{-102,-8},{-82,12}}),
                iconTransformation(extent={{-100,-10},{-80,10}})));
          Modelica.Blocks.Interfaces.RealInput i
            "Signal defining electrical current" annotation (Placement(
                transformation(
                extent={{-20,-20},{20,20}},
                rotation=90,
                origin={0,-96}), iconTransformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={0,-85})));
          Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b annotation (
              Placement(transformation(extent={{88,-14},{108,6}}),
                iconTransformation(extent={{80,-10},{100,10}})));
          Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_c annotation (
              Placement(transformation(extent={{-10,75},{10,95}}),
                iconTransformation(extent={{-13,75},{7,95}})));

        equation
          when initial() then
            if not ID_extern_given then
              ID_alpha = Base_Components.Functions.tableInit(
                    Table_alpha,
                    File_alpha,
                    alpha_values,
                    1);
            end if;
          end when;

          port_a.Q_flow = N_TE*i*alpha_a*port_a.T;
          // Peltier heat flow into 'port_a'
          port_b.Q_flow = -N_TE*i*alpha_b*port_b.T;
          // Peltier heat flow into 'port_b'
          port_c.Q_flow = if ThomsonEffect then -N_TE*i*((alpha_a - alpha_c)*port_a.T
             + (alpha_c - alpha_b)*port_b.T) else 0;
          // Heat flow into 'port_c' due to Thomson effect

          annotation (
            Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),         Icon(coordinateSystem(
                preserveAspectRatio=true,
                extent={{-100,-100},{100,100}},
                grid={1,1}), graphics={
                Rectangle(
                  extent={{-80,75},{80,-75}},
                  lineColor={0,0,0},
                  pattern=LinePattern.None,
                  fillColor={192,192,192},
                  fillPattern=FillPattern.Backward),
                Text(
                  extent={{-94,-11},{91,-46}},
                  lineColor={0,0,255},
                  textString="Peltier"),
                Text(
                  extent={{-91,-40},{92,-78}},
                  lineColor={0,0,255},
                  textString="heat_flow"),
                Text(
                  extent={{-25,-77},{-25,-107}},
                  lineColor={0,0,127},
                  fillPattern=FillPattern.Solid,
                  fillColor={193,0,0},
                  textString="I"),
                Rectangle(
                  extent={{-80,2},{-12,-2}},
                  lineColor={193,0,0},
                  fillColor={193,0,0},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-5,1},{68,-1}},
                  lineColor={193,0,0},
                  fillColor={193,0,0},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{68,-6},{68,6},{80,0},{68,-6}},
                  lineColor={193,0,0},
                  smooth=Smooth.None,
                  fillColor={193,0,0},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-4,15},{-2,1}},
                  lineColor={193,0,0},
                  fillColor={193,0,0},
                  fillPattern=FillPattern.Solid),
                Polygon(
                  points={{0,-5},{-6,5},{6,5},{0,-5}},
                  lineColor={193,0,0},
                  smooth=Smooth.None,
                  fillColor={193,0,0},
                  fillPattern=FillPattern.Solid,
                  origin={-3,69},
                  rotation=180),
                Polygon(
                  points={{-12,-6},{-12,6},{0,0},{-12,-6}},
                  lineColor={193,0,0},
                  smooth=Smooth.None,
                  fillColor={193,0,0},
                  fillPattern=FillPattern.Solid),
                Text(
                  extent={{-43.5,9.5},{43.5,-9.5}},
                  lineColor={184,0,0},
                  origin={-21.5,38.5},
                  rotation=90,
                  textString="Thomson"),
                Rectangle(
                  extent={{-4,39},{-2,25}},
                  lineColor={193,0,0},
                  fillColor={193,0,0},
                  fillPattern=FillPattern.Solid),
                Rectangle(
                  extent={{-4,64},{-2,50}},
                  lineColor={193,0,0},
                  fillColor={193,0,0},
                  fillPattern=FillPattern.Solid),
                Text(
                  extent={{-42,9.5},{42,-9.5}},
                  lineColor={184,0,0},
                  origin={13.5,38},
                  rotation=90,
                  textString="effect"),
                Line(
                  points={{-80,75},{-80,-75}},
                  color={0,0,0},
                  thickness=0.5),
                Line(
                  points={{80,75},{80,-75}},
                  color={0,0,0},
                  thickness=0.5),
                Text(
                  extent={{-91,37},{-91,10}},
                  lineColor={184,0,0},
                  lineThickness=0.5,
                  fillColor={235,235,235},
                  fillPattern=FillPattern.Solid,
                  textString="a"),
                Text(
                  extent={{91,37},{91,10}},
                  lineColor={184,0,0},
                  lineThickness=0.5,
                  fillColor={235,235,235},
                  fillPattern=FillPattern.Solid,
                  textString="b"),
                Text(
                  extent={{18,101},{18,74}},
                  lineColor={184,0,0},
                  lineThickness=0.5,
                  fillColor={235,235,235},
                  fillPattern=FillPattern.Solid,
                  textString="c")}),
            Diagram(coordinateSystem(
                preserveAspectRatio=true,
                extent={{-100,-100},{100,100}},
                grid={1,1}), graphics),
            Documentation(info="<HTML>
<p>
This is a model for transport of heat without storing it.
It may be used for complicated geometries where
the thermal conductance G (= inverse of thermal resistance)
is determined by measurements and is assumed to be constant
over the range of operations. If the component consists mainly of
one type of material and a regular geometry, it may be calculated,
e.g., with one of the following equations:
</p>
<ul>
<li><p>
    Conductance for a <b>box</b> geometry under the assumption
    that heat flows along the box length:</p>
    <pre>
    G = k*A/L
    k: Thermal conductivity (material constant)
    A: Area of box
    L: Length of box
    </pre>
    </li>
<li><p>
    Conductance for a <b>cylindrical</b> geometry under the assumption
    that heat flows from the inside to the outside radius
    of the cylinder:</p>
    <pre>
    G = 2*pi*k*L/log(r_out/r_in)
    pi   : Modelica.Constants.pi
    k    : Thermal conductivity (material constant)
    L    : Length of cylinder
    log  : Modelica.Math.log;
    r_out: Outer radius of cylinder
    r_in : Inner radius of cylinder
    </pre>
    </li>
</li>
</ul>
<pre>
    Typical values for k at 20 degC in W/(m.K):
      aluminium   220
      concrete      1
      copper      384
      iron         74
      silver      407
      steel        45 .. 15 (V2A)
      wood         0.1 ... 0.2
</pre>
</HTML>
"));
        end PeltierHeatFlow;

        model VarResistor_Heat
          "Temperature-dependent electrical resistor with heat port"

          //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

          extends Base_Components.Connectors.OnePort;

          //**Begin helper interface for spatial discretized model****
          Integer ID_rho_el;
          Modelica.Blocks.Interfaces.IntegerInput ID_rho_el_input=ID_rho_el if
            ID_extern_given;
          parameter Boolean ID_extern_given=false;
          // if model is used in a spatial discretized model (e.g TE_Leg) tables are initialized in outer model and ID_rho_el is given by integer input ID_rho_input
          //**End helper interface************************************

          String Table_rho_el="NoName" annotation (dialog(enable=true));
          String File_rho_el="NoName" annotation (dialog(enable=true));
          Real rho_el_values[:, 2]={{0,0}} annotation (dialog(enable=true));

          Modelica.SIunits.Resistivity rho_el
            "(Variable) electrical resistivity";
          Modelica.SIunits.Resistance R "(Variable) electrical resistance";
          parameter Modelica.SIunits.Length L=0.01 "Length";
          parameter Modelica.SIunits.Area A=1 "Cross section area";

          Modelica.SIunits.Power LossPower "Heat flow produced by resister";

          Base_Components.Connectors.HeatPort_a
                          heatPort annotation (Placement(transformation(extent={{-4,
                    -102},{16,-82}}), iconTransformation(extent={{-10,-100},{10,-80}})));

        equation
          when initial() then
            if not ID_extern_given then
              ID_rho_el = Base_Components.Functions.tableInit(
                    Table_rho_el,
                    File_rho_el,
                    rho_el_values,
                    1);
            end if;
          end when;

          rho_el = Base_Components.Functions.Interpolation_2(
                ID_rho_el,
                heatPort.T,
                false,
                rho_el_values);

          R = rho_el*L/A;
          v = R*i;
          LossPower = v*i;
          heatPort.Q_flow = -LossPower;

          annotation (
            Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>  
**************************************************************************** <p>
</html>
"),         Documentation(info="<HTML>
<P>
The linear resistor connects the branch voltage <i>v</i> with the
branch current <i>i</i> by <i>i*R = v</i>.
The Resistance <i>R</i> is allowed to be positive, zero, or negative.
</P>
</HTML>
",       revisions=
                 "<html>
<ul>
<li><i> August 07, 2009   </i>
       by Anton Haumer<br> temperature dependency of resistance added<br>
       </li>
<li><i> March 11, 2009   </i>
       by Christoph Clauss<br> conditional heat port added<br>
       </li>
<li><i> 1998   </i>
       by Christoph Clauss<br> initially implemented<br>
       </li>
</ul>
</html>"),  Icon(coordinateSystem(
                preserveAspectRatio=true,
                extent={{-100,-100},{100,100}},
                grid={2,2}), graphics={
                Rectangle(
                  extent={{-70,30},{70,-30}},
                  lineColor={0,0,255},
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid),
                Line(points={{-90,0},{-70,0}}, color={0,0,255}),
                Line(points={{70,0},{90,0}}, color={0,0,255}),
                Text(
                  extent={{0,-34},{0,-74}},
                  lineColor={0,0,0},
                  textString="R=%R"),
                Line(
                  visible=useHeatPort,
                  points={{0,-100},{0,-30}},
                  color={127,0,0},
                  smooth=Smooth.None,
                  pattern=LinePattern.Dot),
                Text(
                  extent={{0,78},{0,35}},
                  textString="%name",
                  lineColor={0,0,255})}),
            Diagram(coordinateSystem(
                preserveAspectRatio=true,
                extent={{-100,-100},{100,100}},
                grid={2,2}), graphics={
                Rectangle(extent={{-70,30},{70,-30}}, lineColor={0,0,255}),
                Line(points={{-96,0},{-70,0}}, color={0,0,255}),
                Line(points={{70,0},{96,0}}, color={0,0,255})}));
        end VarResistor_Heat;

        model VarGain

          //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

          Real k=1 annotation (dialog(enable=true));
          Modelica.Blocks.Interfaces.RealInput u annotation (Placement(
                transformation(extent={{-120,-30},{-80,10}}), iconTransformation(
                  extent={{-100,-10},{-80,10}})));
          Modelica.Blocks.Interfaces.RealOutput y annotation (Placement(
                transformation(extent={{80,-10},{100,10}}), iconTransformation(
                  extent={{80,-10},{100,10}})));
        equation

          y = k*u;

          annotation (
            Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),         Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},
                    {100,100}}), graphics),
            Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
                    100,100}}), graphics={Polygon(
                  points={{-80,-80},{-80,80},{80,0},{-80,-80}},
                  lineColor={0,0,127},
                  fillColor={255,255,255},
                  fillPattern=FillPattern.Solid), Text(
                  extent={{-80,18},{78,-8}},
                  lineColor={0,0,255},
                  pattern=LinePattern.Dash,
                  lineThickness=0.5,
                  fillColor={193,0,0},
                  fillPattern=FillPattern.Solid,
                  textString="Var. gain")}));
        end VarGain;

        model TE_Voltage
          "Calculation of thermoelectric voltage from temperature interval [T_a, T_b]"

          //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

          //**Begin helper interface for spatial discretized model****
          Integer ID_Int_alpha;
          Modelica.Blocks.Interfaces.IntegerInput ID_Int_alpha_input=ID_Int_alpha if
            ID_extern_given;
          parameter Boolean ID_extern_given=false;
          // if model is used in a spatial discretized model (e.g TE_Leg) tables are initialized in outer model and ID_rho_el is given by integer input ID_rho_input
          //**End helper interface************************************

          String Table_Int_alpha="NoName" annotation (dialog(enable=true));
          String File_Int_alpha="NoName" annotation (dialog(enable=true));
          Real Int_alpha_values[:, 2]={{0,0}} annotation (dialog(enable=true));

          parameter Integer N_TE=1
            "if concatenation is modeled: Number of TE (of the same type) at identical temperature (el. in series, thermally in parallel)";

          Modelica.Blocks.Interfaces.RealInput T_a annotation (Placement(
                transformation(
                extent={{-20,-20},{20,20}},
                rotation=90,
                origin={-60,-94}), iconTransformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={-37,-90})));
          Modelica.Blocks.Interfaces.RealOutput dU_th annotation (Placement(
                transformation(extent={{86,10},{106,30}}), iconTransformation(
                extent={{-10.5,-10.5},{10.5,10.5}},
                rotation=90,
                origin={-2.5,91.5})));
          Modelica.Blocks.Interfaces.RealInput T_b annotation (Placement(
                transformation(
                extent={{-20,-20},{20,20}},
                rotation=90,
                origin={60,-94}), iconTransformation(
                extent={{-10,-10},{10,10}},
                rotation=90,
                origin={40,-90})));

        equation
          when initial() then

            if not ID_extern_given then
              ID_Int_alpha = Base_Components.Functions.tableInit(
                    Table_Int_alpha,
                    File_Int_alpha,
                    Int_alpha_values,
                    1);
            end if;
          end when;

          -dU_th = N_TE*Base_Components.Functions.Interpolation_2(
                ID_Int_alpha,
                T_b,
                false,
                Int_alpha_values) - N_TE*Base_Components.Functions.Interpolation_2(
                ID_Int_alpha,
                T_a,
                false,
                Int_alpha_values);

          annotation (
            Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),         Diagram(coordinateSystem(
                preserveAspectRatio=true,
                extent={{-110,-100},{110,100}},
                grid={1,1}), graphics),
            Icon(coordinateSystem(
                preserveAspectRatio=true,
                extent={{-110,-100},{110,100}},
                grid={1,1}), graphics={
                Rectangle(
                  extent={{-110,80},{110,-79}},
                  lineColor={0,0,255},
                  fillPattern=FillPattern.HorizontalCylinder),
                Rectangle(
                  extent={{-110,37},{110,-100}},
                  lineColor={0,0,255},
                  fillPattern=FillPattern.HorizontalCylinder,
                  fillColor={184,0,0}),
                Text(
                  extent={{-58,-37},{-58,-77}},
                  lineColor={255,255,255},
                  fillPattern=FillPattern.Solid,
                  textString="T_a"),
                Text(
                  extent={{58,-36},{58,-77}},
                  lineColor={255,255,255},
                  fillPattern=FillPattern.Solid,
                  textString="T_b"),
                Text(
                  extent={{3,20},{3,-34}},
                  textString="%name",
                  lineColor={0,0,255}),
                Text(
                  extent={{-1,77},{-1,35}},
                  lineColor={255,255,255},
                  fillPattern=FillPattern.Solid,
                  fillColor={0,0,255},
                  textString="dU_th"),
                Rectangle(
                  extent={{-110,-80},{110,-100}},
                  fillPattern=FillPattern.Solid,
                  fillColor={255,255,255},
                  pattern=LinePattern.None,
                  lineColor={0,0,0}),
                Rectangle(
                  extent={{-110,100},{110,80}},
                  fillPattern=FillPattern.Solid,
                  fillColor={255,255,255},
                  pattern=LinePattern.None,
                  lineColor={0,0,0})}));
        end TE_Voltage;
      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));
      end Base_Components;

      model ThermoelectricElement
        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

        //**Begin helper interface for spatial discretized model

        parameter Boolean ID_extern_given=false;

        Modelica.Blocks.Interfaces.IntegerInput ID_rho_el_input=ID_rho_el if
          ID_extern_given;
        Modelica.Blocks.Interfaces.IntegerInput ID_lambda_input=ID_lambda if
          ID_extern_given;
        Modelica.Blocks.Interfaces.IntegerInput ID_alpha_input=ID_alpha if
          ID_extern_given;

        Integer ID_rho_el;
        Integer ID_lambda;
        Integer ID_alpha;

        // if model is used in a spatial discretized model (e.g TE_Leg) tables are initialized in outer model and ID is given by integer_input
        //**End helper interface************************************

        parameter String Type="" "Indicate doping type (p/n) on component icon"
          annotation (choices(choice="p-type" "p-type", choice="n-type" "n-type"));

        replaceable
          ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase
          Material "Select material from database"
          annotation (dialog(enable=true), choicesAllMatching=true);

        parameter Integer N_TE=1
          "if concatenation is modeled: Number of TE (of the same type) at identical temperature (el. in series, thermally in parallel)";

        String dummy="noName";

        Base_Components.ThermalConductor heatCond_1(
          lambda_values=Material.lambda,
          L=L/2,
          A=N_TE*A,
          ID_extern_given=true)
          annotation (Placement(transformation(extent={{-53,13},{-28,38}})));
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCap(T(
              displayUnit="K", start=T_0), C=Material.c*m) annotation (Placement(
              transformation(
              extent={{-13,-13},{13,13}},
              rotation=270,
              origin={12,1})));
        Base_Components.ThermalConductor heatCond_2(
          lambda_values=Material.lambda,
          L=L/2,
          A=N_TE*A,
          ID_extern_given=true)
          annotation (Placement(transformation(extent={{-1,13},{24,38}})));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a annotation (
            Placement(transformation(extent={{-96,-9},{-75,12}}),
              iconTransformation(extent={{-89,-60},{-69,-40}})));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b annotation (
            Placement(transformation(extent={{45,-9},{66,12}}),
              iconTransformation(extent={{70,-60},{90,-40}})));
        ThermoelectricGenerator_V5_7.Inner_TEG.Components_for_TEL.Base_Components.VarResistor_Heat
          elecResistor(
          rho_el_values=Material.rho_el,
          L=N_TE*L,
          A=A,
          ID_extern_given=true)
          annotation (Placement(transformation(extent={{-30,65},{0,95}})));
        Modelica.Electrical.Analog.Sensors.CurrentSensor current annotation (
            Placement(transformation(
              extent={{-14,-14},{14,14}},
              rotation=0,
              origin={27,80})));
        Modelica.Electrical.Analog.Interfaces.NegativePin n "negative pin"
          annotation (Placement(transformation(extent={{43,68},{67,92}}),
              iconTransformation(extent={{70,40},{90,60}})));
        Modelica.Electrical.Analog.Interfaces.PositivePin p
          "Positive pin (potential p.v > n.v for positive voltage drop v)"
          annotation (Placement(transformation(extent={{-98,67},{-72,93}}),
              iconTransformation(extent={{-89,38},{-69,58}})));

        parameter Modelica.SIunits.Area A=1 "Cross section area";
        parameter Modelica.SIunits.Thickness L=0.01
          "Thickness of thermoelement";
        parameter Boolean ThomsonEffect=true "Activate Thomson Effect";

        parameter Modelica.SIunits.Mass m=N_TE*Material.rho*L*A "Mass";

      public
        parameter Modelica.SIunits.Temperature T_0=295.15
          "Initial avg temperature of element";
        Modelica.Electrical.Analog.Sources.SignalVoltage dU_th annotation (
            Placement(transformation(
              extent={{-16,-16},{16,16}},
              rotation=180,
              origin={-57,80})));
        Modelica.Thermal.HeatTransfer.Sensors.RelTemperatureSensor tempDiff
          annotation (Placement(transformation(extent={{-22,-51},{-3,-70}})));
        Base_Components.PeltierHeatFlow peltierHeatFlow(
          alpha_values=Material.alpha,
          N_TE=N_TE,
          ThomsonEffect=ThomsonEffect,
          ID_extern_given=true)
          annotation (Placement(transformation(extent={{-30,-43},{4,-9}})));
        Base_Components.VarGain varGain(k=N_TE*(peltierHeatFlow.alpha_b +
              peltierHeatFlow.alpha_a)/2) annotation (Placement(transformation(
              extent={{-7.5,-8},{7.5,8}},
              rotation=90,
              origin={-57,54.5})));

      equation
        when initial() then
          if not ID_extern_given then
            ID_rho_el = Base_Components.Functions.tableInit(
                    dummy,
                    dummy,
                    Material.rho_el,
                    1);
            //dummy parameter "no name" will be removed if "extern tables" in MaterialData.MaterialBase is supported
            ID_lambda = Base_Components.Functions.tableInit(
                    dummy,
                    dummy,
                    Material.lambda,
                    1);
            ID_alpha = Base_Components.Functions.tableInit(
                    dummy,
                    dummy,
                    Material.alpha,
                    1);

          end if;

        end when;

        // "connect" ID_inputs of underlaid models"
        heatCond_1.ID_lambda_input = ID_lambda;
        heatCond_2.ID_lambda_input = ID_lambda;
        peltierHeatFlow.ID_alpha_input = ID_alpha;
        elecResistor.ID_rho_el_input = ID_rho_el;

        connect(elecResistor.n, current.p) annotation (Line(
            points={{0,80},{13,80}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(current.n, n) annotation (Line(
            points={{41,80},{55,80}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(dU_th.n, p) annotation (Line(
            points={{-73,80},{-85,80}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(dU_th.p, elecResistor.p) annotation (Line(
            points={{-41,80},{-30,80}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(heatCond_2.port_b, port_b) annotation (Line(
            points={{24,25.5},{37,25.5},{37,1.5},{55.5,1.5}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(heatCond_1.port_a, port_a) annotation (Line(
            points={{-53,25.5},{-66,25.5},{-66,1.5},{-85.5,1.5}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(heatCond_1.port_b, heatCond_2.port_a) annotation (Line(
            points={{-28,25.5},{-1,25.5}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(heatCond_1.port_b, peltierHeatFlow.port_c) annotation (Line(
            points={{-28,25.5},{-13.51,25.5},{-13.51,-11.55}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(heatCap.port, peltierHeatFlow.port_c) annotation (Line(
            points={{-1,1},{-13.51,1},{-13.51,-11.55}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(elecResistor.heatPort, heatCap.port) annotation (Line(
            points={{-15,66.5},{-15,1},{-1,1}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(current.i, peltierHeatFlow.i) annotation (Line(
            points={{27,66},{27,53},{42,53},{42,-45},{-13,-45},{-13,-40.45}},
            color={0,0,255},
            smooth=Smooth.None,
            pattern=LinePattern.Dash));
        connect(varGain.y, dU_th.v) annotation (Line(
            points={{-57,61.25},{-57,68.8}},
            color={0,0,255},
            pattern=LinePattern.Dash,
            smooth=Smooth.None));
        connect(varGain.u, tempDiff.T_rel) annotation (Line(
            points={{-57,47.75},{-57,44},{-71,44},{-71,-49},{-12.5,-49},{-12.5,-51.95}},
            color={184,0,0},
            pattern=LinePattern.Dash,
            smooth=Smooth.None));

        connect(tempDiff.port_b, port_b) annotation (Line(
            points={{-3,-60.5},{47,-60.5},{47,1.5},{55.5,1.5}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(peltierHeatFlow.port_b, port_b) annotation (Line(
            points={{2.3,-26},{37,-26},{37,1.5},{55.5,1.5}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(tempDiff.port_a, port_a) annotation (Line(
            points={{-22,-60.5},{-22,-60},{-76,-60},{-76,1.5},{-85.5,1.5}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(peltierHeatFlow.port_a, port_a) annotation (Line(
            points={{-28.3,-26},{-66,-26},{-66,1.5},{-85.5,1.5}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        annotation (
          Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"),       Diagram(coordinateSystem(
              preserveAspectRatio=false,
              extent={{-100,-100},{100,100}},
              grid={1,1})),
          Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics={
              Rectangle(
                extent={{-69,82},{70,-85}},
                lineColor={0,0,0},
                fillPattern=FillPattern.Solid,
                fillColor={215,215,215}),
              Text(
                extent={{5,39},{5,2}},
                lineColor={255,255,255},
                fillColor={255,128,0},
                fillPattern=FillPattern.Solid,
                textString="%Type"),
              Text(
                extent={{-53,63},{54,35}},
                lineColor={0,0,255},
                fillPattern=FillPattern.Solid,
                textString="electric"),
              Text(
                extent={{-47,-36},{46,-64}},
                lineColor={184,0,0},
                fillPattern=FillPattern.Solid,
                textString="thermal"),
              Line(
                points={{-73,-50},{-68,-50},{-65,-48},{-62,-48},{-58,-53},{-55,-53},
                    {-52,-50},{-40,-50},{-51,-44},{-40,-50},{-51,-57}},
                color={184,0,0},
                smooth=Smooth.None),
              Line(
                points={{38,-51},{43,-51},{46,-49},{49,-49},{53,-54},{56,-54},{59,
                    -51},{71,-51},{59,-44},{71,-51},{59,-58}},
                color={184,0,0},
                smooth=Smooth.None)}));
      end ThermoelectricElement;

      model ThermoelectricElement_Int_alpha
        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

        //**Begin helper interface for spatial discretized model
        Modelica.Blocks.Interfaces.IntegerInput ID_rho_el_input=ID_rho_el if
          ID_extern_given;
        Modelica.Blocks.Interfaces.IntegerInput ID_lambda_input=ID_lambda if
          ID_extern_given;
        Modelica.Blocks.Interfaces.IntegerInput ID_alpha_input=ID_alpha if
          ID_extern_given;
        Modelica.Blocks.Interfaces.IntegerInput ID_Int_alpha_input=ID_Int_alpha if
             ID_extern_given;

        Integer ID_rho_el;
        Integer ID_lambda;
        Integer ID_alpha;
        Integer ID_Int_alpha;

        parameter Boolean ID_extern_given=false;
        // if model is used in a spatial discretized model (e.g TE_Leg) tables are initialized in outer model and ID is given by integer_input
        //**End helper interface************************************

        parameter String Type="" "Indicate doping type (p/n) on component icon"
          annotation (choices(choice="p-type" "p-type", choice="n-type" "n-type"));

        replaceable
          ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase
          Material "Select material from database"
          annotation (choicesAllMatching=true);

        parameter Integer N_TE=1
          "if concatenation is modeled: Number of TE (of the same type) at identical temperature (el. in series, thermally in parallel)";

        String dummy="NoName";

        Base_Components.ThermalConductor heatCond_1(
          lambda_values=Material.lambda,
          L=L/2,
          A=N_TE*A,
          ID_extern_given=true)
          annotation (Placement(transformation(extent={{-38,-19},{-13,6}})));
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCap(T(
              displayUnit="K", start=T_0), C=Material.c*m) annotation (Placement(
              transformation(
              extent={{-13,-13},{13,13}},
              rotation=270,
              origin={27,-31})));
        Base_Components.ThermalConductor heatCond_2(
          lambda_values=Material.lambda,
          L=L/2,
          A=N_TE*A,
          ID_extern_given=true)
          annotation (Placement(transformation(extent={{14,-19},{39,6}})));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a annotation (
            Placement(transformation(extent={{-81,-42},{-60,-21}}),
              iconTransformation(extent={{-89,-60},{-69,-40}})));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b annotation (
            Placement(transformation(extent={{60,-42},{81,-21}}),
              iconTransformation(extent={{70,-60},{90,-40}})));
        ThermoelectricGenerator_V5_7.Inner_TEG.Components_for_TEL.Base_Components.VarResistor_Heat
          elecResistor(
          rho_el_values=Material.rho_el,
          L=N_TE*L,
          A=A,
          ID_extern_given=true)
          annotation (Placement(transformation(extent={{-14,54},{16,84}})));
        Modelica.Electrical.Analog.Sensors.CurrentSensor current annotation (
            Placement(transformation(
              extent={{-14,-14},{14,14}},
              rotation=0,
              origin={38,69})));
        Modelica.Electrical.Analog.Interfaces.NegativePin n "negative pin"
          annotation (Placement(transformation(extent={{58,57},{82,81}}),
              iconTransformation(extent={{70,40},{90,60}})));
        Modelica.Electrical.Analog.Interfaces.PositivePin p
          "Positive pin (potential p.v > n.v for positive voltage drop v)"
          annotation (Placement(transformation(extent={{-83,56},{-57,82}}),
              iconTransformation(extent={{-89,38},{-69,58}})));

        parameter Modelica.SIunits.Area A=1 "Cross section area";
        parameter Modelica.SIunits.Thickness L=0.01
          "Thickness of thermoelement";
        parameter Boolean ThomsonEffect=true "Activate Thomson Effect";

        parameter Modelica.SIunits.Mass m=N_TE*Material.rho*L*A "Mass";

      public
        parameter Modelica.SIunits.Temperature T_0=295.15
          "Initial avg temperature of element";
        Modelica.Electrical.Analog.Sources.SignalVoltage dU_th annotation (
            Placement(transformation(
              extent={{-16,-16},{16,16}},
              rotation=180,
              origin={-38,69})));
        Base_Components.PeltierHeatFlow peltierHeatFlow(
          alpha_values=Material.alpha,
          N_TE=N_TE,
          ThomsonEffect=ThomsonEffect,
          ID_extern_given=true)
          annotation (Placement(transformation(extent={{-17,-78},{19,-42}})));

        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor T_a annotation (
            Placement(transformation(
              extent={{-8,-8},{8,8}},
              rotation=0,
              origin={-53,20})));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor T_b
          annotation (Placement(transformation(extent={{56,12},{40,28}})));
        ThermoelectricGenerator_V5_7.Inner_TEG.Components_for_TEL.Base_Components.TE_Voltage
          TE_Voltage(
          Int_alpha_values=Material.Int_alpha,
          N_TE=N_TE,
          ID_extern_given=true)
          annotation (Placement(transformation(extent={{-49,30},{-26,51}})));

      equation
        when initial() then
          if not ID_extern_given then
            ID_rho_el = Base_Components.Functions.tableInit(
                    dummy,
                    dummy,
                    Material.rho_el,
                    1);
            //dummy parameter "NoName" will be removed if "extern tables" in MaterialData.MaterialBase is supported
            ID_lambda = Base_Components.Functions.tableInit(
                    dummy,
                    dummy,
                    Material.lambda,
                    1);
            ID_alpha = Base_Components.Functions.tableInit(
                    dummy,
                    dummy,
                    Material.alpha,
                    1);
            ID_Int_alpha = Base_Components.Functions.tableInit(
                    dummy,
                    dummy,
                    Material.Int_alpha,
                    1);
          end if;

        end when;

        // "connect" ID_inputs of underlaid models"
        heatCond_1.ID_lambda_input = ID_lambda;
        heatCond_2.ID_lambda_input = ID_lambda;
        TE_Voltage.ID_Int_alpha_input = ID_Int_alpha;
        peltierHeatFlow.ID_alpha_input = ID_alpha;
        elecResistor.ID_rho_el_input = ID_rho_el;

        connect(elecResistor.n, current.p) annotation (Line(
            points={{16,69},{24,69}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(current.n, n) annotation (Line(
            points={{52,69},{70,69}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(dU_th.n, p) annotation (Line(
            points={{-54,69},{-70,69}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(dU_th.p, elecResistor.p) annotation (Line(
            points={{-22,69},{-14,69}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(heatCond_2.port_b, port_b) annotation (Line(
            points={{39,-6.5},{51,-6.5},{51,-31.5},{70.5,-31.5}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(heatCond_1.port_a, port_a) annotation (Line(
            points={{-38,-6.5},{-48,-6.5},{-48,-31.5},{-70.5,-31.5}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(heatCond_1.port_b, heatCond_2.port_a) annotation (Line(
            points={{-13,-6.5},{1,-7},{1,-6.5},{14,-6.5}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(heatCond_1.port_b, peltierHeatFlow.port_c) annotation (Line(
            points={{-13,-6.5},{0.46,-6.5},{0.46,-44.7}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(heatCap.port, peltierHeatFlow.port_c) annotation (Line(
            points={{14,-31},{0.46,-31},{0.46,-44.7}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(elecResistor.heatPort, heatCap.port) annotation (Line(
            points={{1,55.5},{1,-31},{14,-31}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(current.i, peltierHeatFlow.i) annotation (Line(
            points={{38,55},{38,51},{61,51},{61,-80},{1,-80},{1,-75.3}},
            color={0,0,255},
            smooth=Smooth.None,
            pattern=LinePattern.Dash));
        connect(peltierHeatFlow.port_b, port_b) annotation (Line(
            points={{17.2,-60},{51,-60},{51,-31.5},{70.5,-31.5}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(peltierHeatFlow.port_a, port_a) annotation (Line(
            points={{-15.2,-60},{-48,-60},{-48,-31.5},{-70.5,-31.5}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(T_b.port, port_b) annotation (Line(
            points={{56,20},{56,-31.5},{70.5,-31.5}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(TE_Voltage.dU_th, dU_th.v) annotation (Line(
            points={{-37.7614,50.1075},{-37.7614,56},{-38,56},{-38,57.8}},
            color={0,0,127},
            smooth=Smooth.None,
            pattern=LinePattern.Dash));
        connect(T_a.T, TE_Voltage.T_a) annotation (Line(
            points={{-45,20},{-41,20},{-41,31.05},{-41.3682,31.05}},
            color={184,0,0},
            smooth=Smooth.None,
            pattern=LinePattern.Dash));
        connect(T_b.T, TE_Voltage.T_b) annotation (Line(
            points={{40,20},{-33.3182,20},{-33.3182,31.05}},
            color={184,0,0},
            smooth=Smooth.None,
            pattern=LinePattern.Dash));
        connect(T_a.port, port_a) annotation (Line(
            points={{-61,20},{-61,-31.5},{-70.5,-31.5}},
            color={191,0,0},
            smooth=Smooth.None));
        annotation (
          Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"),       Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics),
          Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics={
              Rectangle(
                extent={{-69,82},{70,-85}},
                lineColor={0,0,0},
                fillPattern=FillPattern.Solid,
                fillColor={215,215,215}),
              Text(
                extent={{5,39},{5,2}},
                lineColor={255,255,255},
                fillColor={255,128,0},
                fillPattern=FillPattern.Solid,
                textString="%Type"),
              Text(
                extent={{-53,63},{54,35}},
                lineColor={0,0,255},
                fillPattern=FillPattern.Solid,
                textString="electric"),
              Text(
                extent={{-47,-36},{46,-64}},
                lineColor={184,0,0},
                fillPattern=FillPattern.Solid,
                textString="thermal"),
              Line(
                points={{-73,-50},{-68,-50},{-65,-48},{-62,-48},{-58,-53},{-55,-53},
                    {-52,-50},{-40,-50},{-51,-44},{-40,-50},{-51,-57}},
                color={184,0,0},
                smooth=Smooth.None),
              Line(
                points={{38,-51},{43,-51},{46,-49},{49,-49},{53,-54},{56,-54},{59,
                    -51},{71,-51},{59,-44},{71,-51},{59,-58}},
                color={184,0,0},
                smooth=Smooth.None)}));
      end ThermoelectricElement_Int_alpha;

      model ThermoelectricElement_STATIC
        "No heat storage, material porperties based on avg. temperature"
        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

        //**Begin helper interface for spatial discretized model
        Modelica.Blocks.Interfaces.IntegerInput ID_rho_el_input=ID_rho_el if
          ID_extern_given;
        Modelica.Blocks.Interfaces.IntegerInput ID_lambda_input=ID_lambda if
          ID_extern_given;
        Modelica.Blocks.Interfaces.IntegerInput ID_alpha_input=ID_alpha if
          ID_extern_given;

        Integer ID_rho_el;
        Integer ID_lambda;
        Integer ID_alpha;

        parameter Boolean ID_extern_given=false;
        // if model is used in a spatial discretized model (e.g TE_Leg) tables are initialized in outer model and ID is given by integer_input
        //**End helper interface************************************

        parameter String Type="" "Indicate doping type (p/n) on component icon"
          annotation (choices(choice="p-type" "p-type", choice="n-type" "n-type"));

        replaceable
          ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase
          Material "Select material from database"
          annotation (dialog(enable=true), choicesAllMatching=true);

        parameter Integer N_TE=1
          "if concatenation is modeled: Number of TE (of the same type) at identical temperature (el. in series, thermally in parallel)";

        String dummy="NoName";

        parameter Boolean ThomsonEffect=false "Activate Thomson Effect";

        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a annotation (
            Placement(transformation(extent={{-96,-9},{-75,12}}),
              iconTransformation(extent={{-89,-60},{-69,-40}})));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b annotation (
            Placement(transformation(extent={{45,-9},{66,12}}),
              iconTransformation(extent={{70,-60},{90,-40}})));
        ThermoelectricGenerator_V5_7.Inner_TEG.Components_for_TEL.Base_Components.VarResistor_Heat
          elecResistor(
          rho_el_values=Material.rho_el,
          L=N_TE*L,
          A=A,
          ID_extern_given=true)
          annotation (Placement(transformation(extent={{-29,65},{1,95}})));
        Modelica.Electrical.Analog.Sensors.CurrentSensor current annotation (
            Placement(transformation(
              extent={{-14,-14},{14,14}},
              rotation=0,
              origin={27,80})));
        Modelica.Electrical.Analog.Interfaces.NegativePin n "negative pin"
          annotation (Placement(transformation(extent={{43,68},{67,92}}),
              iconTransformation(extent={{70,40},{90,60}})));
        Modelica.Electrical.Analog.Interfaces.PositivePin p
          "Positive pin (potential p.v > n.v for positive voltage drop v)"
          annotation (Placement(transformation(extent={{-98,67},{-72,93}}),
              iconTransformation(extent={{-89,38},{-69,58}})));

        parameter Modelica.SIunits.Area A=1 "Cross section area";
        parameter Modelica.SIunits.Thickness L=0.01
          "Thickness of thermoelement";
        parameter Modelica.SIunits.Mass m=N_TE*Material.rho*L*A "Mass";

        Real lambda;

      public
        parameter Modelica.SIunits.Temperature T_0=295.15
          "Initial avg temperature of element";
        Modelica.Electrical.Analog.Sources.SignalVoltage dU_th annotation (
            Placement(transformation(
              extent={{-16,-16},{16,16}},
              rotation=180,
              origin={-57,80})));
        Modelica.Thermal.HeatTransfer.Sensors.RelTemperatureSensor tempDiff
          annotation (Placement(transformation(extent={{-23,-51},{-4,-70}})));
        Base_Components.PeltierHeatFlow peltierHeatFlow(
          alpha_values=Material.alpha,
          N_TE=N_TE,
          ThomsonEffect=ThomsonEffect,
          ID_extern_given=true)
          annotation (Placement(transformation(extent={{-30,-43},{4,-9}})));
        Base_Components.VarGain varGain(k=N_TE*peltierHeatFlow.alpha_c)
                                                                   annotation (
            Placement(transformation(
              extent={{-7.5,-8},{7.5,8}},
              rotation=90,
              origin={-57,54.5})));

        Base_Components.ThermalConductor_STATIC heatCond_1(G=N_TE*A*lambda/(L/2))
          annotation (Placement(transformation(extent={{-50,13},{-28,35}})));
        Base_Components.ThermalConductor_STATIC heatCond_2(G=N_TE*A*lambda/(L/2))
          annotation (Placement(transformation(extent={{-4,13},{18,35}})));
      equation
        when initial() then

          if not ID_extern_given then
            ID_lambda = Base_Components.Functions.tableInit(
                    dummy,
                    dummy,
                    Material.lambda,
                    1);
            //dummy parameter "NoName" will be removed if "extern tables" in MaterialData.MaterialBase is supported
            ID_rho_el = Base_Components.Functions.tableInit(
                    dummy,
                    dummy,
                    Material.rho_el,
                    1);
            ID_alpha = Base_Components.Functions.tableInit(
                    dummy,
                    dummy,
                    Material.alpha,
                    1);

          end if;

        end when;

        lambda = Base_Components.Functions.Interpolation_2(
                ID_lambda,
                (port_a.T + port_b.T)/2,
                false,
                Material.lambda);

        // "connect" ID_inputs of underlaid models"
        elecResistor.ID_rho_el_input = ID_rho_el;
        peltierHeatFlow.ID_alpha_input = ID_alpha;

        connect(elecResistor.n, current.p) annotation (Line(
            points={{1,80},{13,80}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(current.n, n) annotation (Line(
            points={{41,80},{55,80}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(dU_th.n, p) annotation (Line(
            points={{-73,80},{-85,80}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(dU_th.p, elecResistor.p) annotation (Line(
            points={{-41,80},{-29,80}},
            color={0,0,255},
            smooth=Smooth.None,
            thickness=0.5));
        connect(current.i, peltierHeatFlow.i) annotation (Line(
            points={{27,66},{27,53},{42,53},{42,-45},{-13,-45},{-13,-40.45}},
            color={0,0,255},
            smooth=Smooth.None,
            pattern=LinePattern.Dash));
        connect(varGain.y, dU_th.v) annotation (Line(
            points={{-57,61.25},{-57,68.8}},
            color={0,0,255},
            pattern=LinePattern.Dash,
            smooth=Smooth.None));
        connect(varGain.u, tempDiff.T_rel) annotation (Line(
            points={{-57,47.75},{-57,44},{-71,44},{-71,-49},{-13.5,-49},{-13.5,-51.95}},
            color={184,0,0},
            pattern=LinePattern.Dash,
            smooth=Smooth.None));

        connect(tempDiff.port_b, port_b) annotation (Line(
            points={{-4,-60.5},{47,-60.5},{47,1.5},{55.5,1.5}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(peltierHeatFlow.port_b, port_b) annotation (Line(
            points={{2.3,-26},{37,-26},{37,1.5},{55.5,1.5}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(tempDiff.port_a, port_a) annotation (Line(
            points={{-23,-60.5},{-23,-60},{-76,-60},{-76,1.5},{-85.5,1.5}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(peltierHeatFlow.port_a, port_a) annotation (Line(
            points={{-28.3,-26},{-66,-26},{-66,1.5},{-85.5,1.5}},
            color={191,0,0},
            smooth=Smooth.None,
            thickness=0.5));
        connect(heatCond_2.port_b, port_b) annotation (Line(
            points={{18,24},{37,24},{37,1},{55.5,1},{55.5,1.5}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(heatCond_2.port_a, heatCond_1.port_b) annotation (Line(
            points={{-4,24},{-28,24}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(heatCond_1.port_a, port_a) annotation (Line(
            points={{-50,24},{-66,24},{-66,1.5},{-85.5,1.5}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(elecResistor.heatPort, heatCond_2.port_a) annotation (Line(
            points={{-14,66.5},{-15,66.5},{-15,24},{-4,24}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        connect(heatCond_2.port_a, peltierHeatFlow.port_c) annotation (Line(
            points={{-4,24},{-13.51,24},{-13.51,-11.55}},
            color={191,0,0},
            thickness=0.5,
            smooth=Smooth.None));
        annotation (
          Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"),       Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics),
          Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics={
              Rectangle(
                extent={{-69,82},{70,-85}},
                lineColor={0,0,0},
                fillPattern=FillPattern.Solid,
                fillColor={215,215,215}),
              Text(
                extent={{5,39},{5,2}},
                lineColor={255,255,255},
                fillColor={255,128,0},
                fillPattern=FillPattern.Solid,
                textString="%Type"),
              Text(
                extent={{-53,63},{54,35}},
                lineColor={0,0,255},
                fillPattern=FillPattern.Solid,
                textString="electric"),
              Text(
                extent={{-47,-36},{46,-64}},
                lineColor={184,0,0},
                fillPattern=FillPattern.Solid,
                textString="thermal"),
              Line(
                points={{-73,-50},{-68,-50},{-65,-48},{-62,-48},{-58,-53},{-55,-53},
                    {-52,-50},{-40,-50},{-51,-44},{-40,-50},{-51,-57}},
                color={184,0,0},
                smooth=Smooth.None),
              Line(
                points={{38,-51},{43,-51},{46,-49},{49,-49},{53,-54},{56,-54},{59,
                    -51},{71,-51},{59,-44},{71,-51},{59,-58}},
                color={184,0,0},
                smooth=Smooth.None)}),
          DymolaStoredErrors);
      end ThermoelectricElement_STATIC;

      model TE_Leg
        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

        //**ID for table initializiation, needed by underlaid components (helper interface)****
        Integer ID_rho_el;
        Integer ID_lambda;
        Integer ID_alpha;
        //**End ID***********************************************************

        String dummy="NoName";

        parameter String materialName "Name of material";

        replaceable
          ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_p_Thermonamic
          Material constrainedby
          ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase
          "Select material of A-legs (e.g a p-type material)"
          annotation (choicesAllMatching=true, dialog(group="Materials"));
        parameter Modelica.SIunits.Temperature T_0=295.15
          "Initial avg temperature of element";

        parameter Integer N_TE=1
          "if concatenation is modeled: Number of TE (of the same type) at identical temperature (el. in series, thermally in parallel)";

        parameter Integer S=1
          "Number of 1D spatial discretization steps within leg";
        parameter Modelica.SIunits.Area A=1 "Cross section area";
        parameter Modelica.SIunits.Thickness L=0.01
          "Thickness of thermoelement";
        parameter Boolean ThomsonEffect=true "Activate Thomson Effect";

        Modelica.Electrical.Analog.Interfaces.PositivePin p
          "Positive pin (potential p.v > n.v for positive voltage drop v)"
          annotation (Placement(transformation(extent={{-95,6},{-75,26}}),
              iconTransformation(extent={{-94,18.5},{-78,34.5}})));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_0 annotation (
            Placement(transformation(extent={{-94,-10.5},{-76,7.5}}),
              iconTransformation(extent={{-93.5,-17.5},{-78,-2}})));
        ThermoelectricElement TE[S](
          each Material=Material,
          each A=A,
          each N_TE=N_TE,
          each T_0=T_0,
          each L=L/S,
          each ThomsonEffect=ThomsonEffect,
          each ID_extern_given=true)
          annotation (Placement(transformation(extent={{-17,-11},{21,27}})));
        Modelica.Electrical.Analog.Interfaces.NegativePin n "negative pin"
          annotation (Placement(transformation(extent={{78,7},{98.5,27.5}}),
              iconTransformation(extent={{79,19},{94.5,34.5}})));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_L annotation (
            Placement(transformation(extent={{79.5,-10.5},{97,7}}),
              iconTransformation(extent={{79,-17.5},{94.5,-2}})));
      equation

        when initial() then
          ID_rho_el = Base_Components.Functions.tableInit(
                  dummy,
                  dummy,
                  Material.rho_el,
                  1);
          //dummy parameter "NoName" will be removed if "extern tables" in MaterialData.MaterialBase is supported
          ID_lambda = Base_Components.Functions.tableInit(
                  dummy,
                  dummy,
                  Material.lambda,
                  1);
          ID_alpha = Base_Components.Functions.tableInit(
                  dummy,
                  dummy,
                  Material.alpha,
                  1);
        end when;

        // "connect" ID_inputs of underlaid models
        for i in 1:S loop
          TE[i].ID_lambda_input = ID_lambda;
          TE[i].ID_alpha_input = ID_alpha;
          TE[i].ID_rho_el_input = ID_rho_el;
        end for;

        connect(TE[1].p, p);
        connect(TE[1].port_a, port_0);
        if S > 1 then
          for i in 1:(S - 1) loop
            connect(TE[i].n, TE[i + 1].p);
            connect(TE[i].port_b, TE[i + 1].port_a);
          end for;
        end if;
        connect(TE[S].n, n);
        connect(TE[S].port_b, port_L);
        annotation (
          Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),       dialog(enable=true),
          choicesAllMatching=true,
          Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={0.5,0.5}), graphics),
          Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={0.5,0.5}), graphics={
              Rectangle(
                extent={{-77.5,42.5},{78.5,-25.5}},
                lineColor={184,0,0},
                fillPattern=FillPattern.Solid,
                fillColor={235,235,235}),
              Line(
                points={{-76,-10},{-71,-10},{-68,-8},{-65,-8},{-61,-13},{-58,-13},
                    {-55,-10},{-43,-10},{-54,-4},{-43,-10},{-54,-17}},
                color={184,0,0},
                smooth=Smooth.None),
              Line(
                points={{44,-9.5},{49,-9.5},{52,-7.5},{55,-7.5},{59,-12.5},{62,-12.5},
                    {65,-9.5},{77,-9.5},{65,-2.5},{77,-9.5},{65,-16.5}},
                color={184,0,0},
                smooth=Smooth.None),
              Text(
                extent={{-77,19},{77.5,1}},
                lineColor={184,0,0},
                lineThickness=0.5,
                fillColor={235,235,235},
                fillPattern=FillPattern.Solid,
                textString="%materialName")}));
      end TE_Leg;

      model TE_Leg_Int_alpha
        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

        //**ID for table initializiation, needed by underlaid components (helper interface)****
        Integer ID_rho_el;
        Integer ID_lambda;
        Integer ID_alpha;
        Integer ID_Int_alpha;
        //**End ID***********************************************************

        String dummy="NoName";

        parameter String materialName "Name of material";

        replaceable
          ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.Bi2_Te3_p_Thermonamic
          Material constrainedby
          ThermoelectricGenerator_V5_7.Thermoelectric_Material_Data.MaterialBase
          "Select material of A-legs (e.g a p-type material)"
          annotation (choicesAllMatching=true, dialog(group="Materials"));
        parameter Modelica.SIunits.Temperature T_0=295.15
          "Initial avg temperature of element";

        parameter Integer N_TE=1
          "if concatenation is modeled: Number of TE (of the same type) at identical temperature (el. in series, thermally in parallel)";

        parameter Integer S=1
          "Number of 1D spatial discretization steps within leg";

        parameter Modelica.SIunits.Area A=1 "Cross section area";
        parameter Modelica.SIunits.Thickness L=0.01
          "Thickness of thermoelement";
        parameter Boolean ThomsonEffect=true "Activate Thomson Effect";

        Modelica.Electrical.Analog.Interfaces.PositivePin p
          "Positive pin (potential p.v > n.v for positive voltage drop v)"
          annotation (Placement(transformation(extent={{-95,6},{-75,26}}),
              iconTransformation(extent={{-94,18.5},{-78,34.5}})));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_0 annotation (
            Placement(transformation(extent={{-94,-10.5},{-76,7.5}}),
              iconTransformation(extent={{-93.5,-17.5},{-78,-2}})));
        ThermoelectricElement_Int_alpha TE[S](
          each Material=Material,
          each A=A,
          each N_TE=N_TE,
          each T_0=T_0,
          each L=L/S,
          each ThomsonEffect=ThomsonEffect,
          each ID_extern_given=true)
          annotation (Placement(transformation(extent={{-17,-11},{21,27}})));
        Modelica.Electrical.Analog.Interfaces.NegativePin n "negative pin"
          annotation (Placement(transformation(extent={{78,7},{98.5,27.5}}),
              iconTransformation(extent={{79,19},{94.5,34.5}})));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_L annotation (
            Placement(transformation(extent={{79.5,-10.5},{97,7}}),
              iconTransformation(extent={{79,-17.5},{94.5,-2}})));

      equation
        when initial() then
          ID_rho_el = Base_Components.Functions.tableInit(
                  dummy,
                  dummy,
                  Material.rho_el,
                  1);
          //dummy parameter "NoName" will be removed if "extern tables" in MaterialData.MaterialBase is supported
          ID_lambda = Base_Components.Functions.tableInit(
                  dummy,
                  dummy,
                  Material.lambda,
                  1);
          ID_alpha = Base_Components.Functions.tableInit(
                  dummy,
                  dummy,
                  Material.alpha,
                  1);
          ID_Int_alpha = Base_Components.Functions.tableInit(
                  dummy,
                  dummy,
                  Material.Int_alpha,
                  1);
        end when;

        // "connect" ID_inputs of underlaid models
        for i in 1:S loop
          TE[i].ID_lambda_input = ID_lambda;
          TE[i].ID_Int_alpha_input = ID_Int_alpha;
          TE[i].ID_alpha_input = ID_alpha;
          TE[i].ID_rho_el_input = ID_rho_el;
        end for;

        connect(TE[1].p, p);
        connect(TE[1].port_a, port_0);
        if S > 1 then
          for i in 1:(S - 1) loop
            connect(TE[i].n, TE[i + 1].p);
            connect(TE[i].port_b, TE[i + 1].port_a);
          end for;
        end if;
        connect(TE[S].n, n);
        connect(TE[S].port_b, port_L);
        annotation (
          Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"),       dialog(enable=true),
          choicesAllMatching=true,
          Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={0.5,0.5}), graphics),
          Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={0.5,0.5}), graphics={
              Rectangle(
                extent={{-77.5,42.5},{78.5,-25.5}},
                lineColor={184,0,0},
                fillPattern=FillPattern.Solid,
                fillColor={235,235,235}),
              Line(
                points={{-76,-10},{-71,-10},{-68,-8},{-65,-8},{-61,-13},{-58,-13},
                    {-55,-10},{-43,-10},{-54,-4},{-43,-10},{-54,-17}},
                color={184,0,0},
                smooth=Smooth.None),
              Line(
                points={{44,-9.5},{49,-9.5},{52,-7.5},{55,-7.5},{59,-12.5},{62,-12.5},
                    {65,-9.5},{77,-9.5},{65,-2.5},{77,-9.5},{65,-16.5}},
                color={184,0,0},
                smooth=Smooth.None),
              Text(
                extent={{-77,19},{77.5,1}},
                lineColor={184,0,0},
                lineThickness=0.5,
                fillColor={235,235,235},
                fillPattern=FillPattern.Solid,
                textString="%materialName")}));
      end TE_Leg_Int_alpha;
      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));
    end Components_for_TEL;

    package Components_for_leg_connection
      "components for CTEL model 'CTEL_1D_dyn_seq_intalpha_contact_res'"

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

    extends Modelica.Icons.BasesPackage;
      partial model Leg_connector_thermal_base
        "base class for the thermal leg connection"

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      replaceable
          ThermoelectricGenerator_V5_7.Packaging_Material_Data.MaterialBase Material
          constrainedby
          ThermoelectricGenerator_V5_7.Packaging_Material_Data.MaterialBase
          annotation (choicesAllMatching=true);

      parameter Integer N_TE=1 "Number of thermocouples";
      parameter Modelica.SIunits.Thickness Thickness "Thickness of connector";
      parameter Modelica.SIunits.Length Length
          "Length of Connector (~3*sqrt(cross section area of thermoelectric element))";
      parameter Modelica.SIunits.Breadth Breadth
          "Breadth of TEG (~3*sqrt(cross section area of thermoelectric element))";

        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a
          annotation (Placement(transformation(extent={{-110,-10},{-90,10}})));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b
          annotation (Placement(transformation(extent={{90,-10},{110,10}})));
      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2014 Chair of Automation, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),                 Icon(graphics={                   Rectangle(extent={{-100,28},{100,
                    -32}}, lineColor={95,95,95})}));
      end Leg_connector_thermal_base;

      partial model Leg_connector_electrical_base
        "base class for the electrical leg connection"

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends Modelica.Electrical.Analog.Interfaces.TwoPin;
      parameter Integer N_TE=1 "Number of thermocouples";
      parameter Modelica.SIunits.Thickness Thickness "Thickness of connector";
      parameter Modelica.SIunits.Length Length
          "Length connector (~3*sqrt(cross section area of thermoelectric element))";
      parameter Modelica.SIunits.Breadth Breadth
          "Breadth of TEG (~3*sqrt(cross section area of thermoelectric element))";
      Modelica.SIunits.Resistance overall_res "Overall resistance";
      replaceable
          ThermoelectricGenerator_V5_7.Packaging_Material_Data.MaterialBase Material
          constrainedby
          ThermoelectricGenerator_V5_7.Packaging_Material_Data.MaterialBase
          annotation (choicesAllMatching=true);

      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));
      end Leg_connector_electrical_base;

      model no_contact_and_no_wire_res
        "No contact resistance and no wire resistance"

        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends
          ThermoelectricGenerator_V5_7.Inner_TEG.Components_for_leg_connection.Leg_connector_electrical_base;

      equation
        overall_res=0;
        0 = p.i + n.i;
        p.v=n.v;

      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),                 Icon(graphics={Rectangle(extent={{-100,32},{100,-28}},
                  lineColor={0,0,255}), Text(
                extent={{0,-8},{0,12}},
                lineColor={0,0,255},
                textString="R=0")}));
      end no_contact_and_no_wire_res;

      model contact_and_wire_res "Contact and wire resistance"

        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      parameter Real spec_contact_resistance(unit="Ohm.m2")=8.4e-10; //Reference: H.J. Goldsmid, Introduction to Thermoelectricity, Srpinter 2010, p.175

        extends Leg_connector_electrical_base;

        Modelica.Electrical.Analog.Basic.Resistor contact_resistance1(R=N_TE*spec_contact_resistance/(Breadth^2))
          annotation (Placement(transformation(extent={{-72,-10},{-52,10}})));
        Modelica.Electrical.Analog.Basic.Resistor resistor(R=2*N_TE*Material.rho_el*Length/(Thickness*Breadth))
          annotation (Placement(transformation(extent={{-10,-10},{10,10}})));
        Modelica.Electrical.Analog.Basic.Resistor contact_resistance2(R=N_TE*spec_contact_resistance/(Breadth^2))
          annotation (Placement(transformation(extent={{52,-10},{72,10}})));
      equation

      overall_res=N_TE*spec_contact_resistance/(Breadth^2)+2*N_TE*Material.rho_el*Length/(Thickness*Breadth)+N_TE*spec_contact_resistance/(Breadth^2);
        connect(p, contact_resistance1.p) annotation (Line(
            points={{-100,0},{-72,0}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(contact_resistance1.n, resistor.p) annotation (Line(
            points={{-52,0},{-10,0}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(resistor.n, contact_resistance2.p) annotation (Line(
            points={{10,0},{52,0}},
            color={0,0,255},
            smooth=Smooth.None));
        connect(contact_resistance2.n, n) annotation (Line(
            points={{72,0},{100,0}},
            color={0,0,255},
            smooth=Smooth.None));
      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),                 Diagram(graphics), Icon(graphics={Rectangle(extent={{-100,32},{100,
                    -32}}, lineColor={0,0,255})}));
      end contact_and_wire_res;

      model no_res_no_storage "No heat resistance nor capacity"

        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

        extends Leg_connector_thermal_base;
      equation
        connect(port_a, port_b) annotation (Line(
            points={{-100,0},{100,0}},
            color={191,0,0},
            smooth=Smooth.None));
      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),                 Diagram(graphics), Icon(graphics));
      end no_res_no_storage;

      model res_and_storage "heat resistance and heat storage"

        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

        extends Leg_connector_thermal_base;
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C=N_TE*Breadth*Length*Thickness*Material.c*Material.rho)
          annotation (Placement(transformation(extent={{-10,6},{10,26}})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor thermalConductor(G=N_TE*Breadth*Length/(Thickness*0.5)*Material.lambda)
          annotation (Placement(transformation(extent={{-66,-10},{-46,10}})));
        Modelica.Thermal.HeatTransfer.Components.ThermalConductor thermalConductor1(G=N_TE*Breadth*Length/(Thickness*0.5)*Material.lambda)
          annotation (Placement(transformation(extent={{40,-10},{60,10}})));
      equation
        connect(thermalConductor.port_a, port_a) annotation (Line(
            points={{-66,0},{-100,0}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(thermalConductor.port_b, heatCapacitor.port) annotation (Line(
            points={{-46,0},{0,0},{0,6}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(heatCapacitor.port, thermalConductor1.port_a) annotation (Line(
            points={{0,6},{0,0},{40,0}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(thermalConductor1.port_b, port_b) annotation (Line(
            points={{60,0},{100,0}},
            color={191,0,0},
            smooth=Smooth.None));
      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),                 Diagram(graphics));
      end res_and_storage;
    annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));
    end Components_for_leg_connection;
    annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));
  end Inner_TEG;

  package Packaging

  //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

  extends Modelica.Icons.Package;
    partial model base_class "basic class for packaging"

    //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      parameter Modelica.SIunits.Thickness Thickness "Thickness of packaging";
      parameter Modelica.SIunits.Length Length "Length of TEG";
      parameter Modelica.SIunits.Breadth Breadth "Breadth of TEG";
      parameter Modelica.SIunits.Temperature T_0 "Initial temperature";

      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a
        annotation (Placement(transformation(extent={{-110,-10},{-90,10}})));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b
        annotation (Placement(transformation(extent={{-70,-10},{-50,10}}),
            iconTransformation(extent={{-70,-10},{-50,10}})));
    annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),               Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},
                {-60,100}}), graphics), Diagram(coordinateSystem(extent={{-100,-100},
                {-60,100}})));
    end base_class;

    model simple_one "No storing / heat conductance = inf"
      extends ThermoelectricGenerator_V5_7.Packaging.base_class;

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

    equation
      connect(port_a, port_b) annotation (Line(
          points={{-100,0},{-60,0}},
          color={191,0,0},
          smooth=Smooth.None));
    annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),               Diagram(graphics));
    end simple_one;

    model seq_1D_with_storing "Seq model with heat storing"

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      parameter Integer S=2
        "Number of 1D spatial discretization steps within leg > 1";

    protected
      parameter Modelica.SIunits.Area Area=Breadth*Length "Area";

    public
      extends base_class;

      replaceable
        ThermoelectricGenerator_V5_7.Packaging_Material_Data.MaterialBase Material
        constrainedby
        ThermoelectricGenerator_V5_7.Packaging_Material_Data.MaterialBase
        annotation (choicesAllMatching=true);

      Base.TC_give_T_L_B_lambda[S] tC_give_T_L_B_lambda(
        each Thickness_seq=Thickness/S,
        each Length=Length,
        each Breadth=Breadth,
        each lambda=Material.lambda)
        annotation (Placement(transformation(extent={{-88,-4},{-78,6}})));
      Base.HC_give_T_L_B_rho_c[S - 1] hC_give_T_L_B_rho_c(
        each Thickness_seq=Thickness/(S - 1),
        each Length=Length,
        each Breadth=Breadth,
        each rho=Material.rho,
        each c=Material.c,
        each T_0=T_0)
        annotation (Placement(transformation(extent={{-78,10},{-68,20}})));

    equation
      assert(S > 1,
        "S (Number of spatial discretization) has to be larger then 1");

      for i in 1:(S - 1) loop

        connect(tC_give_T_L_B_lambda[i].port_b, hC_give_T_L_B_rho_c[i].port)
          annotation (Line(
            points={{-78,1},{-73,1},{-73,10}},
            color={191,0,0},
            smooth=Smooth.None));
        connect(tC_give_T_L_B_lambda[i].port_b, tC_give_T_L_B_lambda[i + 1].port_a)
          annotation (Diagram(graphics));

      end for;

      connect(tC_give_T_L_B_lambda[S].port_b, port_b);
      connect(tC_give_T_L_B_lambda[1].port_a, port_a);

    annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),               Diagram(coordinateSystem(extent={{-100,-140},{-60,140}},
              preserveAspectRatio=false),
                          graphics={Text(
                    extent={{-12,6},{24,-2}},
                    lineColor={0,0,0},
                    textString="..."),Text(
                    extent={{12,6},{12,6}},
                    lineColor={255,0,0},
                    textString="..."),Text(
                    extent={{12,14},{12,-58}},
                    lineColor={0,0,0},
                    textString="... a"),Text(
                    extent={{24,-6},{34,-66}},
                    lineColor={0,0,0},
                    textString="lala

"),    Text(  extent={{24,38},{24,26}},
                    lineColor={0,0,0},
                    textString="Edit Here a")}), Icon(coordinateSystem(
              preserveAspectRatio=false, extent={{-100,-140},{-60,140}}),
            graphics={Rectangle(
              extent={{-100,140},{-60,-140}},
              lineColor={135,135,135},
              fillColor={239,199,159},
              fillPattern=FillPattern.Solid)}));
    end seq_1D_with_storing;

    package Base

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

    extends Modelica.Icons.BasesPackage;
      model TC_give_T_L_B_lambda
        "thermal conductor given by thickness_seq, length, breadth and lambda of TEG"

        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

        parameter Modelica.SIunits.Thickness Thickness_seq
          "Distance between heat ports";
        parameter Modelica.SIunits.Length Length "Length of TEG";
        parameter Modelica.SIunits.Breadth Breadth "Breadth of TEG";
        parameter Modelica.SIunits.ThermalConductivity lambda
          "Thermal conductivity";
        parameter Modelica.SIunits.ThermalConductance G=((Length*Breadth*
            lambda)/Thickness_seq) "Constant thermal conductance of material"
          annotation (dialog(enable=true));

        extends Modelica.Thermal.HeatTransfer.Interfaces.Element1D;

      equation
        Q_flow = G*dT;

      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),                 Icon(graphics={Rectangle(
                        extent={{-90,72},{90,-68}},
                        lineColor={0,0,0},
                        pattern=LinePattern.None,
                        fillColor={192,192,192},
                        fillPattern=FillPattern.Backward),Line(
                        points={{-90,72},{-90,-68}},
                        color={0,0,0},
                        thickness=0.5),Line(
                        points={{90,72},{90,-68}},
                        color={0,0,0},
                        thickness=0.5),Text(
                        extent={{0,-78},{0,-84}},
                        lineColor={0,0,0},
                        textString="%G"),Text(
                        extent={{0,74},{0,100}},
                        lineColor={0,0,255},
                        textString="%name")}));
      end TC_give_T_L_B_lambda;

      model HC_give_T_L_B_rho_c "Lumped thermal element storing heat"

        //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

        parameter Modelica.SIunits.Thickness Thickness_seq
          "distance between heat ports";
        parameter Modelica.SIunits.Length Length "Length of TEG";
        parameter Modelica.SIunits.Breadth Breadth "Breadth of TEG";
        parameter Modelica.SIunits.Density rho "Mass density of material"
          annotation (dialog(enable=true));
        parameter Modelica.SIunits.SpecificHeatCapacity c
          "Specific heat capacity";
        parameter Modelica.SIunits.Temperature T_0 "Initial temperature"
          annotation (dialog(enable=true));

        parameter Modelica.SIunits.HeatCapacity C=Thickness_seq*Length*
            Breadth*rho*c "Heat capacity of element (= cp*m)";
        Modelica.SIunits.Temperature T(start=T_0, displayUnit="degC")
          "Temperature of element";
        Modelica.SIunits.TemperatureSlope der_T(start=0)
          "Time derivative of temperature (= der(T))";

        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port annotation (
            Placement(transformation(extent={{-10,-110},{10,-90}}),
              iconTransformation(extent={{-10,-110},{10,-90}})));
      equation
        T = port.T;
        der_T = der(T);
        C*der(T) = port.Q_flow;
      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),       Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},
                  {100,100}}),graphics={Text(
                        extent={{-150,110},{150,70}},
                        textString="%name",
                        lineColor={0,0,255}),Polygon(
                        points={{0,67},{-20,63},{-40,57},{-52,43},{-58,35},{-68,
                  25},{-72,13},{-76,-1},{-78,-15},{-76,-31},{-76,-43},{-76,-53},
                  {-70,-65},{-64,-73},{-48,-77},{-30,-83},{-18,-83},{-2,-85},
                  {8,-89},{22,-89},{32,-87},{42,-81},{54,-75},{56,-73},{66,-61},
                  {68,-53},{70,-51},{72,-35},{76,-21},{78,-13},{78,3},{74,15},
                  {66,25},{54,33},{44,41},{36,57},{26,65},{0,67}},
                        lineColor={160,160,164},
                        fillColor={192,192,192},
                        fillPattern=FillPattern.Solid),Polygon(
                        points={{-58,35},{-68,25},{-72,13},{-76,-1},{-78,-15},
                  {-76,-31},{-76,-43},{-76,-53},{-70,-65},{-64,-73},{-48,-77},
                  {-30,-83},{-18,-83},{-2,-85},{8,-89},{22,-89},{32,-87},{42,
                  -81},{54,-75},{42,-77},{40,-77},{30,-79},{20,-81},{18,-81},
                  {10,-81},{2,-77},{-12,-73},{-22,-73},{-30,-71},{-40,-65},{-50,
                  -55},{-56,-43},{-58,-35},{-58,-25},{-60,-13},{-60,-5},{-60,
                  7},{-58,17},{-56,19},{-52,27},{-48,35},{-44,45},{-40,57},{-58,
                  35}}, lineColor={0,0,0},
                        fillColor={160,160,164},
                        fillPattern=FillPattern.Solid),Text(
                        extent={{-69,7},{71,-24}},
                        lineColor={0,0,0},
                        textString="%C")}),
          Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},
                  {100,100}}), graphics={Polygon(
                        points={{0,67},{-20,63},{-40,57},{-52,43},{-58,35},{-68,
                  25},{-72,13},{-76,-1},{-78,-15},{-76,-31},{-76,-43},{-76,-53},
                  {-70,-65},{-64,-73},{-48,-77},{-30,-83},{-18,-83},{-2,-85},
                  {8,-89},{22,-89},{32,-87},{42,-81},{54,-75},{56,-73},{66,-61},
                  {68,-53},{70,-51},{72,-35},{76,-21},{78,-13},{78,3},{74,15},
                  {66,25},{54,33},{44,41},{36,57},{26,65},{0,67}},
                        lineColor={160,160,164},
                        fillColor={192,192,192},
                        fillPattern=FillPattern.Solid),Polygon(
                        points={{-58,35},{-68,25},{-72,13},{-76,-1},{-78,-15},
                  {-76,-31},{-76,-43},{-76,-53},{-70,-65},{-64,-73},{-48,-77},
                  {-30,-83},{-18,-83},{-2,-85},{8,-89},{22,-89},{32,-87},{42,
                  -81},{54,-75},{42,-77},{40,-77},{30,-79},{20,-81},{18,-81},
                  {10,-81},{2,-77},{-12,-73},{-22,-73},{-30,-71},{-40,-65},{-50,
                  -55},{-56,-43},{-58,-35},{-58,-25},{-60,-13},{-60,-5},{-60,
                  7},{-58,17},{-56,19},{-52,27},{-48,35},{-44,45},{-40,57},{-58,
                  35}}, lineColor={0,0,0},
                        fillColor={160,160,164},
                        fillPattern=FillPattern.Solid),Ellipse(
                        extent={{-6,-1},{6,-12}},
                        lineColor={255,0,0},
                        fillColor={191,0,0},
                        fillPattern=FillPattern.Solid),Text(
                        extent={{11,13},{50,-25}},
                        lineColor={0,0,0},
                        textString="T"),Line(points={{0,-12},{0,-96}}, color=
                {255,0,0})}),
          DymolaStoredErrors);
      end HC_give_T_L_B_rho_c;
    annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));
    end Base;
  annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));
  end Packaging;

  package System_Components

    //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

  extends Modelica.Icons.Package;
    model simple_heatsink "simple heatsink"

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

    parameter Modelica.SIunits.ThermalResistance R_th=3.5
        "Thermal resistance of heatsink";
        // http://www.conrad.de/ce/de/product/181192/Stiftkuehlkoerper-ICK-S-Fischer-Elektronik-ICK-S-40X40X20-L-x-B-x-H-40-x-40-x-20-mm-Rth-35-KW?queryFromSuggest=true

    extends Modelica.Thermal.HeatTransfer.Interfaces.Element1D;

    equation
      Q_flow=dT/R_th;

    annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),               Diagram(coordinateSystem(extent={{-100,-120},{100,120}},
              preserveAspectRatio=true), graphics={Polygon(
              points={{-100,90},{-100,-110},{40,-110},{40,-90},{-80,-90},{-80,
                  -70},{40,-70},{40,-50},{-80,-50},{-80,-30},{40,-30},{40,-10},
                  {-80,-10},{-80,10},{40,10},{40,30},{-80,30},{-80,50},{40,50},
                  {40,70},{-80,70},{-80,90},{40,90},{40,110},{-100,110},{-100,
                  90}},
              lineColor={135,135,135},
              smooth=Smooth.None,
              fillColor={135,135,135},
              fillPattern=FillPattern.Solid), Text(
              extent={{0,-94},{0,-68}},
              lineColor={255,0,0},
              fillColor={135,135,135},
              fillPattern=FillPattern.Solid,
              textString="Q_flow=dT/R_th")}), Icon(coordinateSystem(extent={{
                -100,-120},{100,120}}), graphics={Polygon(
              points={{-100,90},{-100,-110},{40,-110},{40,-90},{-80,-90},{-80,
                  -70},{40,-70},{40,-50},{-80,-50},{-80,-30},{40,-30},{40,-10},
                  {-80,-10},{-80,10},{40,10},{40,30},{-80,30},{-80,50},{40,50},
                  {40,70},{-80,70},{-80,90},{40,90},{40,110},{-100,110},{-100,
                  90}},
              lineColor={135,135,135},
              smooth=Smooth.None,
              fillColor={135,135,135},
              fillPattern=FillPattern.Solid), Text(
              extent={{0,-92},{0,-66}},
              lineColor={255,0,0},
              fillColor={135,135,135},
              fillPattern=FillPattern.Solid,
              textString="Q_flow=dT/R_th")}));
    end simple_heatsink;

    model simple_heatsink_with_heat_cap "simple heatsink with heat capacity"

    //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

    parameter Modelica.SIunits.HeatCapacity C=150
        "Heat capacity of element (= cp*m)";
    parameter Modelica.SIunits.ThermalResistance R_th=3.5;

      simple_heatsink simple_heatsink1(R_th=R_th)
        annotation (Placement(transformation(extent={{50,-12},{70,12}})));
      Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C=C)
        annotation (Placement(transformation(extent={{-26,28},{-6,48}})));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a
        annotation (Placement(transformation(extent={{-112,-10},{-92,10}})));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b
        annotation (Placement(transformation(extent={{92,-10},{112,10}})));
    equation
      connect(port_a, heatCapacitor.port) annotation (Line(
          points={{-102,0},{-16,0},{-16,28}},
          color={191,0,0},
          smooth=Smooth.None));
      connect(heatCapacitor.port, simple_heatsink1.port_a) annotation (Line(
          points={{-16,28},{-16,0},{50,0}},
          color={191,0,0},
          smooth=Smooth.None));
      connect(simple_heatsink1.port_b, port_b) annotation (Line(
          points={{70,0},{102,0}},
          color={191,0,0},
          smooth=Smooth.None));
    annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),               Diagram(coordinateSystem(extent={{-100,-120},{100,120}},
              preserveAspectRatio=false),graphics={
                                              Text(
              extent={{0,-94},{0,-68}},
              lineColor={255,0,0},
              fillColor={135,135,135},
              fillPattern=FillPattern.Solid,
              textString="Q_flow=dT/R_th")}), Icon(coordinateSystem(extent={{
                -100,-120},{100,120}}), graphics={Polygon(
              points={{-82,90},{-82,-110},{58,-110},{58,-90},{-62,-90},{-62,-70},{58,
                  -70},{58,-50},{-62,-50},{-62,-30},{58,-30},{58,-10},{-62,-10},{-62,
                  10},{58,10},{58,30},{-62,30},{-62,50},{58,50},{58,70},{-62,70},{-62,
                  90},{58,90},{58,110},{-82,110},{-82,90}},
              lineColor={135,135,135},
              smooth=Smooth.None,
              fillColor={135,135,135},
              fillPattern=FillPattern.Solid)}));
    end simple_heatsink_with_heat_cap;

    model MPPT_compact
      "simple MPPT to get the same internal and load resistance"

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

    extends Modelica.Electrical.Analog.Interfaces.TwoPin;

    parameter Modelica.SIunits.Temperature Temp_ref;
    parameter Modelica.SIunits.Resistance R_ref=2.5;
    parameter Modelica.SIunits.LinearTemperatureCoefficient alpha=1.2/300;
    parameter Modelica.SIunits.Temperature T_ref=300.15;
     Modelica.SIunits.Resistance R_temp_corr;

      Modelica.Electrical.Analog.Sensors.VoltageSensor voltageSensor2 annotation (
          Placement(transformation(
            extent={{-8,-8},{8,8}},
            rotation=270,
            origin={-14,-8})));
      Modelica.Electrical.Analog.Sensors.CurrentSensor currentSensor1
                                                                     annotation (
          Placement(transformation(
            extent={{-10,-10},{10,10}},
            rotation=0,
            origin={-66,0})));
      Modelica.Blocks.Interfaces.RealOutput y annotation (Placement(
            transformation(
            extent={{-10,-10},{10,10}},
            rotation=270,
            origin={8,-110})));
      Modelica.Blocks.Math.Product product1 annotation (Placement(transformation(
            extent={{-10,-10},{10,10}},
            rotation=180,
            origin={-68,80})));
      Modelica.Electrical.Analog.Basic.VariableResistor variableResistor
        annotation (Placement(transformation(extent={{20,-10},{40,10}})));
      Modelica.Blocks.Interfaces.RealInput Temp
        annotation (Placement(transformation(extent={{-132,66},{-92,106}})));
      Modelica.Electrical.Analog.Basic.Ground ground
        annotation (Placement(transformation(extent={{82,-46},{102,-26}})));
    initial equation

      R_temp_corr=2.7;

    equation
      R_temp_corr=(1+(Temp-Temp_ref)*alpha)*R_ref;
      variableResistor.R=R_temp_corr;
      connect(voltageSensor2.n, n) annotation (Line(
          points={{-14,-16},{-14,-56},{100,-56},{100,0}},
          color={0,0,255},
          smooth=Smooth.None));
      connect(p, currentSensor1.p) annotation (Line(
          points={{-100,0},{-76,0}},
          color={0,0,255},
          smooth=Smooth.None));
      connect(currentSensor1.n, voltageSensor2.p) annotation (Line(
          points={{-56,0},{-14,0}},
          color={0,0,255},
          smooth=Smooth.None));
      connect(y, product1.y) annotation (Line(
          points={{8,-110},{8,-84},{-92,-84},{-92,80},{-79,80}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(voltageSensor2.p, variableResistor.p) annotation (Line(
          points={{-14,0},{20,0}},
          color={0,0,255},
          smooth=Smooth.None));
      connect(variableResistor.n, n) annotation (Line(
          points={{40,0},{100,0}},
          color={0,0,255},
          smooth=Smooth.None));

      connect(voltageSensor2.v, product1.u2) annotation (Line(
          points={{-22,-8},{-40,-8},{-40,86},{-56,86}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(currentSensor1.i, product1.u1) annotation (Line(
          points={{-66,-10},{-46,-10},{-46,74},{-56,74}},
          color={0,0,127},
          smooth=Smooth.None));
      connect(ground.p, n) annotation (Line(
          points={{92,-26},{94,-26},{94,0},{100,0}},
          color={0,0,255},
          smooth=Smooth.None));
    annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),               Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                -100},{100,100}}), graphics), Icon(coordinateSystem(
              preserveAspectRatio=false, extent={{-100,-100},{100,100}}),
            graphics={
            Rectangle(
              extent={{-100,100},{100,-100}},
              lineColor={95,95,95},
              fillColor={215,215,215},
              fillPattern=FillPattern.Solid), Text(
              extent={{2,18},{2,-18}},
              lineColor={0,0,0},
              textString="MPPT")}));
    end MPPT_compact;
  annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));
  end System_Components;

  package Thermoelectric_Material_Data

    //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

    extends Modelica.Icons.MaterialPropertiesPackage;

    record MaterialBase
      "Base class to be extended by specific material records"

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      parameter Modelica.SIunits.SpecificHeatCapacity c=1000
        "Specific heat capacity" annotation (dialog(enable=true));
      parameter Modelica.SIunits.Density rho=1000 "Mass density of material"
        annotation (dialog(enable=true));
      parameter Real rho_el[:, :](unit="Ohm.m") = {{0,0.01}}
        "Electrical resistivity" annotation (dialog(enable=true));
      parameter Modelica.SIunits.ThermalConductivity lambda[:, :]={{0,1}}
        "Thermal conductivity" annotation (dialog(enable=true));
      parameter Modelica.SIunits.SeebeckCoefficient alpha[:, :]={{0,2e-4}}
        "Seebeck coefficient of material" annotation (dialog(enable=true));

      parameter Modelica.SIunits.Voltage Int_alpha[:, :]={{0,2e-4}}
        "Temperature integral of Seebeck coefficient"
        annotation (dialog(enable=true));

      parameter String Table_alpha="NoName"
        "Name of table on file containing temperature-dependent data of 'alpha'";
      parameter String File_alpha="NoName"
        "Name of file containing temperature-dependent data of 'alpha'";

      parameter String Table_rho_el="NoName"
        "Name of table on file containing temperature-dependent data of 'rho_el'";
      parameter String File_rho_el="NoName"
        "Name of file containing temperature-dependent data of 'rho_el'";

      parameter String Table_lambda="NoName"
        "Name of table on file containing temperature-dependent data of 'lambda'";
      parameter String File_lambda="NoName"
        "Name of file containing temperature-dependent data of 'lambda'";

      parameter String Table_Int_alpha="NoName"
        "Name of table on file containing temperature-dependent data of temp. integral of 'alpha'";
      parameter String File_Int_alpha="NoName"
        "Name of file containing temperature-dependent data of temp. integral of 'alpha'";

      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"));
    end MaterialBase;

    record Bi2_Te3_p_Thermonamic
      "Bismuth-Telluride (Bi2Te3), p-type, from Thermonamic Electronics Corp."

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends MaterialBase(
        c=163,
        alpha=[300, 221E-6; 325, 221.5E-6; 350, 222.5E-6; 375, 223E-6; 400,
            220E-6; 425, 211E-6; 450, 197E-6; 475, 173E-6; 500, 142.5E-6],
        rho=7700,
        rho_el=[300, 9.47867E-6; 325, 1.11111E-5; 350, 1.2987E-5; 375,
            1.49254E-5; 400, 1.66667E-5; 425, 1.81818E-5; 450, 1.92308E-5; 475,
            2.0202E-5; 500, 2.08333E-5],
        lambda=[300, 1.42; 325, 1.36; 350, 1.36; 375, 1.41; 400, 1.505; 425,
            1.65; 450, 1.82; 475, 2.02; 500, 2.25],
        Int_alpha=[300, 0.005525; 325, 0.01105625; 350, 0.01660625; 375,
            0.022175; 400, 0.0277125; 425, 0.0331; 450, 0.0382; 475, 0.042825;
            500, 0.04676875],
        Table_alpha="NoName",
        File_alpha="NoName",
        Table_rho_el="NoName",
        File_rho_el="NoName",
        Table_lambda="NoName",
        File_lambda="NoName",
        Table_Int_alpha="NoName",
        File_Int_alpha="NoName");

      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"), Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,
                100}}), graphics={Rectangle(
              extent={{-100,100},{100,-100}},
              lineColor={252,223,0},
              fillColor={255,255,255},
              fillPattern=FillPattern.Solid,
              lineThickness=0.5), Text(
              extent={{0,118},{0,-76}},
              lineColor={0,0,0},
              fillColor={255,128,0},
              fillPattern=FillPattern.Solid,
              textString="p")}));
    end Bi2_Te3_p_Thermonamic;

    record Bi2_Te3_n_Thermonamic
      "Bismuth-Telluride (Bi2Te3), n-type, from Thermonamic Electronics Corp."

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends MaterialBase(
        c=163,
        alpha=[300, -219E-6; 325, -218.5E-6; 350, -218E-6; 375, -218.5E-6; 400,
            -218E-6; 425, -214.5E-6; 450, -206E-6; 475, -192.5E-6; 500, -175E-6],
        rho=7700,
        rho_el=[300, 8.29876E-6; 325, 9.00901E-6; 350, 9.7561E-6; 375,
            1.0582E-5; 400, 1.13636E-5; 425, 1.20482E-5; 450, 1.25E-5; 475,
            1.25786E-5; 500, 1.25E-5],
        lambda=[300, 1.575; 325, 1.51; 350, 1.51; 375, 1.54; 400, 1.62; 425,
            1.73; 450, 1.88; 475, 2.09; 500, 2.33],
        Int_alpha=[300, -0.005475; 325, -0.01094375; 350, -0.0164; 375, -0.02185625;
            400, -0.0273125; 425, -0.03271875; 450, -0.037975; 475, -0.04295625;
            500, -0.04755],
        Table_alpha="NoName",
        File_alpha="NoName",
        Table_rho_el="NoName",
        File_rho_el="NoName",
        Table_lambda="NoName",
        File_lambda="NoName",
        Table_Int_alpha="NoName",
        File_Int_alpha="NoName");

      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"), Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,
                100}}), graphics={Rectangle(
              extent={{-100,100},{100,-100}},
              lineColor={0,127,0},
              fillColor={255,255,255},
              fillPattern=FillPattern.Solid,
              lineThickness=0.5), Text(
              extent={{0,98},{0,-96}},
              lineColor={0,0,0},
              fillColor={255,255,255},
              fillPattern=FillPattern.Solid,
              textString="n")}));
    end Bi2_Te3_n_Thermonamic;

    record PbTe_p_Thermonamic
      "Lead-Telluride (PbTe), p-type, from Thermonamic Electronics Corp."

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends MaterialBase(
        c=160,
        alpha=[300, 126E-6; 350, 161E-6; 400, 189E-6; 450, 216E-6; 500, 236E-6;
            550, 255E-6; 600, 267E-6; 650, 274E-6; 700, 276E-6],
        rho=8160,
        rho_el=[300, 2E-5; 350, 2.2E-5; 400, 2.5E-5; 450, 2.8E-5; 500, 3.15E-5;
            550, 3.5E-5; 600, 3.75E-5; 650, 4.15E-5; 700, 4.25E-5],
        lambda=[300, 1.97; 350, 1.74; 400, 1.52; 450, 1.33; 500, 1.2; 550, 1.1;
            600, 1.05; 650, 1.01; 700, 1],
        Table_alpha="NoName",
        File_alpha="NoName",
        Table_rho_el="NoName",
        File_rho_el="NoName",
        Table_lambda="NoName",
        File_lambda="NoName");

      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p> 
**************************************************************************** <p>
</html>
"), Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,
                100}}), graphics={Rectangle(
              extent={{-100,100},{100,-100}},
              lineColor={244,224,4},
              lineThickness=0.5,
              fillColor={255,181,178},
              fillPattern=FillPattern.Solid), Text(
              extent={{6,122},{6,-72}},
              lineColor={0,0,0},
              fillColor={255,85,85},
              fillPattern=FillPattern.Solid,
              textString="p")}));
    end PbTe_p_Thermonamic;

    record PbTe_n_Thermonamic
      "Lead-Telluride (PbTe), n-type, from Thermonamic Electronics Corp."

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends MaterialBase(
        c=160,
        alpha=[323, -205E-6; 373, -235E-6; 423, -254E-6; 473, -272E-6; 523, -285E-6;
            573, -294E-6; 623, -297E-6; 673, -299E-6],
        rho=8160,
        rho_el=[323, 1.2E-5; 373, 2.1E-5; 423, 2.7E-5; 473, 3.2E-5; 523, 3.9E-5;
            573, 4.2E-5; 623, 4.6E-5; 673, 5.1E-5],
        lambda=[323, 2.52; 373, 1.87; 423, 1.61; 473, 1.53; 523, 1.33; 573,
            1.29; 623, 1.24; 673, 1.24],
        Table_alpha="NoName",
        File_alpha="NoName",
        Table_rho_el="NoName",
        File_rho_el="NoName",
        Table_lambda="NoName",
        File_lambda="NoName");

      annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"), Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,
                100}}), graphics={Rectangle(
              extent={{-100,100},{100,-100}},
              lineColor={0,127,0},
              lineThickness=0.5,
              fillColor={255,181,178},
              fillPattern=FillPattern.Solid), Text(
              extent={{10,108},{10,-86}},
              lineColor={0,0,0},
              fillColor={195,195,195},
              fillPattern=FillPattern.Solid,
              textString="n")}));
    end PbTe_n_Thermonamic;
    annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));

  end Thermoelectric_Material_Data;

  package Packaging_Material_Data

  //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

  extends Modelica.Icons.MaterialPropertiesPackage;
    record MaterialBase
      "Base class to be extended by specific material records"

      //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      parameter String Material_Name="noName";
      parameter String Material_Name_Abbreviation="noName";
      parameter Modelica.SIunits.SpecificHeatCapacity c=1000
        "Specific heat capacity" annotation (dialog(enable=true));
      parameter Modelica.SIunits.Density rho=1 "Mass density of material"
        annotation (dialog(enable=true));
      parameter Modelica.SIunits.Resistivity rho_el=1 "Electrical resistivity"
                                 annotation (dialog(enable=true));

      parameter Modelica.SIunits.ThermalConductivity lambda=1
        "Thermal conductivity" annotation (dialog(enable=true));

    annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));

    end MaterialBase;

    record Copper

    //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends MaterialBase(
        c=385,
        rho=8920,
        lambda=400,
        rho_el=1.692e-8,
        Material_Name="Copper",
        Material_Name_Abbreviation="Cu"); //Source: http://de.wikipedia.org/wiki/Kupfer

    annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),               Icon(graphics={Rectangle(
              extent={{-100,100},{100,-100}},
              lineColor={127,0,0},
              fillColor={175,175,175},
              fillPattern=FillPattern.Solid), Text(
              extent={{2,60},{2,-56}},
              lineColor={127,0,0},
              fillColor={175,175,175},
              fillPattern=FillPattern.Solid,
              textString="Cu")}));
    end Copper;

    record Ceramic_Al2O3

    //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends MaterialBase(
        c=850,
        rho=3940,
        lambda=30,
        Material_Name="Ceramic",
        rho_el=1e12,
        Material_Name_Abbreviation="Cer");
                  //Source: http://de.wikipedia.org/wiki/Aluminiumoxid, http://en.wikipedia.org/wiki/Aluminium_oxide and http://www.keramik-rs.de/ksuche/k_detail.asp?w_id=42

    annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),               Icon(graphics={Rectangle(
              extent={{-100,100},{100,-100}},
              lineColor={127,0,0},
              fillColor={175,175,175},
              fillPattern=FillPattern.Solid), Text(
              extent={{2,60},{2,-56}},
              lineColor={127,0,0},
              fillColor={175,175,175},
              fillPattern=FillPattern.Solid,
              textString="Cer")}));
    end Ceramic_Al2O3;

    record Heat_Paste

    //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends MaterialBase(
        c=385,
        rho=3400,
        lambda=9,
        Material_Name="Heat paste",
        rho_el=1e4,
        Material_Name_Abbreviation="HP");
        // Source: www.thermalforce.de Product: wlp 35005
        // Information: c and rho_el are dummy values

    annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),               Icon(graphics={Rectangle(
              extent={{-100,100},{100,-100}},
              lineColor={127,0,0},
              fillColor={175,175,175},
              fillPattern=FillPattern.Solid), Text(
              extent={{4,60},{4,-56}},
              lineColor={127,0,0},
              fillColor={175,175,175},
              fillPattern=FillPattern.Solid,
              textString="HP")}));
    end Heat_Paste;

    record Aluminium

    //Copyright(C) 2012-2015 Chair of Automation and Energy Systems, Saarland University (for more information see 'Documentation')

      extends MaterialBase(
        c=897,
        rho=2700,
        lambda=235,
        Material_Name="Aluminum",
        rho_el=2.65e-8,
        Material_Name_Abbreviation="Al");
        //Source: http://de.wikipedia.org/wiki/Aluminium

    annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"),               Icon(graphics={Rectangle(
              extent={{-100,100},{100,-100}},
              lineColor={127,0,0},
              fillColor={175,175,175},
              fillPattern=FillPattern.Solid), Text(
              extent={{4,60},{4,-56}},
              lineColor={127,0,0},
              fillColor={175,175,175},
              fillPattern=FillPattern.Solid,
              textString="HP")}));
    end Aluminium;
  annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This file is part of ThermoelectricGenerator. <p>

  ThermoelectricGenerator is free software: you can redistribute it and/or modify it under the <br> 
  terms of the <b> GNU General Public License </b> as published by the Free Software Foundation, <br>
   either <b>version 3</b> of the License, or any later version. <p>

  ThermoelectricGenerator is distributed in the hope that it will be useful, but WITHOUT ANY <br> 
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A <br>
  PARTICULAR PURPOSE. See the GNU General PUblic License for more details. <p> 
  

  You should have received a copy of the GNU General Public License along with <br>
  ThermoelectricGenerator. If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
**************************************************************************** <p>
</html>
"));
  end Packaging_Material_Data;

  annotation (Documentation(info="<html>
<p>
**************************************************************************** <br>
  <b> ThermoelectricGenerator </b> - Component-oriented Modeling of Thermoelectric Devices <br>
  ------------------------------------------------------------------------------------------------------------------ <br>
  <b> Copyright (C) 2012-2015 Chair of Automation and Energy Systems, Saarland University </b> <br>
------------------------------------------------------------------------------------------------------------------ <br>
  This program is free software: you can redistribute it and/or modify it under the terms of the <br> 
  <b> GNU General Public License </b> as published by the Free Software Foundation, either <br>
  <b>version 3</b> of the License, or any later version. <p>

  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; <br> 
  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR <br>
  PURPOSE. See the GNU General PUblic License for more details. <p> 

  You should have received a copy of the GNU General Public License along with this program. <br>
  If not, see http://www.gnu.org/licenses/. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  Type classes, parts of models, blocks, functions, records and/or connector classes are also <br> 
  under the GNU General Public License, version 3 of the License, or any later version, according <br>
  to article 2d) of The ModelicaLicense 2. <br>
------------------------------------------------------------------------------------------------------------------ <br>
  <b> <u> Comment:<p> </b> </u>
  
  If you do some improvements or extensions at ThermoelectricGenerator, please let us know! <p> 
  If you use ThermoelectricGenerator for scientific research, please quote our paper: <p>
  F. Felgner, L. Exel, M. Nesarajah, and G. Frey, ''Component-oriented Modeling of <br>
  Thermoelectric Devices for Energy System Design'', IEEE Transactions on Industrial Electronics, <br>
  Vol.: 61, No.: 3, March 2014, pp. 1301-1310 <p>
  http://ieeexplore.ieee.org/xpls/abs_all.jsp?arnumber=6512017 <p>
------------------------------------------------------------------------------------------------------------------ <br>
  <u> Contact details:</u> <p>
  <table>
  <tr> <td> Dr.-Ing. Felix Felgner </td> <td> Secretariat </td> </tr>
  <tr> <td> </td> <td> </td> </tr>
  <tr> <td> Saarland University </td> <td> Saarland University </td> </tr>
  <tr> <td> Faculty 7 - Natural Sciences and Technology II </td> <td> Faculty 7 - Natural Sciences and Technology II </td> </tr>
  <tr> <td> Department 7.4 - Mechatronics Engineering </td> <td> Department 7.4 - Mechatronics Engineering </td> </tr>
  <tr> <td> Chair of Automation </td> <td> Chair of Automation </td> </tr>
  <tr> <td> D-66123 Saarbruecken </td> <td> D-66123 Saarbruecken </td> </tr>
  <tr> <td> Germany </td> <td> Germany </td> </tr>
  <tr> <td> Building A5 1 / Room 1.32 </td> <td> Building A5 1 / Room 1.34  </td> </tr>
  <tr> <td> Tel: +49-(0)681-302-57593 </td> <td> Tel: +49-(0)681-302-57595 </td> </tr>
  <tr> <td> Fax: +49-(0)681-302-57599 </td> <td> Fax: +49-(0)681-302-57599 </td> </tr>
  <tr> <td> felix.felgner@aut.uni-saarland.de </td> <td> sekretariat@aut.uni-saarland.de </td> </tr>
  <tr> <td> </td> </tr>
  <tr> <td> URL: www.aut.uni-saarland.de </td> </tr>
  </table>                      
**************************************************************************** <p>
</html>
"), uses(Modelica(version="3.2.1"), ThermoelectricGenerator_V5_6(version="1")),
    version="1",
    conversion(noneFromVersion=""));
end ThermoelectricGenerator_V5_7;
